#include "mainwidget.h"
#include "lenswidget.h"
#include <grale/constants.h>
#include <qsplitter.h>
#include <q3progressbar.h>
#include <qsizepolicy.h>
#include <qpushbutton.h>
#include <qslider.h>
#include <qlayout.h>
#include <q3vbox.h>
#include <qlabel.h>
#include <qimage.h>
#include <qpixmap.h>
#include <qcolor.h>
#include <q3filedialog.h>
#include <qmessagebox.h>
#include <q3textedit.h>
#include <qbrush.h>
#include <q3stylesheet.h>
//Added by qt3to4:
#include <Q3HBoxLayout>
#include <Q3VBoxLayout>
#include <Q3Frame>
#include <QCloseEvent>
#include <stdio.h>
#include <iostream>
#include <algorithm>

using namespace grale;

//#define DUTCH

MainWidget::MainWidget()
{
#ifdef DUTCH
	setCaption("Demonstratie gravitationele lenzen");
#else
	setCaption("Gravitational lens demonstration");
#endif
	QSplitter *pSplitter = new QSplitter(Qt::Horizontal, this);

	setCentralWidget(pSplitter);

	m_pLensWidget = new LensWidget(pSplitter, 1024, 1024, 2.0*ANGLE_ARCMIN);
	Q3Frame *pFrame = new Q3Frame(pSplitter);

	QLabel *pLogo = new QLabel(pFrame);
	QPixmap logoPixmap(m_logos);
	
	pLogo->setPixmap(logoPixmap);
	pLogo->setMinimumSize(logoPixmap.width(), logoPixmap.height());
	pLogo->setMaximumSize(logoPixmap.width(), logoPixmap.height());

	pFrame->setMinimumWidth(logoPixmap.width()+22);
	pFrame->setMaximumWidth(logoPixmap.width()+22);
	pSplitter->setCollapsible(pFrame, false);

	QPushButton *pNewButton = new QPushButton(pFrame);
	QPushButton *pLoadButton = new QPushButton(pFrame);
	QPushButton *pSaveButton = new QPushButton(pFrame);

#ifdef DUTCH
	pNewButton->setText("Begin opnieuw");
	pLoadButton->setText("Kies achtergrond");
	pSaveButton->setText("Bewaar figuur");
#else
	pNewButton->setText("Start over");
	pLoadButton->setText("Choose background");
	pSaveButton->setText("Save image");
#endif 
	QObject::connect(pNewButton, SIGNAL(clicked()), m_pLensWidget, SLOT(clearLens()));
	QObject::connect(pLoadButton, SIGNAL(clicked()), this, SLOT(onLoadBackgroundImage()));
	QObject::connect(pSaveButton, SIGNAL(clicked()), this, SLOT(onSaveLensedImage()));

	Q3ProgressBar *pProgressBar = new Q3ProgressBar(100, pFrame, 0, Qt::WNoAutoErase|Qt::WPaintClever);
	m_pLensWidget->setProgressBar(pProgressBar);
	
	QSlider *pSlider = new QSlider(0,4000,100,1000,Qt::Horizontal,pFrame);
	QObject::connect(pSlider, SIGNAL(valueChanged(int)), this, SLOT(sliderChanged(int)));
	QObject::connect(this, SIGNAL(massScaleChanged(double)), m_pLensWidget, SLOT(setMassScale(double)));

	Q3TextEdit *pInfo = new Q3TextEdit(pFrame);
#ifdef DUTCH
	pInfo->setText("<p><b>Instructies</b></p>"
		       "<p>Hou in het gebied hiernaast de linkermuisknop ingedrukt en beweeg "
		       "de muis om een gravitationele lens te maken of uit te breiden. "
		       "Met de knoppen hieronder kan je weer helemaal opnieuw beginnen "
		       "of een andere achtergrond gebruiken. Met de schuifbalk kan je de "
		       "zichtbaarheid van de gravitationele lens regelen.</p>");
#else
	pInfo->setText("<p><b>Instructions</b></p>"
		       "<p>In the area on the left side, hold down the left mouse button "
		       "and move the mouse to add a component to the gravitational lens. "
		       "Using the buttons below, you can start over or set another background "
		       "image. The slider controls the visibility of the gravitational lens.</p>");
#endif
	pInfo->setReadOnly(true);
	pInfo->setFrameStyle(Q3Frame::StyledPanel|Q3Frame::Plain);

	// layout stuff

	Q3HBoxLayout *pHorizontalLayout = new Q3HBoxLayout(pFrame);

	QSpacerItem *pHSpacer1 = new QSpacerItem(10,10,QSizePolicy::Fixed,QSizePolicy::Fixed);
	pHorizontalLayout->addItem(pHSpacer1);

	Q3VBoxLayout *pVerticalLayout = new Q3VBoxLayout(pHorizontalLayout);

	QSpacerItem *pHSpacer2 = new QSpacerItem(10,10,QSizePolicy::Fixed,QSizePolicy::Fixed);
	pHorizontalLayout->addItem(pHSpacer2);

	QSpacerItem *pVSpacer1 = new QSpacerItem(10,10,QSizePolicy::Minimum, QSizePolicy::Fixed);
	pVerticalLayout->addItem(pVSpacer1);

	pVerticalLayout->add(pLogo);

	QSpacerItem *pVSpacer2 = new QSpacerItem(10,50,QSizePolicy::Minimum, QSizePolicy::Minimum);
	QSpacerItem *pVSpacer3 = new QSpacerItem(10,50,QSizePolicy::Minimum, QSizePolicy::Minimum);

	pVerticalLayout->addItem(pVSpacer2);
	pVerticalLayout->add(pInfo);
	pVerticalLayout->addItem(pVSpacer3);
	pVerticalLayout->add(pNewButton);
	pVerticalLayout->add(pLoadButton);
	pVerticalLayout->add(pSaveButton);
	pVerticalLayout->add(pSlider);
	pVerticalLayout->add(pProgressBar);

	show();
}

MainWidget::~MainWidget()
{
}

void MainWidget::closeEvent(QCloseEvent *pEvt)
{
	pEvt->accept();
}

void MainWidget::sliderChanged(int value)
{
	double s = (double)value/1000.0;

	emit massScaleChanged(s);
}

void MainWidget::onLoadBackgroundImage()
{
	Q3FileDialog fileDialog("", "*.*", this, 0, true);

#ifdef DUTCH
	fileDialog.setCaption("Selecteer een figuur om als achtergrond te gebruiken");
#else
	fileDialog.setCaption("Select an image to use as background");
#endif

	if (fileDialog.exec() != QDialog::Accepted)
		return;

	QImage image;

	if (!image.load(fileDialog.selectedFile().ascii()))
	{
#ifdef DUTCH
		QMessageBox::warning(this, "Er is een fout opgetreden", "Het geselecteerde bestand kan niet geladen worden", QMessageBox::Ok, Qt::NoButton);
#else
		QMessageBox::warning(this, "An error occurred", "Unable to load the selected file", QMessageBox::Ok, Qt::NoButton);
#endif
		return;
	}

	m_pLensWidget->setLensBackground(image);
}

void MainWidget::onSaveLensedImage()
{
#ifdef DUTCH
	QString fileName = Q3FileDialog::getSaveFileName(QString::null, "*.png", this, 0, "Figuur opslaan");
#else
	QString fileName = Q3FileDialog::getSaveFileName(QString::null, "*.png", this, 0, "Save image");
#endif
	if (fileName == QString::null) // cancelled
		return;
	
	QFileInfo fileInfo(fileName);

	if (fileInfo.exists())
	{
#ifdef DUTCH
		int result = QMessageBox::question(this, "Bevestigen", "Er is al een bestand met dezelfde naam. Overschrijven?", "Ja", "Nee", QString::null, 1);
#else
		int result = QMessageBox::question(this, "Confirm", "A file with the specified name already exists. Replace?", "Yes", "No", QString::null, 1);
#endif
		if (result != 0)
			return;
	}

	QImage image = m_pLensWidget->getLensedImage();

	if (!image.save(fileName,"PNG"))
	{
#ifdef DUTCH
		QMessageBox::warning(this, "Er is een fout opgetreden", "Het bestand kon niet opgeslagen worden", QMessageBox::Ok, Qt::NoButton);
#else
		QMessageBox::warning(this, "An error occurred", "Unable to save the file", QMessageBox::Ok, Qt::NoButton);
#endif
	}
}

//#include "mainwidget.moc"

const char * MainWidget::m_logos[] = {
"240 206 5530 2",
"  	c None",
". 	c #8A8A8A",
"+ 	c #A7A7A7",
"@ 	c #AEAEAE",
"# 	c #AFAFAF",
"$ 	c #979797",
"% 	c #E8E8E8",
"& 	c #FEFEFE",
"* 	c #FFFFFF",
"= 	c #FCFCFC",
"- 	c #F8F8F8",
"; 	c #FDFDFD",
"> 	c #EDEDED",
", 	c #D4D4D4",
"' 	c #CBCBCB",
") 	c #E0E0E0",
"! 	c #FBFBFB",
"~ 	c #E6E6E6",
"{ 	c #C0C0C0",
"] 	c #B7B7B7",
"^ 	c #AEAEAF",
"/ 	c #A9A9A9",
"( 	c #B6B6B6",
"_ 	c #DBDBDB",
": 	c #F4F4F5",
"< 	c #FDFDFE",
"[ 	c #FEFEFF",
"} 	c #F3F3F3",
"| 	c #D0D0D0",
"1 	c #C2C2C2",
"2 	c #ABABAC",
"3 	c #A0A0A1",
"4 	c #949496",
"5 	c #949497",
"6 	c #A2A2A4",
"7 	c #B7B7BA",
"8 	c #D4D4D7",
"9 	c #EDEDF1",
"0 	c #FAFAFD",
"a 	c #FBFBFF",
"b 	c #FBFCFF",
"c 	c #FCFCFF",
"d 	c #FDFDFF",
"e 	c #F9F9F9",
"f 	c #F7F7F7",
"g 	c #F4F4F4",
"h 	c #F1F1F1",
"i 	c #F6F6F6",
"j 	c #F0F0F0",
"k 	c #E2E2E3",
"l 	c #C6C6C7",
"m 	c #BCBCBD",
"n 	c #AFAFB2",
"o 	c #A2A2A5",
"p 	c #96969A",
"q 	c #89898D",
"r 	c #818186",
"s 	c #89898E",
"t 	c #949499",
"u 	c #808086",
"v 	c #646469",
"w 	c #75767B",
"x 	c #B6B6BC",
"y 	c #F2F3F8",
"z 	c #F9F9FF",
"A 	c #FAFAFF",
"B 	c #F2F2F2",
"C 	c #FAFAFA",
"D 	c #ECECEC",
"E 	c #EFEFEF",
"F 	c #DFDFDF",
"G 	c #D3D3D3",
"H 	c #C5C5C5",
"I 	c #BFBFBF",
"J 	c #BDBDBD",
"K 	c #BCBCBC",
"L 	c #BBBBBB",
"M 	c #C8C8C8",
"N 	c #D9D9D9",
"O 	c #C6C6C6",
"P 	c #C1C1C1",
"Q 	c #BEBEBE",
"R 	c #BABABA",
"S 	c #D1D1D1",
"T 	c #F8F8FB",
"U 	c #D1D1D5",
"V 	c #C1C1C5",
"W 	c #B6B6BA",
"X 	c #A9A9AE",
"Y 	c #9B9BA1",
"Z 	c #8E8E95",
"` 	c #808087",
" .	c #75757D",
"..	c #72727A",
"+.	c #3F4048",
"@.	c #21222A",
"#.	c #282831",
"$.	c #32323B",
"%.	c #43434C",
"&.	c #7C7C84",
"*.	c #E6E6EE",
"=.	c #F7F7FF",
"-.	c #F8F8FF",
";.	c #E1E1E1",
">.	c #CACACA",
",.	c #C4C4C4",
"'.	c #E4E4E4",
").	c #E7E7E7",
"!.	c #DADADA",
"~.	c #CFCFCF",
"{.	c #C3C3C3",
"].	c #B8B8B8",
"^.	c #CDCDCD",
"/.	c #B9B9B9",
"(.	c #B4B4B4",
"_.	c #A4A4A4",
":.	c #A0A0A0",
"<.	c #9D9D9D",
"[.	c #9A9A9A",
"}.	c #989898",
"|.	c #9B9B9B",
"1.	c #A2A2A2",
"2.	c #B5B5B5",
"3.	c #D7D7D7",
"4.	c #F5F5F5",
"5.	c #EAEAEA",
"6.	c #C9C9C9",
"7.	c #B2B2B2",
"8.	c #A8A8A8",
"9.	c #999999",
"0.	c #969696",
"a.	c #9E9E9E",
"b.	c #DDDDDD",
"c.	c #FCFDFF",
"d.	c #FAFBFF",
"e.	c #EEEEF4",
"f.	c #C8C8CF",
"g.	c #BDBDC4",
"h.	c #B1B2B9",
"i.	c #A4A4AD",
"j.	c #96979F",
"k.	c #898992",
"l.	c #7B7B86",
"m.	c #6E6F7A",
"n.	c #464651",
"o.	c #20202B",
"p.	c #242430",
"q.	c #2B2B37",
"r.	c #333440",
"s.	c #41414D",
"t.	c #585863",
"u.	c #A1A2AB",
"v.	c #F0F0FA",
"w.	c #F3F4FF",
"x.	c #F4F4FF",
"y.	c #F5F5FF",
"z.	c #F6F6FF",
"A.	c #F9FAFF",
"B.	c #C7C7C7",
"C.	c #A3A3A3",
"D.	c #9F9F9F",
"E.	c #D2D2D2",
"F.	c #B1B1B1",
"G.	c #ACACAC",
"H.	c #959595",
"I.	c #949494",
"J.	c #939393",
"K.	c #9C9C9C",
"L.	c #B3B3B3",
"M.	c #8F8F8F",
"N.	c #898989",
"O.	c #838383",
"P.	c #7E7E7E",
"Q.	c #7A7A7A",
"R.	c #777777",
"S.	c #747474",
"T.	c #737373",
"U.	c #717171",
"V.	c #727272",
"W.	c #757575",
"X.	c #7D7D7D",
"Y.	c #ABABAB",
"Z.	c #8E8E8E",
"`.	c #818181",
" +	c #797979",
".+	c #767676",
"++	c #707070",
"@+	c #828282",
"#+	c #FDFEFF",
"$+	c #E2E2EA",
"%+	c #C4C4CD",
"&+	c #B9B9C3",
"*+	c #AEAEB8",
"=+	c #A0A1AC",
"-+	c #92939F",
";+	c #858592",
">+	c #787886",
",+	c #656674",
"'+	c #2A2A39",
")+	c #252534",
"!+	c #282938",
"~+	c #2E2E3E",
"{+	c #363646",
"]+	c #424352",
"^+	c #595A68",
"/+	c #84848F",
"(+	c #D4D5E1",
"_+	c #F0F1FF",
":+	c #F1F2FF",
"<+	c #F2F3FF",
"[+	c #F3F3FF",
"}+	c #D6D6D6",
"|+	c #B0B0B0",
"1+	c #909090",
"2+	c #848484",
"3+	c #CECECE",
"4+	c #CCCCCC",
"5+	c #929292",
"6+	c #8D8D8D",
"7+	c #878787",
"8+	c #787878",
"9+	c #6E6E6E",
"0+	c #6D6D6D",
"a+	c #6F6F6F",
"b+	c #7F7F7F",
"c+	c #8C8C8C",
"d+	c #7C7C7C",
"e+	c #666666",
"f+	c #585858",
"g+	c #454545",
"h+	c #363636",
"i+	c #2B2B2B",
"j+	c #212121",
"k+	c #171717",
"l+	c #131313",
"m+	c #151515",
"n+	c #1E1E1E",
"o+	c #353535",
"p+	c #656565",
"q+	c #DCDCDC",
"r+	c #A5A5A5",
"s+	c #858585",
"t+	c #4B4B4B",
"u+	c #262626",
"v+	c #1C1C1C",
"w+	c #161616",
"x+	c #121212",
"y+	c #111111",
"z+	c #1B1B1B",
"A+	c #292929",
"B+	c #4A4A4A",
"C+	c #686868",
"D+	c #F2F2FD",
"E+	c #D5D6E1",
"F+	c #C0C0CD",
"G+	c #B5B5C3",
"H+	c #AAAAB8",
"I+	c #9C9DAB",
"J+	c #8F8F9F",
"K+	c #818292",
"L+	c #757587",
"M+	c #505063",
"N+	c #29293D",
"O+	c #2A2B3E",
"P+	c #2D2E41",
"Q+	c #323347",
"R+	c #39394D",
"S+	c #454659",
"T+	c #5D5D6F",
"U+	c #878794",
"V+	c #A8A8B7",
"W+	c #EBECFE",
"X+	c #ECEDFF",
"Y+	c #EDEEFF",
"Z+	c #EEEFFF",
"`+	c #EFF0FF",
" @	c #A6A8A9",
".@	c #9C9E9F",
"+@	c #939596",
"@@	c #898B8B",
"#@	c #808080",
"$@	c #5C5C5C",
"%@	c #464646",
"&@	c #343434",
"*@	c #282828",
"=@	c #1A1A1A",
"-@	c #141414",
";@	c #2A2A2A",
">@	c #393939",
",@	c #636363",
"'@	c #AAAAAA",
")@	c #A1A1A1",
"!@	c #6A6A6A",
"~@	c #626262",
"{@	c #505050",
"]@	c #3D3D3D",
"^@	c #303030",
"/@	c #272727",
"(@	c #0F0F0F",
"_@	c #0E0E0E",
":@	c #101010",
"<@	c #232323",
"[@	c #575757",
"}@	c #646464",
"|@	c #525252",
"1@	c #313131",
"2@	c #080808",
"3@	c #020202",
"4@	c #000000",
"5@	c #0C0C0C",
"6@	c #5E5E5E",
"7@	c #919191",
"8@	c #5A5A5A",
"9@	c #010101",
"0@	c #050505",
"a@	c #494949",
"b@	c #FCFCFE",
"c@	c #FBFBFE",
"d@	c #F2F2FF",
"e@	c #ECEDFA",
"f@	c #CDCDDC",
"g@	c #BCBDCD",
"h@	c #B1B2C3",
"i@	c #A6A7B9",
"j@	c #9999AC",
"k@	c #8C8DA1",
"l@	c #7E7F94",
"m@	c #727389",
"n@	c #404057",
"o@	c #2E2F47",
"p@	c #2F3048",
"q@	c #31324B",
"r@	c #35364F",
"s@	c #3C3C55",
"t@	c #474860",
"u@	c #616277",
"v@	c #8B8C9C",
"w@	c #8B8C9E",
"x@	c #DEDEF4",
"y@	c #E8E8FE",
"z@	c #E8E9FE",
"A@	c #E9EAFF",
"B@	c #EBEBFF",
"C@	c #ECECFF",
"D@	c #EFEFFF",
"E@	c #F4F5FF",
"F@	c #F6F6F7",
"G@	c #D8D8D8",
"H@	c #A0A3A6",
"I@	c #9AA3AA",
"J@	c #929DA5",
"K@	c #89949E",
"L@	c #788086",
"M@	c #6C6C6D",
"N@	c #606060",
"O@	c #444444",
"P@	c #202020",
"Q@	c #0B0B0B",
"R@	c #333333",
"S@	c #EEEEEE",
"T@	c #404040",
"U@	c #222222",
"V@	c #040404",
"W@	c #030303",
"X@	c #3C3C3C",
"Y@	c #E3E3E3",
"Z@	c #ADADAD",
"`@	c #484848",
" #	c #1D1D1D",
".#	c #060606",
"+#	c #0A0A0A",
"@#	c #3A3A3A",
"##	c #868686",
"$#	c #696969",
"%#	c #181818",
"&#	c #FAFAFE",
"*#	c #F8F9FE",
"=#	c #F7F7FE",
"-#	c #E4E5F6",
";#	c #C5C6D9",
">#	c #B8B9CD",
",#	c #ADAEC3",
"'#	c #A2A3BA",
")#	c #9596AD",
"!#	c #8989A2",
"~#	c #7C7D96",
"{#	c #6C6D87",
"]#	c #383955",
"^#	c #333451",
"/#	c #343552",
"(#	c #363754",
"_#	c #393A58",
":#	c #3F405D",
"<#	c #4A4B68",
"[#	c #65667F",
"}#	c #8E8FA2",
"|#	c #7C7D94",
"1#	c #BEBFDA",
"2#	c #E3E4FE",
"3#	c #E4E5FE",
"4#	c #E5E6FE",
"5#	c #E6E7FE",
"6#	c #EEEEFF",
"7#	c #F7F8FF",
"8#	c #F5F6F9",
"9#	c #D7D7D9",
"0#	c #9FA0A1",
"a#	c #9DA4AA",
"b#	c #A8B6C1",
"c#	c #B2C2CE",
"d#	c #A7B9C6",
"e#	c #7D8B97",
"f#	c #4A4F53",
"g#	c #090909",
"h#	c #E9E9E9",
"i#	c #5B5B5B",
"j#	c #2C2C2C",
"k#	c #2D2D2D",
"l#	c #3E3E3E",
"m#	c #DEDEDE",
"n#	c #7B7B7B",
"o#	c #595959",
"p#	c #191919",
"q#	c #1F1F1F",
"r#	c #6B6B6B",
"s#	c #3B3B3B",
"t#	c #5F5F5F",
"u#	c #FAFBFE",
"v#	c #F9F9FE",
"w#	c #F6F6FE",
"x#	c #F4F4FE",
"y#	c #F0F0FF",
"z#	c #EAEAFF",
"A#	c #DADBF1",
"B#	c #BFC0D8",
"C#	c #B4B5CE",
"D#	c #A9AAC4",
"E#	c #9E9FBA",
"F#	c #9293B0",
"G#	c #8586A4",
"H#	c #7A7B9A",
"I#	c #5F6080",
"J#	c #38395A",
"K#	c #38395C",
"L#	c #393A5D",
"M#	c #3A3B5E",
"N#	c #3D3E61",
"O#	c #414266",
"P#	c #4E4F71",
"Q#	c #6A6B88",
"R#	c #8F90A6",
"S#	c #787995",
"T#	c #A3A4C4",
"U#	c #DDDEFE",
"V#	c #DEDFFE",
"W#	c #E0E1FE",
"X#	c #E1E2FE",
"Y#	c #E8E9FF",
"Z#	c #EBECFF",
"`#	c #F5F5FE",
" $	c #DDDDE3",
".$	c #C6C6CB",
"+$	c #BDBDBF",
"@$	c #B2B2B4",
"#$	c #A4A9AC",
"$$	c #ACB6BE",
"%$	c #C4D0D9",
"&$	c #E2E8ED",
"*$	c #CED9E2",
"=$	c #668196",
"-$	c #172734",
";$	c #090B0D",
">$	c #0D0D0D",
",$	c #E5E5E5",
"'$	c #8B8B8B",
")$	c #3F3F3F",
"!$	c #070707",
"~$	c #4C4C4C",
"{$	c #242424",
"]$	c #A6A6A6",
"^$	c #EBEBEB",
"/$	c #F8F8FE",
"($	c #F2F3FE",
"_$	c #F1F1FE",
":$	c #EFEFFE",
"<$	c #EAEBFF",
"[$	c #D1D2EB",
"}$	c #BABBD7",
"|$	c #B0B1CE",
"1$	c #A5A6C5",
"2$	c #9B9CBC",
"3$	c #8E90B1",
"4$	c #8284A7",
"5$	c #78799E",
"6$	c #56587D",
"7$	c #3C3D65",
"8$	c #3C3E66",
"9$	c #3D3E67",
"0$	c #3E3F68",
"a$	c #40426B",
"b$	c #454670",
"c$	c #505279",
"d$	c #6F7192",
"e$	c #8F90AB",
"f$	c #747597",
"g$	c #8688AE",
"h$	c #D7D8FE",
"i$	c #D9DAFE",
"j$	c #DADBFE",
"k$	c #DCDDFE",
"l$	c #DFE0FE",
"m$	c #E6E6FE",
"n$	c #EAEAF4",
"o$	c #CBCBD3",
"p$	c #BFBFC6",
"q$	c #B5B5BA",
"r$	c #ACACAF",
"s$	c #A8A8AA",
"t$	c #A7A7A8",
"u$	c #A8ABAE",
"v$	c #AFB7BE",
"w$	c #C2CDD6",
"x$	c #CBD7DF",
"y$	c #91AABD",
"z$	c #3E5B73",
"A$	c #202D39",
"B$	c #1B1C1D",
"C$	c #565656",
"D$	c #D5D5D5",
"E$	c #E2E2E2",
"F$	c #2F2F2F",
"G$	c #F2F2FE",
"H$	c #F0F0FE",
"I$	c #EDEEFE",
"J$	c #E9E9FE",
"K$	c #E0E1FC",
"L$	c #C8C9E7",
"M$	c #B6B7D8",
"N$	c #ABACCF",
"O$	c #A1A2C7",
"P$	c #9798BE",
"Q$	c #8B8CB5",
"R$	c #8081AA",
"S$	c #7678A2",
"T$	c #4E4F7C",
"U$	c #3F4170",
"V$	c #404271",
"W$	c #414272",
"X$	c #414373",
"Y$	c #434575",
"Z$	c #484979",
"`$	c #535583",
" %	c #74769B",
".%	c #8D8EAE",
"+%	c #70729B",
"@%	c #6D6F9A",
"#%	c #CCCEF9",
"$%	c #D2D4FE",
"%%	c #D4D6FE",
"&%	c #D6D7FE",
"*%	c #D8D9FE",
"=%	c #EBEBFE",
"-%	c #D9D9E6",
";%	c #C3C3CE",
">%	c #B9BAC3",
",%	c #AFAFB6",
"'%	c #AAABB0",
")%	c #ABABAE",
"!%	c #AAAAAC",
"~%	c #A8A9AA",
"{%	c #ABB0B5",
"]%	c #9CA9B4",
"^%	c #59748A",
"/%	c #4D6A81",
"(%	c #324455",
"_%	c #282D31",
":%	c #535353",
"<%	c #2E2E2E",
"[%	c #323232",
"}%	c #DCDCDD",
"|%	c #FBFCFE",
"1%	c #F3F4FE",
"2%	c #F1F2FE",
"3%	c #ECEDFE",
"4%	c #E9EAFE",
"5%	c #E7E8FE",
"6%	c #E2E3FE",
"7%	c #D9DAFB",
"8%	c #C0C1E4",
"9%	c #B1B2D8",
"0%	c #A7A8D0",
"a%	c #9D9EC8",
"b%	c #9394C0",
"c%	c #888AB8",
"d%	c #7D7FAE",
"e%	c #7475A6",
"f%	c #454779",
"g%	c #44467A",
"h%	c #45477B",
"i%	c #46487D",
"j%	c #47497D",
"k%	c #494B7F",
"l%	c #4D4F82",
"m%	c #585A8B",
"n%	c #7B7DA5",
"o%	c #8C8DB1",
"p%	c #6E709F",
"q%	c #696B9D",
"r%	c #BABCEE",
"s%	c #CCCEFE",
"t%	c #CED0FE",
"u%	c #D0D2FE",
"v%	c #D2D3FE",
"w%	c #D6D8FE",
"x%	c #E6E7FF",
"y%	c #E9E9FF",
"z%	c #E9EAFD",
"A%	c #CDCEDE",
"B%	c #BEBFCD",
"C%	c #B5B5C1",
"D%	c #ACACB6",
"E%	c #ABABB3",
"F%	c #ABACB1",
"G%	c #ABABAF",
"H%	c #9DA0A3",
"I%	c #3F4C58",
"J%	c #293947",
"K%	c #303E4C",
"L%	c #303A42",
"M%	c #333334",
"N%	c #414141",
"O%	c #5D5D5D",
"P%	c #474747",
"Q%	c #434343",
"R%	c #4E4E4E",
"S%	c #252525",
"T%	c #383838",
"U%	c #545454",
"V%	c #6C6C6C",
"W%	c #4D4D4D",
"X%	c #2D2D2F",
"Y%	c #7B7B7F",
"Z%	c #F5F5FD",
"`%	c #F0F1FE",
" &	c #EEEFFE",
".&	c #D1D3F9",
"+&	c #B8B9E2",
"@&	c #ACAED9",
"#&	c #A2A4D2",
"$&	c #989ACB",
"%&	c #9091C4",
"&&	c #888ABE",
"*&	c #7E80B4",
"=&	c #7173A7",
"-&	c #494B80",
";&	c #4D4F84",
">&	c #4F5187",
",&	c #505288",
"'&	c #525389",
")&	c #53558A",
"!&	c #56588D",
"~&	c #626396",
"{&	c #8687AF",
"]&	c #8D8EB5",
"^&	c #7072A3",
"/&	c #6D6EA3",
"(&	c #AAABE0",
"_&	c #C8CAFE",
":&	c #C9CAFE",
"<&	c #C9CBFE",
"[&	c #CBCDFE",
"}&	c #DBDCFE",
"|&	c #E5E5FE",
"1&	c #E4E4FB",
"2&	c #BBBBCC",
"3&	c #B1B1C0",
"4&	c #AAAAB6",
"5&	c #ABABB5",
"6&	c #ACACB3",
"7&	c #B2B6BD",
"8&	c #B3B7BE",
"9&	c #616164",
"0&	c #1F2022",
"a&	c #252627",
"b&	c #2D2E2F",
"c&	c #363737",
"d&	c #4F4F4F",
"e&	c #010102",
"f&	c #0A0A0B",
"g&	c #17171B",
"h&	c #29292E",
"i&	c #4E4E55",
"j&	c #B0B0BA",
"k&	c #EDEDFA",
"l&	c #EDEDFF",
"m&	c #C8CAF6",
"n&	c #B1B2E1",
"o&	c #A7A9DB",
"p&	c #9EA0D4",
"q&	c #9698CD",
"r&	c #9193C7",
"s&	c #8D8FC5",
"t&	c #8587BC",
"u&	c #7374AA",
"v&	c #56578D",
"w&	c #595B91",
"x&	c #5C5E94",
"y&	c #5E5F96",
"z&	c #5F6197",
"A&	c #616399",
"B&	c #64659B",
"C&	c #6E70A3",
"D&	c #9192B9",
"E&	c #8F90B9",
"F&	c #7778AB",
"G&	c #7475AB",
"H&	c #9A9BD1",
"I&	c #C7C8FF",
"J&	c #C7C9FF",
"K&	c #C8CAFF",
"L&	c #CBCCFE",
"M&	c #DBDDFE",
"N&	c #DFE0FA",
"O&	c #C1C2D9",
"P&	c #B8B8CD",
"Q&	c #AEAFC0",
"R&	c #A9A9B8",
"S&	c #AAAAB5",
"T&	c #ABACB4",
"U&	c #9B9CA2",
"V&	c #2F2F33",
"W&	c #262628",
"X&	c #424242",
"Y&	c #000001",
"Z&	c #040406",
"`&	c #0C0C0F",
" *	c #16161B",
".*	c #23232B",
"+*	c #33333D",
"@*	c #4A4A56",
"#*	c #9797A6",
"$*	c #E8E9FB",
"%*	c #E7E7FE",
"&*	c #E4E4FE",
"**	c #CFD1FE",
"=*	c #C0C2F3",
"-*	c #ACAEE1",
";*	c #A5A7DC",
">*	c #9FA1D6",
",*	c #999AD0",
"'*	c #9496CC",
")*	c #9495CC",
"!*	c #8E90C6",
"~*	c #787AAF",
"{*	c #66689D",
"]*	c #6A6CA1",
"^*	c #6F71A7",
"/*	c #7274AA",
"(*	c #7476AC",
"_*	c #7779AD",
":*	c #797BAF",
"<*	c #8283B4",
"[*	c #9FA0C6",
"}*	c #9597C1",
"|*	c #8183B6",
"1*	c #7F80B6",
"2*	c #9193C9",
"3*	c #C5C7FE",
"4*	c #C6C8FF",
"5*	c #C9CBFF",
"6*	c #D5D6FE",
"7*	c #DDDEFC",
"8*	c #C1C2DD",
"9*	c #B6B6CE",
"0*	c #ACACC1",
"a*	c #A7A8BA",
"b*	c #A8A9B8",
"c*	c #A9A9B6",
"d*	c #AAAAB4",
"e*	c #7D7D85",
"f*	c #2A2A2F",
"g*	c #2E2E31",
"h*	c #333335",
"i*	c #3A3A3B",
"j*	c #373737",
"k*	c #515151",
"l*	c #1D1D1F",
"m*	c #0E0E11",
"n*	c #0F0F14",
"o*	c #17181F",
"p*	c #22232C",
"q*	c #2F2F3B",
"r*	c #3E3F4D",
"s*	c #525365",
"t*	c #9999AE",
"u*	c #E2E3FA",
"v*	c #D4D5FE",
"w*	c #D0D1FE",
"x*	c #BABCF0",
"y*	c #ACADE3",
"z*	c #A6A8DE",
"A*	c #A1A3D9",
"B*	c #9C9ED4",
"C*	c #9B9CD2",
"D*	c #9D9FD5",
"E*	c #9C9DD2",
"F*	c #8486BA",
"G*	c #8384B7",
"H*	c #8B8CBE",
"I*	c #9092C3",
"J*	c #9294C5",
"K*	c #9193C4",
"L*	c #9293C4",
"M*	c #9A9CC9",
"N*	c #B1B3D6",
"O*	c #A6A8D1",
"P*	c #9A9CCC",
"Q*	c #9698CA",
"R*	c #9C9ED1",
"S*	c #C5C7FC",
"T*	c #CBCCFF",
"U*	c #C7C8E8",
"V*	c #B5B6D2",
"W*	c #ABACC4",
"X*	c #A6A7BC",
"Y*	c #5E5E68",
"Z*	c #2F3037",
"`*	c #343439",
" =	c #3B3B3E",
".=	c #424243",
"+=	c #D1D2D3",
"@=	c #AAAAAD",
"#=	c #707074",
"$=	c #3A3B41",
"%=	c #20212A",
"&=	c #2F2F3E",
"*=	c #3B3C4D",
"==	c #494A5F",
"-=	c #5C5D75",
";=	c #B1B2CD",
">=	c #DEDFFD",
",=	c #D3D4FE",
"'=	c #CACCFE",
")=	c #C7C9FE",
"!=	c #B6B7ED",
"~=	c #ADAEE4",
"{=	c #A9ABE1",
"]=	c #A6A7DD",
"^=	c #A4A6DA",
"/=	c #A7A9DC",
"(=	c #AEB0E1",
"_=	c #ACADDE",
":=	c #8587B9",
"<=	c #7B7DB0",
"[=	c #7072A7",
"}=	c #6A6CA2",
"|=	c #67699E",
"1=	c #696BA0",
"2=	c #6F71A6",
"3=	c #7375A7",
"4=	c #9193BB",
"5=	c #8688B7",
"6=	c #8486B9",
"7=	c #8F91C4",
"8=	c #9EA0D1",
"9=	c #C6C8FA",
"0=	c #CBCDFF",
"a=	c #CFD1FF",
"b=	c #CFD0FF",
"c=	c #CDCFFE",
"d=	c #D1D3FE",
"e=	c #D5D7FE",
"f=	c #D0D1F4",
"g=	c #B8BADA",
"h=	c #AEB0CC",
"i=	c #A6A6BF",
"j=	c #A7A8B9",
"k=	c #51515D",
"l=	c #34343E",
"m=	c #393940",
"n=	c #404045",
"o=	c #48484B",
"p=	c #B0B0B2",
"q=	c #E7E7E9",
"r=	c #ADAEB4",
"s=	c #999AA2",
"t=	c #777883",
"u=	c #414250",
"v=	c #303142",
"w=	c #3A3B50",
"x=	c #46475F",
"y=	c #545571",
"z=	c #6D6E8E",
"A=	c #C8C9EC",
"B=	c #C6C7FD",
"C=	c #B4B5EB",
"D=	c #AFB1E6",
"E=	c #AEB0E5",
"F=	c #B0B2E5",
"G=	c #B2B4E5",
"H=	c #A6A8DC",
"I=	c #9799CE",
"J=	c #67699F",
"K=	c #5B5D92",
"L=	c #55578D",
"M=	c #515287",
"N=	c #4E5085",
"O=	c #4C4E83",
"P=	c #57598E",
"Q=	c #636599",
"R=	c #5B5D8E",
"S=	c #797AA4",
"T=	c #67699B",
"U=	c #64679B",
"V=	c #6E6FA5",
"W=	c #7A7CB2",
"X=	c #B6B8EE",
"Y=	c #CACDFF",
"Z=	c #CCCEFF",
"`=	c #CED0FF",
" -	c #D7D8FF",
".-	c #D4D6FF",
"+-	c #CACBFF",
"@-	c #C7CAFF",
"#-	c #C8CDFF",
"$-	c #C9CEFE",
"%-	c #CCD1FF",
"&-	c #D1D5FE",
"*-	c #D5D9FD",
"=-	c #CDD3ED",
"--	c #B9BFDB",
";-	c #A6A7C3",
">-	c #A7A7B9",
",-	c #555564",
"'-	c #373743",
")-	c #3D3D46",
"!-	c #44444B",
"~-	c #4C4C51",
"{-	c #D0D0D3",
"]-	c #F1F1F5",
"^-	c #C6C6CC",
"/-	c #B6B7BF",
"(-	c #A9A9B4",
"_-	c #A3A3B1",
":-	c #9393A4",
"<-	c #55566A",
"[-	c #3C3D54",
"}-	c #464762",
"|-	c #525372",
"1-	c #5E6083",
"2-	c #9293BB",
"3-	c #D1D3FF",
"4-	c #C7C8FE",
"5-	c #C4C6FC",
"6-	c #B5B7EC",
"7-	c #B5B6EA",
"8-	c #B9BBEB",
"9-	c #B2B4E6",
"0-	c #9B9DD2",
"a-	c #9597CD",
"b-	c #8688BD",
"c-	c #46487C",
"d-	c #46477C",
"e-	c #45477C",
"f-	c #585A8E",
"g-	c #696A9E",
"h-	c #555787",
"i-	c #6D6F99",
"j-	c #5A5C8D",
"k-	c #606296",
"l-	c #6A6CA0",
"m-	c #9FA1D7",
"n-	c #D2D3FF",
"o-	c #D0D2FF",
"p-	c #C8CCFF",
"q-	c #CBD2FF",
"r-	c #CDD4FF",
"s-	c #CED4FE",
"t-	c #D0D6FE",
"u-	c #D4DAFF",
"v-	c #D6DDF8",
"w-	c #BBC1E1",
"x-	c #A9AACA",
"y-	c #A5A6C2",
"z-	c #A6A7BF",
"A-	c #A7A7BC",
"B-	c #717283",
"C-	c #393947",
"D-	c #3F3F4A",
"E-	c #47474F",
"F-	c #4F4F56",
"G-	c #D8D8DD",
"H-	c #C9C9D0",
"I-	c #BABAC4",
"J-	c #AEAFBB",
"K-	c #ABACBB",
"L-	c #A7A8BB",
"M-	c #9A9BB1",
"N-	c #53546F",
"O-	c #474866",
"P-	c #525375",
"Q-	c #5C5E85",
"R-	c #70719D",
"S-	c #C1C3F5",
"T-	c #C4C6FA",
"U-	c #BCBEF0",
"V-	c #BBBDED",
"W-	c #B0B1E5",
"X-	c #A0A1D7",
"Y-	c #9092C7",
"Z-	c #8E90C5",
"`-	c #7779AE",
" ;	c #47497C",
".;	c #48497D",
"+;	c #4A4C80",
"@;	c #4B4D81",
"#;	c #65679A",
"$;	c #7678AB",
"%;	c #5B5D8D",
"&;	c #6C6D99",
"*;	c #595B8D",
"=;	c #5D5F93",
"-;	c #64669A",
";;	c #8F91C5",
">;	c #CACCFF",
",;	c #D3D4FF",
"';	c #CDCEFF",
");	c #CCCDFF",
"!;	c #CAD0FF",
"~;	c #CFD6FF",
"{;	c #D4DBFF",
"];	c #D5DCFF",
"^;	c #D5DCFE",
"/;	c #D2D8FF",
"(;	c #D0D5FD",
"_;	c #BABDE3",
":;	c #AEAFD2",
"<;	c #A6A7C6",
"[;	c #A5A6C1",
"};	c #A6A6BE",
"|;	c #9394A8",
"1;	c #3D3E4F",
"2;	c #3F404D",
"3;	c #484852",
"4;	c #515159",
"5;	c #D5D5DB",
"6;	c #EFEFF5",
"7;	c #C7C8D0",
"8;	c #BABBC6",
"9;	c #AFAFC1",
"0;	c #ABACC2",
"a;	c #A8A9C3",
"b;	c #8687A5",
"c;	c #4C4D70",
"d;	c #52537A",
"e;	c #5C5D89",
"f;	c #656797",
"g;	c #A8A9DD",
"h;	c #C8C9FA",
"i;	c #BBBCEE",
"j;	c #AEB0E4",
"k;	c #A2A4D9",
"l;	c #8E90C4",
"m;	c #8D8FC3",
"n;	c #6C6EA2",
"o;	c #4D4F83",
"p;	c #4F5184",
"q;	c #505285",
"r;	c #525487",
"s;	c #545689",
"t;	c #55578A",
"u;	c #7476A9",
"v;	c #8586B9",
"w;	c #656696",
"x;	c #6D6F9B",
"y;	c #5E6092",
"z;	c #5F6093",
"A;	c #626498",
"B;	c #686A9D",
"C;	c #8687BB",
"D;	c #D6D7FF",
"E;	c #CDD2FF",
"F;	c #DDE2FF",
"G;	c #E0E5FF",
"H;	c #DBE1FF",
"I;	c #D3D9FE",
"J;	c #C8CCF3",
"K;	c #B8BADD",
"L;	c #B0B1D0",
"M;	c #A3A4C2",
"N;	c #A3A4BF",
"O;	c #A2A2B9",
"P;	c #5C5D70",
"Q;	c #3E3F4E",
"R;	c #474754",
"S;	c #50505A",
"T;	c #BBBBC2",
"U;	c #555555",
"V;	c #E7E7ED",
"W;	c #C8C8D1",
"X;	c #BABBC7",
"Y;	c #B2B3C4",
"Z;	c #B0B1C5",
"`;	c #ADAEC7",
" >	c #AAABC8",
".>	c #A3A4C5",
"+>	c #57587E",
"@>	c #53557F",
"#>	c #5C5E8E",
"$>	c #66689B",
"%>	c #C0C2F5",
"&>	c #A6A7DC",
"*>	c #9D9FD3",
"=>	c #9294C8",
"->	c #9193C6",
";>	c #57598C",
">>	c #595A8D",
",>	c #5A5C8E",
"'>	c #5C5E90",
")>	c #616295",
"!>	c #8485B7",
"~>	c #8E90C2",
"{>	c #7071A0",
"]>	c #70729F",
"^>	c #656798",
"/>	c #66689A",
"(>	c #696B9E",
"_>	c #8081B5",
":>	c #D3D5FF",
"<>	c #C9CAFF",
"[>	c #CBD1FF",
"}>	c #D3D9FF",
"|>	c #DAE0FF",
"1>	c #E2E7FF",
"2>	c #E9ECFF",
"3>	c #E0E4FF",
"4>	c #D6DCFF",
"5>	c #D2D9FE",
"6>	c #C6C8EA",
"7>	c #B3B4D7",
"8>	c #A3A4C6",
"9>	c #9E9FBD",
"0>	c #A1A1BB",
"a>	c #83849A",
"b>	c #3F3F51",
"c>	c #434452",
"d>	c #4E4E59",
"e>	c #8B8C95",
"f>	c #F6F6FD",
"g>	c #F7F8FC",
"h>	c #E0E0E6",
"i>	c #CBCBD5",
"j>	c #BDBDCB",
"k>	c #B6B6C8",
"l>	c #B2B3C9",
"m>	c #AEAFCA",
"n>	c #ABACCC",
"o>	c #A8A9CE",
"p>	c #60628C",
"q>	c #555685",
"r>	c #5E6093",
"s>	c #6A6BA0",
"t>	c #9698CE",
"u>	c #B8BAEF",
"v>	c #AAACE1",
"w>	c #A2A4D8",
"x>	c #9A9CD0",
"y>	c #9294C7",
"z>	c #9395C8",
"A>	c #9597CA",
"B>	c #6C6DA0",
"C>	c #616294",
"D>	c #636596",
"E>	c #646696",
"F>	c #686A9A",
"G>	c #6C6E9E",
"H>	c #9294C4",
"I>	c #9698C8",
"J>	c #7C7DAB",
"K>	c #7476A2",
"L>	c #6D6FA0",
"M>	c #7172A4",
"N>	c #7476A8",
"O>	c #7D7FB1",
"P>	c #C0C1F5",
"Q>	c #D7DDFF",
"R>	c #E1E6FF",
"S>	c #DCE1FF",
"T>	c #D6DDFF",
"U>	c #D8DDFE",
"V>	c #D6DAFE",
"W>	c #C9CBF6",
"X>	c #B3B4DE",
"Y>	c #A6A8CD",
"Z>	c #9C9DBE",
"`>	c #9A9BB7",
" ,	c #9A9BB3",
".,	c #535368",
"+,	c #3F4050",
"@,	c #484956",
"#,	c #61616B",
"$,	c #E3E3EB",
"%,	c #E7E8EE",
"&,	c #D8D8E0",
"*,	c #D4D4DD",
"=,	c #C8C8D6",
"-,	c #BEBFD1",
";,	c #B7B7CE",
">,	c #B1B2CE",
",,	c #ACADCF",
"',	c #A8A9D1",
"),	c #636492",
"!,	c #58598C",
"~,	c #626499",
"{,	c #999BD1",
"],	c #C8C9FF",
"^,	c #C5C7FD",
"/,	c #B4B6EA",
"(,	c #A8AADE",
"_,	c #A1A3D7",
":,	c #9B9DD0",
"<,	c #9596CA",
"[,	c #9496C8",
"},	c #9799CB",
"|,	c #989ACC",
"1,	c #6E70A0",
"2,	c #6A6C9D",
"3,	c #6D6F9F",
"4,	c #6F71A0",
"5,	c #7274A2",
"6,	c #797BA9",
"7,	c #9D9ECC",
"8,	c #8A8CB7",
"9,	c #797AA7",
"0,	c #7476A4",
"a,	c #7677A6",
"b,	c #787AA9",
"c,	c #7B7DAD",
"d,	c #7F81B1",
"e,	c #B8BAEA",
"f,	c #CDCFFF",
"g,	c #D1D7FF",
"h,	c #D9DFFF",
"i,	c #DCE1FE",
"j,	c #D6DAFF",
"k,	c #CCCFFF",
"l,	c #CACBFE",
"m,	c #B9BBE9",
"n,	c #ABACD6",
"o,	c #A0A2C6",
"p,	c #9697B6",
"q,	c #9596B1",
"r,	c #787990",
"s,	c #3D3E50",
"t,	c #4D4E5A",
"u,	c #9A9AA3",
"v,	c #F7F8FE",
"w,	c #EAEAF1",
"x,	c #CECED7",
"y,	c #C7C7D2",
"z,	c #C5C6D3",
"A,	c #CCCDDA",
"B,	c #CDCEDD",
"C,	c #C3C4D8",
"D,	c #B8B8D4",
"E,	c #AFB0D3",
"F,	c #A5A7D1",
"G,	c #5F6091",
"H,	c #5C5E92",
"I,	c #696AA0",
"J,	c #7677AD",
"K,	c #C4C6FB",
"L,	c #B1B3E7",
"M,	c #A8AADD",
"N,	c #A3A5D7",
"O,	c #9EA0D2",
"P,	c #9899CB",
"Q,	c #9B9DCE",
"R,	c #7173A2",
"S,	c #7475A4",
"T,	c #7779A6",
"U,	c #787AA7",
"V,	c #797BA8",
"W,	c #7B7DA9",
"X,	c #8788B5",
"Y,	c #A6A7D2",
"Z,	c #A3A5D0",
"`,	c #9799C2",
" '	c #7F80AB",
".'	c #7C7EAB",
"+'	c #7E7FAC",
"@'	c #8081AF",
"#'	c #8183B1",
"$'	c #8587B5",
"%'	c #B5B6E3",
"&'	c #C8CBFE",
"*'	c #D8DDFF",
"='	c #DFE3FE",
"-'	c #D5DBFE",
";'	c #CBCFFF",
">'	c #C4C6F8",
",'	c #B0B2DF",
"''	c #A6A8CF",
")'	c #9A9BBE",
"!'	c #9091AE",
"~'	c #8D8EA7",
"{'	c #4B4C61",
"]'	c #393A4B",
"^'	c #434451",
"/'	c #595A64",
"('	c #D1D1D8",
"_'	c #EDEEF3",
":'	c #CECFD6",
"<'	c #C2C2CD",
"['	c #BABBC8",
"}'	c #B8B9CA",
"|'	c #BCBDD0",
"1'	c #C3C4D7",
"2'	c #C9CADE",
"3'	c #C7C8DF",
"4'	c #BABADB",
"5'	c #999AC3",
"6'	c #5F6191",
"7'	c #7D7FB5",
"8'	c #C2C4F8",
"9'	c #A7A9DA",
"0'	c #ABACD8",
"a'	c #9EA0CF",
"b'	c #9D9ECF",
"c'	c #9FA1D0",
"d'	c #9597C5",
"e'	c #7879A7",
"f'	c #7C7EAA",
"g'	c #8081AD",
"h'	c #8283AE",
"i'	c #8384AE",
"j'	c #8486B0",
"k'	c #9798C2",
"l'	c #ACADD6",
"m'	c #A8AAD3",
"n'	c #A3A5CC",
"o'	c #8687B0",
"p'	c #8586B0",
"q'	c #8587B2",
"r'	c #8788B4",
"s'	c #8889B6",
"t'	c #8C8DBA",
"u'	c #B4B5DF",
"v'	c #C9CCFE",
"w'	c #CCD0FE",
"x'	c #D2D6FF",
"y'	c #DADDFE",
"z'	c #BBBCED",
"A'	c #ABADD7",
"B'	c #9394B4",
"C'	c #8A8BA6",
"D'	c #717289",
"E'	c #36374A",
"F'	c #3A3B49",
"G'	c #454651",
"H'	c #71717A",
"I'	c #EFF0F6",
"J'	c #FAFAFC",
"K'	c #E6E7EA",
"L'	c #CCCCD2",
"M'	c #C1C1CA",
"N'	c #B8B8C5",
"O'	c #B3B4C3",
"P'	c #B3B3C7",
"Q'	c #B3B3CB",
"R'	c #B3B4CF",
"S'	c #B7B8D4",
"T'	c #BDBEDC",
"U'	c #C1C1DF",
"V'	c #9193B7",
"W'	c #7375A1",
"X'	c #7072A4",
"Y'	c #797AAF",
"Z'	c #8A8CC1",
"`'	c #C2C4F6",
" )	c #BFC1F5",
".)	c #AFB1E4",
"+)	c #A9ABDE",
"@)	c #AEAFDA",
"#)	c #B1B3D9",
"$)	c #A5A7D3",
"%)	c #A4A6D3",
"&)	c #9496C2",
"*)	c #8687B1",
"=)	c #8A8BB4",
"-)	c #8C8DB5",
";)	c #8D8FB6",
">)	c #8E90B7",
",)	c #A7A9CF",
"')	c #B4B5DB",
"))	c #B0B2D7",
"!)	c #ADAFD3",
"~)	c #8F91B7",
"{)	c #8E90B6",
"])	c #8E90B8",
"^)	c #8F91BA",
"/)	c #9697C0",
"()	c #AEAFD9",
"_)	c #C5C7FA",
":)	c #B2B4E2",
"<)	c #A7A9D1",
"[)	c #9C9DBF",
"})	c #8C8DAB",
"|)	c #82839C",
"1)	c #4F5064",
"2)	c #323344",
"3)	c #45454F",
"4)	c #898991",
"5)	c #F4F4F9",
"6)	c #888888",
"7)	c #DCDCDF",
"8)	c #C8C8CD",
"9)	c #C0C0C7",
"0)	c #B7B8C2",
"a)	c #B3B3C0",
"b)	c #B2B2C3",
"c)	c #B0B1C7",
"d)	c #AFB0CA",
"e)	c #AEAFCD",
"f)	c #ADAED0",
"g)	c #ACADD4",
"h)	c #8E90BA",
"i)	c #7A7CA5",
"j)	c #8A8BB3",
"k)	c #8C8DB9",
"l)	c #8A8CBD",
"m)	c #CCCDFE",
"n)	c #BCBEF2",
"o)	c #ABADDF",
"p)	c #A8A9DA",
"q)	c #A7A9D7",
"r)	c #B5B7DB",
"s)	c #B6B7DC",
"t)	c #ABACD7",
"u)	c #9596C0",
"v)	c #8889B2",
"w)	c #8F90B8",
"x)	c #9294BA",
"y)	c #9597BC",
"z)	c #9798BD",
"A)	c #989ABE",
"B)	c #BABCDF",
"C)	c #B6B8DB",
"D)	c #B5B7D9",
"E)	c #999BBF",
"F)	c #9698BC",
"G)	c #9598BD",
"H)	c #9799BF",
"I)	c #9D9FC4",
"J)	c #A0A2CB",
"K)	c #D1D2FF",
"L)	c #D0D1FF",
"M)	c #CECFFF",
"N)	c #BEC0F1",
"O)	c #ADAFDA",
"P)	c #A3A4C9",
"Q)	c #9596B6",
"R)	c #8586A1",
"S)	c #323345",
"T)	c #313240",
"U)	c #393944",
"V)	c #484850",
"W)	c #A2A3A8",
"X)	c #616161",
"Y)	c #D2D2D3",
"Z)	c #C4C4C7",
"`)	c #BCBCC2",
" !	c #B5B6BE",
".!	c #B2B3BE",
"+!	c #B1B2C1",
"@!	c #B0B1C4",
"#!	c #AFB0C7",
"$!	c #ADAECA",
"%!	c #ABACCD",
"&!	c #A8A9D0",
"*!	c #5D5F8F",
"=!	c #797AAA",
"-!	c #8F90BD",
";!	c #A4A6D0",
">!	c #C9CAF5",
",!	c #BABBEE",
"'!	c #B0B2E4",
")!	c #ADAEDF",
"!!	c #A9ABDB",
"~!	c #A7A8D6",
"{!	c #ACADD8",
"]!	c #BFC0E1",
"^!	c #BABBDE",
"/!	c #9698BF",
"(!	c #9799BD",
"_!	c #9B9DC0",
":!	c #9FA0C2",
"<!	c #A4A5C5",
"[!	c #A2A4C5",
"}!	c #C0C1E2",
"|!	c #C1C3E3",
"1!	c #BDBEDE",
"2!	c #BCBDDD",
"3!	c #A5A7C8",
"4!	c #9FA0C1",
"5!	c #9EA0C1",
"6!	c #9D9FC2",
"7!	c #9FA1C4",
"8!	c #9FA1C8",
"9!	c #D0D1FB",
"0!	c #C7C9FC",
"a!	c #B6B7E5",
"b!	c #AAABD3",
"c!	c #9E9FC1",
"d!	c #8E8FAC",
"e!	c #7F7F98",
"f!	c #4E4E62",
"g!	c #2C2D3D",
"h!	c #30313D",
"i!	c #393942",
"j!	c #4D4D53",
"k!	c #B7B7BB",
"l!	c #BFBFC0",
"m!	c #B3B3B9",
"n!	c #B2B2BB",
"o!	c #B2B2BE",
"p!	c #B1B2C2",
"q!	c #AEAFC8",
"r!	c #ACADCB",
"s!	c #A7A8CB",
"t!	c #8183AB",
"u!	c #575887",
"v!	c #5A5C90",
"w!	c #7576AB",
"x!	c #8789BD",
"y!	c #B8B9E8",
"z!	c #C7C9FD",
"A!	c #B8B9EB",
"B!	c #B1B3E4",
"C!	c #AEB0E0",
"D!	c #ACAEDC",
"E!	c #A9ABD8",
"F!	c #B5B6DC",
"G!	c #C6C8E4",
"H!	c #9FA1C2",
"I!	c #989ABD",
"J!	c #9FA1C3",
"K!	c #A5A6C7",
"L!	c #A8AAC9",
"M!	c #B6B7D1",
"N!	c #B0B2CE",
"O!	c #C9CAE8",
"P!	c #C8CAE6",
"Q!	c #C4C6E2",
"R!	c #C3C4E0",
"S!	c #B2B3D1",
"T!	c #A7A9C7",
"U!	c #A6A8C7",
"V!	c #A6A7C7",
"W!	c #A7A9C9",
"X!	c #A4A6C8",
"Y!	c #A3A5CA",
"Z!	c #CDCFF6",
"`!	c #D5D6FF",
" ~	c #D2D4FF",
".~	c #D5D7FF",
"+~	c #C3C5F5",
"@~	c #B0B1DC",
"#~	c #A6A7CB",
"$~	c #999AB9",
"%~	c #8889A3",
"&~	c #737489",
"*~	c #343546",
"=~	c #2A2A38",
"-~	c #2F2F39",
";~	c #38383F",
">~	c #4A4A4E",
",~	c #CBCCCE",
"'~	c #B4B4B6",
")~	c #B2B2B6",
"!~	c #B1B1B9",
"~~	c #B1B2BC",
"{~	c #B1B1BF",
"]~	c #B0B1C2",
"^~	c #AEAFC5",
"/~	c #ADAEC9",
"(~	c #9FA0C0",
"_~	c #6F7196",
":~	c #545680",
"<~	c #616397",
"[~	c #6D6FA4",
"}~	c #7C7DB3",
"|~	c #A3A5DA",
"1~	c #CACCFD",
"2~	c #C7C9FB",
"3~	c #B6B8E9",
"4~	c #B0B2E0",
"5~	c #AEAFDC",
"6~	c #AFB0DA",
"7~	c #B4B5DC",
"8~	c #BABBDD",
"9~	c #B1B3CD",
"0~	c #ADAECC",
"a~	c #BDBED5",
"b~	c #C1C3DB",
"c~	c #D0D1EB",
"d~	c #CED0E9",
"e~	c #CBCCE5",
"f~	c #C9CAE3",
"g~	c #BDBED8",
"h~	c #AFB0CB",
"i~	c #AEAFCB",
"j~	c #AEAFCC",
"k~	c #ACADCC",
"l~	c #AAABCC",
"m~	c #A9AACD",
"n~	c #C9CBF0",
"o~	c #DBDFFF",
"p~	c #C9CAFD",
"q~	c #BBBDE9",
"r~	c #ACAED4",
"s~	c #A1A2C3",
"t~	c #9394B0",
"u~	c #808198",
"v~	c #5A5B6D",
"w~	c #282937",
"x~	c #292934",
"y~	c #2E2E36",
"z~	c #37373C",
"A~	c #5D5D5F",
"B~	c #D9D9DA",
"C~	c #676767",
"D~	c #A8A8A9",
"E~	c #ACACAE",
"F~	c #B2B2B7",
"G~	c #B3B3BB",
"H~	c #B1B1BC",
"I~	c #B0B1BF",
"J~	c #AFB0C2",
"K~	c #ACADC4",
"L~	c #8A8BA8",
"M~	c #5B5C7D",
"N~	c #575986",
"O~	c #686A9F",
"P~	c #7577AD",
"Q~	c #9E9FD5",
"R~	c #C7C8FC",
"S~	c #C8CAF9",
"T~	c #B3B5E4",
"U~	c #B2B3E1",
"V~	c #B0B1DD",
"W~	c #AFB1DA",
"X~	c #B3B5DC",
"Y~	c #B7B9DE",
"Z~	c #A9AAC8",
"`~	c #B4B5CF",
" {	c #B4B5D0",
".{	c #B8BAD3",
"+{	c #BFC0D7",
"@{	c #D3D4E7",
"#{	c #D7D7EE",
"${	c #D4D6EC",
"%{	c #D1D2E8",
"&{	c #CFCFE6",
"*{	c #C6C7DF",
"={	c #B7B8D0",
"-{	c #B6B7CF",
";{	c #B4B6D0",
">{	c #B1B2CF",
",{	c #AFB1CF",
"'{	c #AEAFD0",
"){	c #C4C6E8",
"!{	c #D8DAFF",
"~{	c #D8D9FF",
"{{	c #C7C9F8",
"]{	c #B3B5DD",
"^{	c #A8AACC",
"/{	c #9C9DBB",
"({	c #8A8BA3",
"_{	c #797A8E",
":{	c #3B3C4C",
"<{	c #262733",
"[{	c #292932",
"}{	c #2E2E34",
"|{	c #39393C",
"1{	c #6D6E6E",
"2{	c #949495",
"3{	c #98989B",
"4{	c #A4A4AA",
"5{	c #ADADB6",
"6{	c #B2B2BD",
"7{	c #686981",
"8{	c #4B4C69",
"9{	c #515275",
"0{	c #585982",
"a{	c #5E5F8E",
"b{	c #65679B",
"c{	c #7375AA",
"d{	c #A1A2D8",
"e{	c #C4C6F6",
"f{	c #BABCE9",
"g{	c #B7B9E5",
"h{	c #B3B5E1",
"i{	c #B2B3DD",
"j{	c #B2B4DC",
"k{	c #BBBDE0",
"l{	c #B5B6D7",
"m{	c #A8A9C7",
"n{	c #B6B7D0",
"o{	c #BABBD4",
"p{	c #BBBCD4",
"q{	c #C3C4D9",
"r{	c #DBDCEC",
"s{	c #DDDDF0",
"t{	c #DADBEE",
"u{	c #D7D8EB",
"v{	c #D4D5E9",
"w{	c #CFD0E4",
"x{	c #BFC0D5",
"y{	c #BDBDD4",
"z{	c #BABCD3",
"A{	c #B7B9D3",
"B{	c #B5B7D2",
"C{	c #B3B5D2",
"D{	c #BFC0E0",
"E{	c #DBDDFF",
"F{	c #D9DBFF",
"G{	c #BFC1EB",
"H{	c #AFB0D5",
"I{	c #9596AF",
"J{	c #84859A",
"K{	c #666778",
"L{	c #272734",
"M{	c #262630",
"N{	c #292930",
"O{	c #303034",
"P{	c #3C3C3D",
"Q{	c #818182",
"R{	c #808084",
"S{	c #8D8D94",
"T{	c #9797A0",
"U{	c #8E8E9B",
"V{	c #626273",
"W{	c #48495D",
"X{	c #4A4B64",
"Y{	c #515270",
"Z{	c #58597C",
"`{	c #5E6089",
" ]	c #7D7FB3",
".]	c #B0B2E8",
"+]	c #C6C8FE",
"@]	c #B7B8E2",
"#]	c #B5B7DE",
"$]	c #B5B7DD",
"%]	c #BFC1E1",
"&]	c #B3B5D4",
"*]	c #B5B7D0",
"=]	c #C1C1D8",
"-]	c #C6C7DB",
";]	c #CACBDD",
">]	c #E0E1F0",
",]	c #E2E3F2",
"']	c #E0E1F1",
")]	c #DDDEEE",
"!]	c #DADBEB",
"~]	c #D7D8E9",
"{]	c #C7C8DA",
"]]	c #C1C1D7",
"^]	c #BEBFD6",
"/]	c #BBBCD5",
"(]	c #B8BAD5",
"_]	c #C0C1DE",
":]	c #DBDCFD",
"<]	c #D7D9FF",
"[]	c #CCCDF9",
"}]	c #B8B9DE",
"|]	c #ACADCE",
"1]	c #8E8FA5",
"2]	c #858597",
"3]	c #434351",
"4]	c #24252F",
"5]	c #26262D",
"6]	c #2B2B2F",
"7]	c #777778",
"8]	c #6D6D6F",
"9]	c #67676B",
"0]	c #5A5B61",
"a]	c #3E3F49",
"b]	c #30303E",
"c]	c #363749",
"d]	c #43445A",
"e]	c #50516B",
"f]	c #5B5C7C",
"g]	c #63648A",
"h]	c #7A7BA6",
"i]	c #999ACB",
"j]	c #C0C2F6",
"k]	c #BEC0F0",
"l]	c #B8BAE8",
"m]	c #B7B8E5",
"n]	c #B6B8E1",
"o]	c #B7B8DF",
"p]	c #B9BBDF",
"q]	c #BDBFE0",
"r]	c #C1C3E2",
"s]	c #B3B4D1",
"t]	c #CBCBDE",
"u]	c #CDCDDF",
"v]	c #D1D2E2",
"w]	c #E6E7F5",
"x]	c #E7E8F4",
"y]	c #E5E5F2",
"z]	c #E2E3F0",
"A]	c #E0E0ED",
"B]	c #DDDEEC",
"C]	c #D0D1E0",
"D]	c #C9CADB",
"E]	c #C6C7DA",
"F]	c #C0C1D8",
"G]	c #BEBFD8",
"H]	c #BEBFDB",
"I]	c #DBDCFC",
"J]	c #C5C6ED",
"K]	c #B3B4D6",
"L]	c #A7A8C4",
"M]	c #9899B0",
"N]	c #8D8EA1",
"O]	c #777887",
"P]	c #2A2A35",
"Q]	c #24242C",
"R]	c #27272C",
"S]	c #2D2D30",
"T]	c #404042",
"U]	c #1E1E22",
"V]	c #16161E",
"W]	c #1E1F2A",
"X]	c #292938",
"Y]	c #353648",
"Z]	c #414259",
"`]	c #4E4F6B",
" ^	c #5C5D7F",
".^	c #72749B",
"+^	c #C8CAF7",
"@^	c #BCBEED",
"#^	c #B8B9E5",
"$^	c #B7B9E1",
"%^	c #B7B9DF",
"&^	c #C1C2E2",
"*^	c #C4C5E3",
"=^	c #B8B9D1",
"-^	c #C8C9DC",
";^	c #CFD0E1",
">^	c #D4D5E3",
",^	c #D8D9E6",
"'^	c #EBECF8",
")^	c #EBECF6",
"!^	c #E9EAF4",
"~^	c #E7E8F2",
"{^	c #E5E5F0",
"]^	c #E2E3EE",
"^^	c #D7D8E4",
"/^	c #CFD0DE",
"(^	c #CCCDDD",
"_^	c #C8C9DB",
":^	c #C5C5DA",
"<^	c #BEC0DA",
"[^	c #DADBF9",
"}^	c #DDDEFF",
"|^	c #DADBFF",
"1^	c #D9DBFE",
"2^	c #D4D5FF",
"3^	c #D1D2FA",
"4^	c #BCBDE0",
"5^	c #A1A2BA",
"6^	c #9697AB",
"7^	c #9191A0",
"8^	c #555561",
"9^	c #23232C",
"0^	c #25252B",
"a^	c #2A2A2D",
"b^	c #323233",
"c^	c #121214",
"d^	c #131318",
"e^	c #17171F",
"f^	c #1E1E29",
"g^	c #262735",
"h^	c #323245",
"i^	c #3E3F56",
"j^	c #4E4F6A",
"k^	c #707197",
"l^	c #BFC0ED",
"m^	c #C9CAFB",
"n^	c #BABCEB",
"o^	c #B9BAE7",
"p^	c #B8B9E4",
"q^	c #B8BAE1",
"r^	c #BDBEE1",
"s^	c #C3C4E3",
"t^	c #BDBED4",
"u^	c #C4C5D9",
"v^	c #CCCDDE",
"w^	c #D9DAE6",
"x^	c #E1E1EC",
"y^	c #EFEFF8",
"z^	c #EFEFF7",
"A^	c #EDEEF5",
"B^	c #ECECF4",
"C^	c #E9E9F1",
"D^	c #E7E7F0",
"E^	c #DEDEE9",
"F^	c #D5D5E1",
"G^	c #D1D2E0",
"H^	c #C4C5DB",
"I^	c #C0C2DB",
"J^	c #D4D5F1",
"K^	c #DEE0FF",
"L^	c #DCDDFF",
"M^	c #DCDEFF",
"N^	c #DCDCFF",
"O^	c #CDCEFE",
"P^	c #D3D5FE",
"Q^	c #CACBEF",
"R^	c #B5B6D4",
"S^	c #A9AAC3",
"T^	c #A0A0B4",
"U^	c #9B9CAB",
"V^	c #8A8A96",
"W^	c #30313A",
"X^	c #24242A",
"Y^	c #27282B",
"Z^	c #2E2E2F",
"`^	c #1F1F20",
" /	c #1E1E21",
"./	c #1F2025",
"+/	c #22222A",
"@/	c #31323D",
"#/	c #444453",
"$/	c #4A4B5E",
"%/	c #404158",
"&/	c #53546E",
"*/	c #6B6C8A",
"=/	c #7D7E9F",
"-/	c #CFD0FE",
";/	c #C6C8F8",
">/	c #B9BBEA",
",/	c #B8BAE6",
"'/	c #B8B9E3",
")/	c #B8BAE0",
"!/	c #BEC0E1",
"~/	c #C5C6E4",
"{/	c #C2C3DE",
"]/	c #B8B9D2",
"^/	c #C1C2D7",
"//	c #C9CADC",
"(/	c #D8D9E5",
"_/	c #DDDEE8",
":/	c #E8E9F2",
"</	c #F1F2F9",
"[/	c #F2F2F8",
"}/	c #F1F1F7",
"|/	c #F0F0F5",
"1/	c #EDEDF3",
"2/	c #EAEBF1",
"3/	c #E3E4EC",
"4/	c #D9D9E4",
"5/	c #CBCCDE",
"6/	c #C7C8DC",
"7/	c #C3C4DB",
"8/	c #D1D2EC",
"9/	c #E2E3FF",
"0/	c #E0E1FF",
"a/	c #DEDFFF",
"b/	c #C8CBFF",
"c/	c #D5D6FA",
"d/	c #BCBDDC",
"e/	c #B0B1CB",
"f/	c #A8A8BD",
"g/	c #A4A5B5",
"h/	c #A0A0AC",
"i/	c #6D6D76",
"j/	c #26262A",
"k/	c #2C2C2D",
"l/	c #2D2D2E",
"m/	c #49494E",
"n/	c #81818A",
"o/	c #9B9BA7",
"p/	c #A0A1B0",
"q/	c #A1A1B5",
"r/	c #6D6E87",
"s/	c #4D4E6B",
"t/	c #646584",
"u/	c #77799B",
"v/	c #9698BD",
"w/	c #D2D4FA",
"x/	c #D1D2FE",
"y/	c #C6C7F5",
"z/	c #BBBDEA",
"A/	c #BABBE6",
"B/	c #B9BAE4",
"C/	c #B9BBE0",
"D/	c #C6C7E4",
"E/	c #BFC0DB",
"F/	c #BABBD2",
"G/	c #DADBE7",
"H/	c #E0E1EA",
"I/	c #EFF0F7",
"J/	c #F5F5FB",
"K/	c #F4F5F8",
"L/	c #F4F4F8",
"M/	c #F3F3F6",
"N/	c #F0F1F4",
"O/	c #E8E9EF",
"P/	c #DDDDE6",
"Q/	c #D7D8E3",
"R/	c #D3D3E1",
"S/	c #CECFDF",
"T/	c #CACBDE",
"U/	c #C7C7DD",
"V/	c #CDCFE7",
"W/	c #E1E2FF",
"X/	c #DADCFF",
"Y/	c #D7D8FD",
"Z/	c #C0C1E0",
"`/	c #B5B6D0",
" (	c #AEAFC4",
".(	c #ADADBE",
"+(	c #A9AAB6",
"@(	c #A2A3AC",
"#(	c #34343B",
"$(	c #2A2A2B",
"%(	c #4F4F50",
"&(	c #BBBBC1",
"*(	c #B0B0B9",
"=(	c #A2A2AE",
"-(	c #9E9EAE",
";(	c #9F9FB3",
">(	c #9192AA",
",(	c #4A4B69",
"'(	c #535477",
")(	c #61628A",
"!(	c #6F719F",
"~(	c #C9CBF3",
"{(	c #C2C3EB",
"](	c #C0C1E8",
"^(	c #BEBFE4",
"/(	c #BCBEE1",
"((	c #C2C3E2",
"_(	c #C8C9E5",
":(	c #BCBDD4",
"<(	c #D5D6E3",
"[(	c #DDDDE8",
"}(	c #F4F5FB",
"|(	c #F7F7FA",
"1(	c #F6F7F8",
"2(	c #F5F6F7",
"3(	c #F3F3F5",
"4(	c #EFF0F4",
"5(	c #ECECF2",
"6(	c #E0E0E7",
"7(	c #D9DAE4",
"8(	c #D5D5E2",
"9(	c #CFD0E0",
"0(	c #C6C6DC",
"a(	c #C8C9E2",
"b(	c #D5D6FB",
"c(	c #BFC0DF",
"d(	c #B3B3C9",
"e(	c #B3B4C4",
"f(	c #B1B2BF",
"g(	c #AEAFB8",
"h(	c #7A7A81",
"i(	c #27272B",
"j(	c #EBEBEF",
"k(	c #B4B4BD",
"l(	c #A4A5B1",
"m(	c #9B9BAB",
"n(	c #9B9BB0",
"o(	c #9899B2",
"p(	c #4C4D71",
"q(	c #575883",
"r(	c #636495",
"s(	c #9092C6",
"t(	c #BEC0EE",
"u(	c #B9BBE8",
"v(	c #B9BAE5",
"w(	c #B9BAE2",
"x(	c #BABCE0",
"y(	c #BDBFE1",
"z(	c #C7C9E4",
"A(	c #BBBDD5",
"B(	c #BEBED4",
"C(	c #CFD0DF",
"D(	c #D6D7E4",
"E(	c #E5E6ED",
"F(	c #F7F7FD",
"G(	c #F9F9FD",
"H(	c #F8F8FA",
"I(	c #F8F9F9",
"J(	c #F5F5F7",
"K(	c #F1F2F4",
"L(	c #E2E3E9",
"M(	c #DBDBE4",
"N(	c #D5D6E2",
"O(	c #C6C7DD",
"P(	c #C4C6DE",
"Q(	c #DCDEFA",
"R(	c #D2D3F9",
"S(	c #B5B6D1",
"T(	c #B4B4CA",
"U(	c #B5B6C6",
"V(	c #B6B6C3",
"W(	c #B5B5BF",
"X(	c #A6A7AD",
"Y(	c #404044",
"Z(	c #CDCDD3",
"`(	c #B8B8C1",
" _	c #A8A9B5",
"._	c #9798AD",
"+_	c #656684",
"@_	c #48496D",
"#_	c #53547F",
"$_	c #5E5F90",
"%_	c #BCBDF4",
"&_	c #C8C9FB",
"*_	c #B7B9E7",
"=_	c #B7B8E4",
"-_	c #B8BADF",
";_	c #BCBEE0",
">_	c #C2C3E3",
",_	c #C5C6E2",
"'_	c #BEBFD5",
")_	c #C8C8DB",
"!_	c #D0D1E1",
"~_	c #D7D8E5",
"{_	c #DFDFE9",
"]_	c #E8E8F0",
"^_	c #F8F9FF",
"/_	c #F8F9FB",
"(_	c #F9F9FA",
"__	c #F7F8F9",
":_	c #F2F2F5",
"<_	c #EEEEF3",
"[_	c #E5E5EC",
"}_	c #C2C3DB",
"|_	c #D7D8F4",
"1_	c #DBDCFF",
"2_	c #CCCEF3",
"3_	c #B9BADA",
"4_	c #B4B5CB",
"5_	c #B6B6C7",
"6_	c #B7B7C4",
"7_	c #B6B6BD",
"8_	c #656569",
"9_	c #F9FAFD",
"0_	c #BCBCC5",
"a_	c #ADADB9",
"b_	c #9495A9",
"c_	c #7B7C9A",
"d_	c #45466A",
"e_	c #4F517B",
"f_	c #5A5B8C",
"g_	c #66699D",
"h_	c #9EA0D6",
"i_	c #C8C9FE",
"j_	c #C4C5F8",
"k_	c #B7B9E9",
"l_	c #B6B8E5",
"m_	c #B5B7E3",
"n_	c #B5B7E0",
"o_	c #C1C3DF",
"p_	c #C7C8DB",
"q_	c #D0D0E0",
"r_	c #DEDFE9",
"s_	c #EAEBF3",
"t_	c #F9FAFE",
"u_	c #F7F7F8",
"v_	c #F4F5F7",
"w_	c #ECEDF2",
"x_	c #DADAE4",
"y_	c #CACADD",
"z_	c #C5C5DB",
"A_	c #C1C2DA",
"B_	c #D0D1EC",
"C_	c #DFE0FF",
"D_	c #D1D3FD",
"E_	c #C5C6EB",
"F_	c #B7B8D8",
"G_	c #B4B4CF",
"H_	c #B5B6CB",
"I_	c #B6B7C8",
"J_	c #B7B8C5",
"K_	c #B8B8C2",
"L_	c #B8B8BE",
"M_	c #2B2B2C",
"N_	c #E1E1E7",
"O_	c #C0C0C9",
"P_	c #B1B1BD",
"Q_	c #A2A2B2",
"R_	c #9192AB",
"S_	c #898AA7",
"T_	c #444569",
"U_	c #4C4D77",
"V_	c #565888",
"W_	c #C2C4FA",
"X_	c #BFC1F3",
"Y_	c #B6B8E8",
"Z_	c #B4B6E4",
"`_	c #B4B5E1",
" :	c #B4B5DE",
".:	c #B6B7DD",
"+:	c #BCBDDA",
"@:	c #B4B6CF",
"#:	c #EDEDF6",
"$:	c #F7F8FB",
"%:	c #F6F7F9",
"&:	c #F5F6F8",
"*:	c #EFEFF4",
"=:	c #EBEBF1",
"-:	c #E5E6EE",
";:	c #D8D8E3",
">:	c #D2D3E0",
",:	c #C2C3DA",
"':	c #C4C5E2",
"):	c #DDDFFF",
"!:	c #D0D2FC",
"~:	c #CDCFFA",
"{:	c #CCCEF8",
"]:	c #CDCEF8",
"^:	c #CFD0F9",
"/:	c #D3D5FC",
"(:	c #D7D9FD",
"_:	c #C1C2E4",
"::	c #B8B8D6",
"<:	c #B6B7CB",
"[:	c #B7B8C8",
"}:	c #B8B9C5",
"|:	c #B9B9C2",
"1:	c #B7B7BD",
"2:	c #5C5C60",
"3:	c #A6A7B6",
"4:	c #9596AA",
"5:	c #8E8FA7",
"6:	c #8D8EAB",
"7:	c #494A73",
"8:	c #525484",
"9:	c #5E6094",
"0:	c #AAACE2",
"a:	c #BBBDEE",
"b:	c #B4B6E6",
"c:	c #B3B4E3",
"d:	c #B2B3E0",
"e:	c #C6C8E5",
"f:	c #BBBDD7",
"g:	c #C4C5DA",
"h:	c #CCCCDE",
"i:	c #D3D4E3",
"j:	c #EEEFF9",
"k:	c #F8FAFF",
"l:	c #F6F7FC",
"m:	c #F3F3F8",
"n:	c #F0F1F6",
"o:	c #E8E9F0",
"p:	c #E4E4EE",
"q:	c #D6D6E2",
"r:	c #CACBDC",
"s:	c #C5C6DA",
"t:	c #C0C0D8",
"u:	c #BBBCD6",
"v:	c #B9BBD8",
"w:	c #DBDDFD",
"x:	c #D7D8FC",
"y:	c #CED0F6",
"z:	c #C6C7F1",
"A:	c #BFC0EC",
"B:	c #B9BAE8",
"C:	c #B4B6E5",
"D:	c #B0B2E2",
"E:	c #AFB1E2",
"F:	c #BDBEED",
"G:	c #C8C9F8",
"H:	c #CFD0F1",
"I:	c #C2C3E1",
"J:	c #BABAD6",
"K:	c #B5B6CF",
"L:	c #B6B7CC",
"M:	c #B8B8C8",
"N:	c #B9B9C6",
"O:	c #B1B1B7",
"P:	c #49494C",
"Q:	c #2F2F30",
"R:	c #F6F6FC",
"S:	c #CACAD2",
"T:	c #B9B9C5",
"U:	c #AAABB9",
"V:	c #999AAD",
"W:	c #8C8DA5",
"X:	c #8B8CA9",
"Y:	c #626486",
"Z:	c #45476F",
"`:	c #4F517F",
" <	c #5A5B8F",
".<	c #8D8EC5",
"+<	c #C6C8FB",
"@<	c #B6B8EA",
"#<	c #B6B8E3",
"$<	c #BBBCE2",
"%<	c #C1C2E3",
"&<	c #C7C8E5",
"*<	c #C5C7E4",
"=<	c #ABACCB",
"-<	c #AFB1CC",
";<	c #C0C3D9",
"><	c #C9CDE1",
",<	c #D1D4E5",
"'<	c #DBDEEC",
")<	c #F2F4FD",
"!<	c #F0F0F7",
"~<	c #EEEEF5",
"{<	c #E6E6F0",
"]<	c #E2E2EE",
"^<	c #CBCCDC",
"/<	c #C1C2D8",
"(<	c #B6B7D2",
"_<	c #B0B2D0",
":<	c #CECFF1",
"<<	c #CBCDF1",
"[<	c #C4C6ED",
"}<	c #BDBFE9",
"|<	c #B0B1E0",
"1<	c #A9AADB",
"2<	c #A2A4D6",
"3<	c #9698CB",
"4<	c #9395C9",
"5<	c #BBBCEC",
"6<	c #BBBEF0",
"7<	c #C3C5FA",
"8<	c #CACCF8",
"9<	c #BCBEE4",
"0<	c #B7B8DA",
"a<	c #B5B6D3",
"b<	c #B7B8CC",
"c<	c #B9B9C9",
"d<	c #B9BAC6",
"e<	c #BABAC3",
"f<	c #A0A0A6",
"g<	c #333337",
"h<	c #313133",
"i<	c #D4D5DC",
"j<	c #BCBDC8",
"k<	c #AEAEBD",
"l<	c #9D9EB1",
"m<	c #8E8FA6",
"n<	c #8788A5",
"o<	c #6F7092",
"p<	c #43446C",
"q<	c #4C4D7B",
"r<	c #56578B",
"s<	c #64669B",
"t<	c #787AB0",
"u<	c #B5B7ED",
"v<	c #BEBFEA",
"w<	c #C3C4E9",
"x<	c #C3C4E7",
"y<	c #BFC0E3",
"z<	c #B9BADE",
"A<	c #A3A5C5",
"B<	c #ABADCA",
"C<	c #BFC5DC",
"D<	c #CED4E6",
"E<	c #D6DBEB",
"F<	c #DFE4F1",
"G<	c #F2F4FF",
"H<	c #F3F3FD",
"I<	c #EFEFF9",
"J<	c #EDEEF7",
"K<	c #EBEBF5",
"L<	c #E7E7F2",
"M<	c #E2E3EF",
"N<	c #DEDFEC",
"O<	c #D2D3E3",
"P<	c #C7C8D9",
"Q<	c #C2C3D7",
"R<	c #B6B8D2",
"S<	c #AAACCB",
"T<	c #C6C8EC",
"U<	c #BFC1E8",
"V<	c #B1B2DF",
"W<	c #AAABDA",
"X<	c #A1A3D4",
"Y<	c #8F90C4",
"Z<	c #8688BB",
"`<	c #8284B8",
" [	c #ACAEDF",
".[	c #989AD0",
"+[	c #B7B9ED",
"@[	c #B3B4DC",
"#[	c #B2B3D6",
"$[	c #B4B5D2",
"%[	c #B8B8CC",
"&[	c #B9BAC9",
"*[	c #BBBCC4",
"=[	c #303033",
"-[	c #E1E1E9",
";[	c #C0C1CB",
">[	c #B2B2C0",
",[	c #A1A2B4",
"'[	c #9192A8",
")[	c #7B7C9D",
"![	c #46476E",
"~[	c #484A76",
"{[	c #515386",
"][	c #5F6196",
"^[	c #7072A8",
"/[	c #C7C8F3",
"([	c #BCBEE8",
"_[	c #B6B8E4",
":[	c #AFB1DE",
"<[	c #ABACD9",
"[[	c #AAABD8",
"}[	c #B4B6DD",
"|[	c #AFB1D5",
"1[	c #B1B5D1",
"2[	c #C1C8E0",
"3[	c #D6DCEB",
"4[	c #E2E6F1",
"5[	c #E4E8F6",
"6[	c #EEF0FF",
"7[	c #ECEDF9",
"8[	c #EAEAF6",
"9[	c #E4E4F1",
"0[	c #DFE0EE",
"a[	c #DADBEA",
"b[	c #D0D1E2",
"c[	c #C1C2D6",
"d[	c #B7B9D1",
"e[	c #ABACCA",
"f[	c #AFB1D3",
"g[	c #C2C4EA",
"h[	c #BEBFE8",
"i[	c #ACAEDE",
"j[	c #A6A8D9",
"k[	c #9EA0D3",
"l[	c #6B6DA1",
"m[	c #696BA1",
"n[	c #8385B9",
"o[	c #9193C5",
"p[	c #7375AB",
"q[	c #65679D",
"r[	c #626399",
"s[	c #8283B1",
"t[	c #9E9FC7",
"u[	c #B4B5D1",
"v[	c #B8B9CC",
"w[	c #BABAC9",
"x[	c #BBBBC6",
"y[	c #B9BAC2",
"z[	c #45454A",
"A[	c #333336",
"B[	c #383839",
"C[	c #ECECF3",
"D[	c #C5C5CF",
"E[	c #B6B6C4",
"F[	c #A6A7B8",
"G[	c #9697AC",
"H[	c #8687A1",
"I[	c #8081A0",
"J[	c #4F5075",
"K[	c #454671",
"L[	c #4D4F80",
"M[	c #5A5C91",
"N[	c #7F81B7",
"O[	c #BDBFF4",
"P[	c #C8CAFD",
"Q[	c #B7B9EB",
"R[	c #AEB0E2",
"S[	c #AAACDE",
"T[	c #A6A7D6",
"U[	c #ACAED8",
"V[	c #B1B3DB",
"W[	c #A1A3C8",
"X[	c #999BBE",
"Y[	c #AEB3D0",
"Z[	c #BFC7E0",
"`[	c #D5DAEB",
" }	c #E7EAF9",
".}	c #ECEEFF",
"+}	c #EBECFA",
"@}	c #E7E8F6",
"#}	c #E3E4F3",
"$}	c #E0E0F0",
"%}	c #DBDBEC",
"&}	c #D5D6E9",
"*}	c #CFD0E5",
"=}	c #BCBDD2",
"-}	c #ABACC9",
";}	c #9E9FC2",
">}	c #A2A4C9",
",}	c #C1C3E9",
"'}	c #BEBFE9",
")}	c #B3B5E3",
"!}	c #AFB0E1",
"~}	c #A9ABDD",
"{}	c #A0A1D4",
"]}	c #7F81B5",
"^}	c #595B8E",
"/}	c #63649A",
"(}	c #8A8BBE",
"_}	c #8284B7",
":}	c #66689E",
"<}	c #56588F",
"[}	c #4B4D83",
"}}	c #434578",
"|}	c #40426F",
"1}	c #43446B",
"2}	c #8788A4",
"3}	c #B9B9CC",
"4}	c #BABBC9",
"5}	c #BCBCC6",
"6}	c #343438",
"7}	c #3D3D3E",
"8}	c #F3F3FA",
"9}	c #CDCDD6",
"0}	c #BABAC7",
"a}	c #AAABBB",
"b}	c #9A9BAF",
"c}	c #8A8AA3",
"d}	c #7E7F9E",
"e}	c #5A5B7F",
"f}	c #42436D",
"g}	c #4A4B7B",
"h}	c #55578B",
"i}	c #A1A3D8",
"j}	c #AAACE0",
"k}	c #A4A6D7",
"l}	c #A2A3D3",
"m}	c #A4A5D3",
"n}	c #A9AAD7",
"o}	c #ADAFD8",
"p}	c #9697BC",
"q}	c #A0A2C3",
"r}	c #A8ABCA",
"s}	c #B5BCD8",
"t}	c #C6CDE4",
"u}	c #CFD6E9",
"v}	c #E6E9FC",
"w}	c #E8EAFE",
"x}	c #EAEBFE",
"y}	c #E9E9FC",
"z}	c #E3E4F5",
"A}	c #E0E0F2",
"B}	c #DCDDEF",
"C}	c #D7D7EB",
"D}	c #D1D2E7",
"E}	c #CCCDE4",
"F}	c #B0B1CC",
"G}	c #AAACC9",
"H}	c #9D9FC1",
"I}	c #9899BD",
"J}	c #9798BF",
"K}	c #B7B9E2",
"L}	c #BDBEE8",
"M}	c #BABBE7",
"N}	c #B5B7E4",
"O}	c #A3A4D7",
"P}	c #7375A8",
"Q}	c #616398",
"R}	c #797AB0",
"S}	c #9B9CCD",
"T}	c #7D7FB4",
"U}	c #63659B",
"V}	c #53558B",
"W}	c #424475",
"X}	c #3E3F6B",
"Y}	c #3A3B60",
"Z}	c #363757",
"`}	c #32334E",
" |	c #44445A",
".|	c #727384",
"+|	c #ADADBA",
"@|	c #A7A8B1",
"#|	c #43434A",
"$|	c #38383B",
"%|	c #3C3C3E",
"&|	c #434344",
"*|	c #D8D9E1",
"=|	c #BEBECA",
"-|	c #AEAFBE",
";|	c #9E9FB2",
">|	c #7F809C",
",|	c #696B8C",
"'|	c #404169",
")|	c #464876",
"!|	c #5D6094",
"~|	c #6E70A6",
"{|	c #8789BF",
"]|	c #C3C5F8",
"^|	c #BEC0F5",
"/|	c #ACAEE2",
"(|	c #A7A9DD",
"_|	c #A3A5D8",
":|	c #9FA1D3",
"<|	c #9EA0D0",
"[|	c #A1A3D2",
"}|	c #A5A6D2",
"||	c #8C8EB6",
"1|	c #9496BB",
"2|	c #A2A4C6",
"3|	c #ACB0D0",
"4|	c #B6BCD9",
"5|	c #C2C7E2",
"6|	c #E3E7FE",
"7|	c #E4E6FE",
"8|	c #E7E8FD",
"9|	c #E0E1F6",
"0|	c #DCDDF2",
"a|	c #D8D9EE",
"b|	c #D3D3EA",
"c|	c #CCCEE5",
"d|	c #C6C8E1",
"e|	c #9D9EC0",
"f|	c #9798BC",
"g|	c #9193B8",
"h|	c #8D8EB7",
"i|	c #A9AAD4",
"j|	c #B5B7E6",
"k|	c #7C7DAD",
"l|	c #656799",
"m|	c #606295",
"n|	c #7173A9",
"o|	c #9091C5",
"p|	c #A4A5D7",
"q|	c #8C8EC3",
"r|	c #7B7DB3",
"s|	c #515387",
"t|	c #38395D",
"u|	c #343554",
"v|	c #2F304A",
"w|	c #2A2B40",
"x|	c #252636",
"y|	c #2F2F3C",
"z|	c #40404A",
"A|	c #34353B",
"B|	c #3D3D40",
"C|	c #414143",
"D|	c #B3B3C1",
"E|	c #A3A3B5",
"F|	c #9293A9",
"G|	c #82829E",
"H|	c #737494",
"I|	c #424469",
"J|	c #434470",
"K|	c #4B4D7F",
"L|	c #797BB1",
"M|	c #A7A9DE",
"N|	c #A4A6D9",
"O|	c #9FA1D4",
"P|	c #9B9CCF",
"Q|	c #9FA1D1",
"R|	c #9B9CC8",
"S|	c #9597BD",
"T|	c #9D9FC3",
"U|	c #A6A7CA",
"V|	c #ADAFD0",
"W|	c #E1E3FF",
"X|	c #E2E4FF",
"Y|	c #E4E6FF",
"Z|	c #DEDFF7",
"`|	c #D8D9F1",
" 1	c #D4D5EE",
".1	c #CFD0E9",
"+1	c #C8C9E4",
"@1	c #C1C2DE",
"#1	c #B3B5D3",
"$1	c #A1A2C2",
"%1	c #9091B7",
"&1	c #8485B0",
"*1	c #9798C5",
"=1	c #B2B4E3",
"-1	c #898BBC",
";1	c #7173A1",
">1	c #6F71A1",
",1	c #787AAD",
"'1	c #BFC1F2",
")1	c #BDBFF2",
"!1	c #AEB0E6",
"~1	c #8183B0",
"{1	c #585980",
"]1	c #3B3C5E",
"^1	c #28293D",
"/1	c #232333",
"(1	c #1C1D29",
"_1	c #141419",
":1	c #202023",
"<1	c #ECEDF4",
"[1	c #C8C8D2",
"}1	c #B6B7C4",
"|1	c #8586A0",
"11	c #777896",
"21	c #494A6E",
"31	c #474979",
"41	c #525488",
"51	c #606297",
"61	c #8D8FC4",
"71	c #C6C8F9",
"81	c #B3B5EA",
"91	c #A1A3D6",
"01	c #9799CC",
"a1	c #A5A7D4",
"b1	c #9091BD",
"c1	c #7F80AC",
"d1	c #8788B3",
"e1	c #989AC0",
"f1	c #A1A3C7",
"g1	c #A8AACD",
"h1	c #C9CBEB",
"i1	c #DFE1FF",
"j1	c #DCDDF9",
"k1	c #D5D6F1",
"l1	c #D0D1ED",
"m1	c #CCCDE9",
"n1	c #B2B3D4",
"o1	c #9A9CBE",
"p1	c #9698BB",
"q1	c #9496BA",
"r1	c #7C7DAA",
"s1	c #8284B1",
"t1	c #AAACDB",
"u1	c #A8AADC",
"v1	c #7173A5",
"w1	c #646598",
"x1	c #797AA9",
"y1	c #AEAFDE",
"z1	c #C3C5F4",
"A1	c #B9BBEF",
"B1	c #B2B3E9",
"C1	c #ABADE2",
"D1	c #A6A7D8",
"E1	c #9495BA",
"F1	c #707191",
"G1	c #3F405C",
"H1	c #2C2D44",
"I1	c #27273A",
"J1	c #212230",
"K1	c #1B1B26",
"L1	c #15151D",
"M1	c #0E0E14",
"N1	c #07070A",
"O1	c #F5F5FC",
"P1	c #D2D2DB",
"Q1	c #9B9CAF",
"R1	c #898AA2",
"S1	c #7A7B98",
"T1	c #57587A",
"U1	c #3D3E65",
"V1	c #444673",
"W1	c #4C4E81",
"X1	c #595B90",
"Y1	c #7A7BB1",
"Z1	c #B4B6EB",
"`1	c #A8A9DF",
" 2	c #9799CD",
".2	c #A0A2D0",
"+2	c #9FA1CF",
"@2	c #8189B6",
"#2	c #8892BD",
"$2	c #8285B1",
"%2	c #8A8BB6",
"&2	c #9294BC",
"*2	c #9B9DC4",
"=2	c #A5A7CC",
"-2	c #D1D3F6",
";2	c #DCDEFE",
">2	c #DDDFFE",
",2	c #DCDDFC",
"'2	c #D1D3F1",
")2	c #CCCDEC",
"!2	c #C9CAE9",
"~2	c #B8B9DB",
"{2	c #AEB0D4",
"]2	c #8D8FB5",
"^2	c #8C8DB4",
"/2	c #888AB2",
"(2	c #7D7EAA",
"_2	c #7576A4",
":2	c #7072A1",
"<2	c #9092C2",
"[2	c #9C9ED0",
"}2	c #626397",
"|2	c #5B5D90",
"12	c #7677AB",
"22	c #BCBEEF",
"32	c #C9CAF4",
"42	c #BABBEB",
"52	c #A6A8DB",
"62	c #A8A9D8",
"72	c #ABACD5",
"82	c #A1A2BF",
"92	c #83849E",
"02	c #414156",
"a2	c #252637",
"b2	c #1F1F2D",
"c2	c #191923",
"d2	c #12131A",
"e2	c #0C0D11",
"f2	c #050507",
"g2	c #DFDFE7",
"h2	c #BFBFCA",
"i2	c #AFB0BE",
"j2	c #9FA0B2",
"k2	c #7E7F9A",
"l2	c #656686",
"m2	c #3C3D62",
"n2	c #41426D",
"o2	c #484A7A",
"p2	c #6D6FA5",
"q2	c #8587BD",
"r2	c #9D9FD4",
"s2	c #9597C9",
"t2	c #9697C8",
"u2	c #9EA0CE",
"v2	c #9D9FCE",
"w2	c #8E91C2",
"x2	c #7D89B5",
"y2	c #9CA9CD",
"z2	c #7E84B2",
"A2	c #8485B2",
"B2	c #8D8EB9",
"C2	c #D5D6FC",
"D2	c #DADCFE",
"E2	c #D0D1F3",
"F2	c #C8CAEC",
"G2	c #C5C6E8",
"H2	c #C0C1E3",
"I2	c #B3B5DA",
"J2	c #AAACD2",
"K2	c #9596BE",
"L2	c #8486AF",
"M2	c #8183AD",
"N2	c #7E80AA",
"O2	c #68699A",
"P2	c #7B7DAE",
"Q2	c #898BBD",
"R2	c #7678AC",
"S2	c #4C4E82",
"T2	c #7576AC",
"U2	c #B8BAED",
"V2	c #BFC0EF",
"W2	c #B9BAE9",
"X2	c #ABADDB",
"Y2	c #ACADD7",
"Z2	c #ADAFD4",
"`2	c #B0B1D1",
" 3	c #B2B3CE",
".3	c #B1B2C9",
"+3	c #606174",
"@3	c #2A2B3A",
"#3	c #1D1D2A",
"$3	c #161620",
"%3	c #101016",
"&3	c #0A0A0E",
"*3	c #030304",
"=3	c #ECEDF3",
"-3	c #C3C4CE",
";3	c #B4B5C1",
">3	c #71718F",
",3	c #424365",
"'3	c #3E3F66",
")3	c #434572",
"!3	c #4B4D80",
"~3	c #9B9CD1",
"{3	c #BDBEF0",
"]3	c #B0B2E6",
"^3	c #9B9DCD",
"/3	c #9E9FCC",
"(3	c #9799CA",
"_3	c #9596C9",
":3	c #7879AC",
"<3	c #666A9C",
"[3	c #7177A7",
"}3	c #7678A8",
"|3	c #7F80AF",
"13	c #8788B6",
"23	c #9192BE",
"33	c #B5B6E0",
"43	c #D1D3F8",
"53	c #C6C8ED",
"63	c #C1C3E7",
"73	c #BFC1E4",
"83	c #B1B3DA",
"93	c #A6A7D0",
"03	c #9596C1",
"a3	c #7C7DA9",
"b3	c #7375A2",
"c3	c #646596",
"d3	c #636597",
"e3	c #8788BC",
"f3	c #54568C",
"g3	c #B5B6E7",
"h3	c #A9AADC",
"i3	c #B0B1DE",
"j3	c #B9BAE1",
"k3	c #BBBCDF",
"l3	c #B4B5D6",
"m3	c #B0B1CA",
"n3	c #808196",
"o3	c #474859",
"p3	c #444553",
"q3	c #3C3C47",
"r3	c #202028",
"s3	c #15151A",
"t3	c #08080A",
"u3	c #CCCDD5",
"v3	c #A9AAB8",
"w3	c #9899AB",
"x3	c #87889E",
"y3	c #787993",
"z3	c #4B4C6C",
"A3	c #393A5E",
"B3	c #40416A",
"C3	c #474978",
"D3	c #4E5083",
"E3	c #58598E",
"F3	c #65669C",
"G3	c #7A7CB1",
"H3	c #BCBDEB",
"I3	c #B1B2E0",
"J3	c #9698C9",
"K3	c #9092C5",
"L3	c #5C5E91",
"M3	c #5E5F92",
"N3	c #67699A",
"O3	c #797BAB",
"P3	c #8284B2",
"Q3	c #C1C3EF",
"R3	c #D2D4FC",
"S3	c #C4C6EE",
"T3	c #BDBFE8",
"U3	c #B1B2DA",
"V3	c #A2A3D0",
"W3	c #9697C4",
"X3	c #7677A5",
"Y3	c #6D6F9E",
"Z3	c #7C7EA9",
"`3	c #6E6F9E",
" 4	c #5B5C8F",
".4	c #7E80B3",
"+4	c #57598D",
"@4	c #8A8CBE",
"#4	c #8F91C3",
"$4	c #9496CB",
"%4	c #9C9ED3",
"&4	c #A8AAD6",
"*4	c #B8B9DA",
"=4	c #C4C5DE",
"-4	c #A7A8BE",
";4	c #727388",
">4	c #4F4F5E",
",4	c #4F505B",
"'4	c #51525B",
")4	c #7C7C82",
"!4	c #BBBBBE",
"~4	c #5D5E5F",
"{4	c #0F0F10",
"]4	c #DBDBE2",
"^4	c #BEBEC9",
"/4	c #AEAFBC",
"(4	c #9D9EAE",
"_4	c #8C8CA0",
":4	c #7B7C94",
"<4	c #5A5B77",
"[4	c #38395B",
"}4	c #3C3D63",
"|4	c #42446F",
"14	c #484A7B",
"24	c #505286",
"34	c #696B9F",
"44	c #C0C2EA",
"54	c #9597CB",
"64	c #7B7DB1",
"74	c #585A8D",
"84	c #616396",
"94	c #6B6D9F",
"04	c #7476A7",
"a4	c #8082B1",
"b4	c #9899C6",
"c4	c #CACCFA",
"d4	c #BBBCE8",
"e4	c #BBBCE4",
"f4	c #B5B5DD",
"g4	c #A0A2CF",
"h4	c #9596C4",
"i4	c #7779A8",
"j4	c #666798",
"k4	c #6C6E9D",
"l4	c #7C7EA8",
"m4	c #7D7EB2",
"n4	c #9899CE",
"o4	c #8082B8",
"p4	c #67689E",
"q4	c #8485B8",
"r4	c #8E90C1",
"s4	c #7273A8",
"t4	c #6B6DA2",
"u4	c #7275AA",
"v4	c #797BA7",
"w4	c #7B7DA2",
"x4	c #80819E",
"y4	c #80808F",
"z4	c #6E6E7D",
"A4	c #62636F",
"B4	c #5F5F69",
"C4	c #888990",
"D4	c #EAEAEF",
"E4	c #FCFCFD",
"F4	c #E9E9EF",
"G4	c #B3B3BF",
"H4	c #A2A3B0",
"I4	c #9191A3",
"J4	c #808197",
"K4	c #6B6C85",
"L4	c #4B4D7E",
"M4	c #7173A0",
"N4	c #9293BC",
"O4	c #B3B5E0",
"P4	c #9395CA",
"Q4	c #535589",
"R4	c #7273A5",
"S4	c #A5A6D6",
"T4	c #CECFFE",
"U4	c #CBCCFA",
"V4	c #BABCEA",
"W4	c #B7B8E3",
"X4	c #B9BAE0",
"Y4	c #7C7DAE",
"Z4	c #5D5E90",
"`4	c #5A5B8E",
" 5	c #5B5D8F",
".5	c #6C6E9B",
"+5	c #7E80A9",
"@5	c #7F81B2",
"#5	c #BABBF0",
"$5	c #B7B9EF",
"%5	c #A5A6DA",
"&5	c #9597C8",
"*5	c #5D5E94",
"=5	c #55578C",
"-5	c #4F5185",
";5	c #4D4E7E",
">5	c #4D4E79",
",5	c #505175",
"'5	c #565775",
")5	c #60617A",
"!5	c #727285",
"~5	c #888996",
"{5	c #93949D",
"]5	c #8C8C95",
"^5	c #FCFDFE",
"/5	c #F5F6FA",
"(5	c #CDCDD4",
"_5	c #A7A8B5",
":5	c #9697A7",
"<5	c #858598",
"[5	c #75768D",
"}5	c #41425E",
"|5	c #363759",
"15	c #3B3C61",
"25	c #44456D",
"35	c #535580",
"45	c #6E6F99",
"55	c #8687AC",
"65	c #797BA6",
"75	c #A3A5D9",
"85	c #B0B2E3",
"95	c #ADAFE1",
"05	c #9193C8",
"a5	c #5D5F94",
"b5	c #525489",
"c5	c #636598",
"d5	c #7475A5",
"e5	c #8182B0",
"f5	c #BCBDEF",
"g5	c #BCBDE3",
"h5	c #8385B7",
"i5	c #585A8C",
"j5	c #7778A4",
"k5	c #8D8EB8",
"l5	c #7E80B6",
"m5	c #545686",
"n5	c #535581",
"o5	c #53547B",
"p5	c #545577",
"q5	c #565774",
"r5	c #5A5B73",
"s5	c #626376",
"t5	c #70707F",
"u5	c #9B9CA7",
"v5	c #E2E2E9",
"w5	c #DBDCE1",
"x5	c #BFBFC7",
"y5	c #ADADB8",
"z5	c #9C9CAA",
"A5	c #8A8B9C",
"B5	c #7A7B90",
"C5	c #53546D",
"D5	c #363753",
"E5	c #414262",
"F5	c #8283A4",
"G5	c #6A6C96",
"H5	c #606298",
"I5	c #5B5D91",
"J5	c #898BBB",
"K5	c #C5C7F9",
"L5	c #BCBDE4",
"M5	c #9394C6",
"N5	c #8384B8",
"O5	c #484A7E",
"P5	c #9A9BC4",
"Q5	c #B4B5DD",
"R5	c #CBCDFB",
"S5	c #C0C1F8",
"T5	c #7577AC",
"U5	c #656698",
"V5	c #5F608E",
"W5	c #5D5F87",
"X5	c #5D5F82",
"Y5	c #60617F",
"Z5	c #666681",
"`5	c #74758C",
" 6	c #9A9BAD",
".6	c #CECFDD",
"+6	c #EEEEF9",
"@6	c #ECEDF0",
"#6	c #C5C5CB",
"$6	c #B3B3BC",
"%6	c #A2A3AF",
"&6	c #9091A0",
"*6	c #7F8092",
"=6	c #696A7F",
"-6	c #40415A",
";6	c #555570",
">6	c #767790",
",6	c #7E7E99",
"'6	c #606187",
")6	c #4F507F",
"!6	c #52548A",
"~6	c #8284B9",
"{6	c #9B9DD3",
"]6	c #9496CA",
"^6	c #8D8FC1",
"/6	c #9495C6",
"(6	c #6D6EA4",
"_6	c #7375A4",
":6	c #7A7CAA",
"<6	c #BDBEF1",
"[6	c #B9BADF",
"}6	c #9799C9",
"|6	c #6E70A4",
"16	c #5D5F95",
"26	c #A1A2CE",
"36	c #BEC0E9",
"46	c #C4C6F9",
"56	c #B2B4DD",
"66	c #B0B1D6",
"76	c #B4B5D5",
"86	c #C0C1DD",
"96	c #D4D5EC",
"06	c #E2E2F7",
"a6	c #ECEDFD",
"b6	c #D1D1D6",
"c6	c #A8A9B3",
"d6	c #9898A4",
"e6	c #898998",
"f6	c #7E7E90",
"g6	c #636376",
"h6	c #797A8C",
"i6	c #74758B",
"j6	c #565777",
"k6	c #47496F",
"l6	c #424471",
"m6	c #434577",
"n6	c #8F90C6",
"o6	c #8788BB",
"p6	c #999BCB",
"q6	c #8F90C3",
"r6	c #898BB8",
"s6	c #8C8EC0",
"t6	c #B8BAE9",
"u6	c #C0C2E4",
"v6	c #898BBF",
"w6	c #5C5E93",
"x6	c #55568D",
"y6	c #64669C",
"z6	c #7C7DB2",
"A6	c #8F91C1",
"B6	c #9496C1",
"C6	c #C3C4F0",
"D6	c #E2E2E6",
"E6	c #C0C1C6",
"F6	c #B0B0B8",
"G6	c #A2A2AD",
"H6	c #9899A5",
"I6	c #9899A6",
"J6	c #90909D",
"K6	c #68687A",
"L6	c #4D4D66",
"M6	c #404160",
"N6	c #444678",
"O6	c #7274A9",
"P6	c #A1A3CF",
"Q6	c #B2B3E7",
"R6	c #C5C7F8",
"S6	c #C2C4E9",
"T6	c #AFB1DC",
"U6	c #9698CC",
"V6	c #8B8DC3",
"W6	c #8284BA",
"X6	c #787AAE",
"Y6	c #6C6EA3",
"Z6	c #6C6EA0",
"`6	c #8385AF",
" 7	c #A7A8CA",
".7	c #C5C6F2",
"+7	c #E8E8FF",
"@7	c #DBDCDC",
"#7	c #CFD0D1",
"$7	c #C4C4C8",
"%7	c #BABAC0",
"&7	c #AFAFB8",
"*7	c #ACADB6",
"=7	c #888896",
"-7	c #46485C",
";7	c #393A53",
">7	c #363755",
",7	c #37385A",
"'7	c #47497A",
")7	c #686AA0",
"!7	c #8C8EBE",
"~7	c #B2B4E1",
"{7	c #CACCFC",
"]7	c #CBCCF7",
"^7	c #C1C3EA",
"/7	c #A5A7DA",
"(7	c #A7A8DA",
"_7	c #8082B5",
":7	c #5C5E8F",
"<7	c #797AA1",
"[7	c #9899BB",
"}7	c #B8B9E1",
"|7	c #C8CAF2",
"17	c #CFD0F5",
"27	c #D5D6F8",
"37	c #DBDCFA",
"47	c #E1E2FC",
"57	c #E6E6FD",
"67	c #EAEAFE",
"77	c #F1F1FF",
"87	c #B8B8B9",
"97	c #B8B8BB",
"07	c #BABABF",
"a7	c #C0C0C5",
"b7	c #BABBC1",
"c7	c #9E9FA8",
"d7	c #818595",
"e7	c #4C5972",
"f7	c #394866",
"g7	c #3B4A6B",
"h7	c #424C6C",
"i7	c #3C3E62",
"j7	c #42436B",
"k7	c #464874",
"l7	c #4B4D7D",
"m7	c #63659A",
"n7	c #7577A9",
"o7	c #9293BE",
"p7	c #999AC6",
"q7	c #BEC0F3",
"r7	c #D6D7F9",
"s7	c #C2C3EF",
"t7	c #B4B6E7",
"u7	c #6B6DA3",
"v7	c #5E6097",
"w7	c #57598F",
"x7	c #4B4D82",
"y7	c #4A4C7F",
"z7	c #565884",
"A7	c #787A9A",
"B7	c #8D8EAF",
"C7	c #A8A9C9",
"D7	c #C4C5D8",
"E7	c #CACADA",
"F7	c #CFCFDC",
"G7	c #D4D4DF",
"H7	c #D8D8E1",
"I7	c #DBDBE1",
"J7	c #DEDEE2",
"K7	c #E1E1E2",
"L7	c #E3E3E4",
"M7	c #B2B2B5",
"N7	c #AEAEB2",
"O7	c #9D9DA4",
"P7	c #8E8F99",
"Q7	c #848D9E",
"R7	c #7A8AA1",
"S7	c #647893",
"T7	c #495D7D",
"U7	c #353D5B",
"V7	c #3C3D5C",
"W7	c #46486F",
"X7	c #4C4E78",
"Y7	c #525483",
"Z7	c #595A8C",
"`7	c #646698",
" 8	c #7F81AD",
".8	c #ACAEDD",
"+8	c #D6D8FF",
"@8	c #D7D9FE",
"#8	c #A0A2D7",
"$8	c #7678AE",
"%8	c #4C4E84",
"&8	c #47497E",
"*8	c #424473",
"=8	c #464872",
"-8	c #787992",
";8	c #6A6A83",
">8	c #585973",
",8	c #6F6F88",
"'8	c #9596A9",
")8	c #9C9CAC",
"!8	c #A1A2AF",
"~8	c #A5A6B0",
"{8	c #A8A8B1",
"]8	c #ABABB1",
"^8	c #ADAEB1",
"/8	c #AFAFB1",
"(8	c #969697",
"_8	c #868689",
":8	c #7A7A7F",
"<8	c #71757F",
"[8	c #738194",
"}8	c #8F9DAF",
"|8	c #939FB1",
"18	c #5A6E8B",
"28	c #364462",
"38	c #32354E",
"48	c #393A56",
"58	c #414261",
"68	c #47486B",
"78	c #4E4F75",
"88	c #54567F",
"98	c #5D5F8B",
"08	c #6E6F9B",
"a8	c #9192B7",
"b8	c #C2C3F7",
"c8	c #ACAEE4",
"d8	c #999BD0",
"e8	c #8486BB",
"f8	c #404170",
"g8	c #3D3F6A",
"h8	c #444567",
"i8	c #585974",
"j8	c #747588",
"k8	c #58596D",
"l8	c #3C3C51",
"m8	c #38394C",
"n8	c #474858",
"o8	c #575865",
"p8	c #676772",
"q8	c #75767E",
"r8	c #7D7D84",
"s8	c #838385",
"t8	c #2E2F31",
"u8	c #20222A",
"v8	c #2A3B50",
"w8	c #556B83",
"x8	c #697C93",
"y8	c #465B77",
"z8	c #2C364E",
"A8	c #2D2E43",
"B8	c #34354D",
"C8	c #3D3E5A",
"D8	c #505172",
"E8	c #595A7E",
"F8	c #67688D",
"G8	c #8081A4",
"H8	c #ADAECD",
"I8	c #C9CBF5",
"J8	c #C5C7FB",
"K8	c #B8BAEE",
"L8	c #999ACE",
"M8	c #7F80B2",
"N8	c #555786",
"O8	c #3E406C",
"P8	c #3A3B61",
"Q8	c #41425C",
"R8	c #58596C",
"S8	c #676878",
"T8	c #464657",
"U8	c #2E2F3F",
"V8	c #232432",
"W8	c #1C1D28",
"X8	c #1A1A23",
"Y8	c #1E1E24",
"Z8	c #212125",
"`8	c #242426",
" 9	c #272728",
".9	c #060607",
"+9	c #0C0C10",
"@9	c #141C28",
"#9	c #25364C",
"$9	c #2B3C54",
"%9	c #28374E",
"&9	c #232536",
"*9	c #272839",
"=9	c #2E2F43",
"-9	c #36374E",
";9	c #40415B",
">9	c #4C4D69",
",9	c #5D5E7C",
"'9	c #767694",
")9	c #A7A7C0",
"!9	c #D9DAF9",
"~9	c #CCCDFC",
"{9	c #B9BBE6",
"]9	c #9495BE",
"^9	c #56577D",
"/9	c #333452",
"(9	c #31324D",
"_9	c #33344B",
":9	c #3B3C4F",
"<9	c #4F505F",
"[9	c #545460",
"}9	c #22222D",
"|9	c #181821",
"19	c #121219",
"29	c #0D0D12",
"39	c #08080B",
"49	c #020204",
"59	c #020203",
"69	c #060709",
"79	c #0C0D12",
"89	c #11131B",
"99	c #161822",
"09	c #1A1C28",
"a9	c #1E1E2B",
"b9	c #232332",
"c9	c #29293A",
"d9	c #313144",
"e9	c #3A3B51",
"f9	c #484860",
"g9	c #5E5F78",
"h9	c #84859B",
"i9	c #C1C1D6",
"j9	c #D7D8FB",
"k9	c #BBBCDD",
"l9	c #7B7B9A",
"m9	c #30314A",
"n9	c #2D2E44",
"o9	c #2B2C40",
"p9	c #2D2D3E",
"q9	c #343442",
"r9	c #42424D",
"s9	c #383842",
"t9	c #202029",
"u9	c #13131A",
"v9	c #050506",
"w9	c #070709",
"x9	c #0B0C10",
"y9	c #15151C",
"z9	c #191A23",
"A9	c #1F1F2B",
"B9	c #252633",
"C9	c #46475B",
"D9	c #66667A",
"E9	c #9192A2",
"F9	c #9494A9",
"G9	c #DDDEFA",
"H9	c #DFE0F9",
"I9	c #636479",
"J9	c #333446",
"K9	c #2B2C3C",
"L9	c #272836",
"M9	c #272833",
"N9	c #2A2A34",
"O9	c #2B2B33",
"P9	c #1B1B20",
"Q9	c #0E0F12",
"R9	c #09090B",
"S9	c #040405",
"T9	c #0C0C0E",
"U9	c #0D0D10",
"V9	c #101015",
"W9	c #1B1B23",
"X9	c #21212C",
"Y9	c #2A2A37",
"Z9	c #373745",
"`9	c #4D4D5C",
" 0	c #787986",
".0	c #8A8A98",
"+0	c #727387",
"@0	c #BABBD3",
"#0	c #E9EAFC",
"$0	c #BDBECD",
"%0	c #71717E",
"&0	c #43434E",
"*0	c #303039",
"=0	c #222227",
"-0	c #1A1A1E",
";0	c #131315",
">0	c #232324",
",0	c #252529",
"'0	c #28282E",
")0	c #1F2027",
"!0	c #3B3B46",
"~0	c #595A65",
"{0	c #868690",
"]0	c #757582",
"^0	c #656677",
"/0	c #F1F1FD",
"(0	c #CFCFD8",
"_0	c #97979E",
":0	c #5C5C61",
"<0	c #3D3E41",
"[0	c #2F3031",
"}0	c #B0B0B1",
"|0	c #CECECF",
"10	c #C4C5C7",
"20	c #99999D",
"30	c #313237",
"40	c #2F2F36",
"50	c #46464D",
"60	c #6F6F76",
"70	c #7E7E86",
"80	c #646470",
"90	c #5E5E6D",
"00	c #A0A0B1",
"a0	c #F4F4F7",
"b0	c #DEDEE0",
"c0	c #F6F6F8",
"d0	c #515256",
"e0	c #5A5A5F",
"f0	c #7F7F84",
"g0	c #6A6A71",
"h0	c #5B5C65",
"i0	c #60616C",
"j0	c #E4E5FF",
"k0	c #E5E6FF",
"l0	c #DFE0E1",
"m0	c #A7A8AA",
"n0	c #6E6E74",
"o0	c #7B7B82",
"p0	c #BEBEC7",
"q0	c #EEEEFE",
"r0	c #ECECFE",
"s0	c #F2F3F5",
"t0	c #EEEEF1",
"u0	c #F4F5F9",
"v0	c #F3F3FE",
"w0	c #F5F6FF",
"x0	c #DEE1E6",
"y0	c #EBEDF0",
"z0	c #FDFBFC",
"A0	c #F7E4EA",
"B0	c #F4D8E0",
"C0	c #EEC2D0",
"D0	c #F0C3D1",
"E0	c #F2CAD6",
"F0	c #EFBDCC",
"G0	c #EBADC0",
"H0	c #E8A4B9",
"I0	c #F6DDE5",
"J0	c #75829A",
"K0	c #838EA4",
"L0	c #FFFEFE",
"M0	c #FAEFF3",
"N0	c #F5DCE4",
"O0	c #E7A3B8",
"P0	c #E085A1",
"Q0	c #DA7293",
"R0	c #E28EA8",
"S0	c #E498AF",
"T0	c #ECB8C8",
"U0	c #EFC1CF",
"V0	c #F7DEE6",
"W0	c #FAECF1",
"X0	c #FBEFF3",
"Y0	c #FBF0F3",
"Z0	c #FBF0F4",
"`0	c #FDF9FA",
" a	c #EAECEF",
".a	c #1A2E58",
"+a	c #2D4066",
"@a	c #E8EAEE",
"#a	c #F9F1F3",
"$a	c #E29AB1",
"%a	c #D26083",
"&a	c #C62959",
"*a	c #D45B80",
"=a	c #E59CB2",
"-a	c #FEFDFD",
";a	c #7E899F",
">a	c #142954",
",a	c #939DB1",
"'a	c #F8EDF1",
")a	c #E1A2B5",
"!a	c #C7456D",
"~a	c #B6073C",
"{a	c #C22555",
"]a	c #DF8CA5",
"^a	c #FAEEF2",
"/a	c #E7EAEE",
"(a	c #283B62",
"_a	c #263960",
":a	c #F4F5F6",
"<a	c #FBF7F8",
"[a	c #F4E5EA",
"}a	c #D17C95",
"|a	c #B51E4C",
"1a	c #AF0035",
"2a	c #B61043",
"3a	c #DB87A0",
"4a	c #FAF0F3",
"5a	c #E8ECF1",
"6a	c #A4B7CA",
"7a	c #4C7198",
"8a	c #7693B0",
"9a	c #CBD6E1",
"0a	c #959EB2",
"aa	c #132954",
"ba	c #9DA6B7",
"ca	c #F0E2E5",
"da	c #CE9EA7",
"ea	c #FFFFFE",
"fa	c #FAF6F7",
"ga	c #FAF4F6",
"ha	c #D18EA3",
"ia	c #AC1C48",
"ja	c #A70033",
"ka	c #AB0034",
"la	c #BC2D58",
"ma	c #EDC7D3",
"na	c #CAD4E0",
"oa	c #738FAE",
"pa	c #2D5A87",
"qa	c #245383",
"ra	c #6485A7",
"sa	c #446C94",
"ta	c #1B4D7E",
"ua	c #497096",
"va	c #9FB3C8",
"wa	c #EEF1F4",
"xa	c #32456A",
"ya	c #394B6F",
"za	c #EFE0E3",
"Aa	c #C9929D",
"Ba	c #FFFEFF",
"Ca	c #D9B2BA",
"Da	c #C8C8CE",
"Ea	c #A6A7B3",
"Fa	c #A4A5B3",
"Ga	c #A4A5B4",
"Ha	c #B9BBC8",
"Ia	c #C8C9D5",
"Ja	c #C8C8D5",
"Ka	c #DBDCE5",
"La	c #ECECF1",
"Ma	c #FEFFFE",
"Na	c #FEFFFF",
"Oa	c #E2BFCA",
"Pa	c #A92D52",
"Qa	c #9C0030",
"Ra	c #A20031",
"Sa	c #A70032",
"Ta	c #BE4167",
"Ua	c #F7EBEF",
"Va	c #E3E8EE",
"Wa	c #9CB1C5",
"Xa	c #466E96",
"Ya	c #1B4C7E",
"Za	c #4C7399",
"`a	c #9DB2C6",
" b	c #E7EBF1",
".b	c #CCD6E1",
"+b	c #CED7E2",
"@b	c #7290AE",
"#b	c #235382",
"$b	c #6C8AAA",
"%b	c #C7D2DE",
"&b	c #DDE0E6",
"*b	c #8D97AB",
"=b	c #8C97AB",
"-b	c #8C96AB",
";b	c #8D96AB",
">b	c #E5E7EC",
",b	c #A03F51",
"'b	c #9D384B",
")b	c #95273C",
"!b	c #A24355",
"~b	c #9E384B",
"{b	c #AB5566",
"]b	c #FCFDFC",
"^b	c #E9EAEE",
"/b	c #CACBD6",
"(b	c #BABCCC",
"_b	c #9FA1B8",
":b	c #898DAA",
"<b	c #888AA9",
"[b	c #9485A3",
"}b	c #841641",
"|b	c #8E0534",
"1b	c #9B0131",
"2b	c #B73159",
"3b	c #F5E5EA",
"4b	c #F4F6F8",
"5b	c #C2CEDB",
"6b	c #6C8BAB",
"7b	c #285685",
"8b	c #2D5A88",
"9b	c #7692B0",
"0b	c #C9D3DF",
"ab	c #DEE4EB",
"bb	c #99ADC3",
"cb	c #466D96",
"db	c #1B4D7F",
"eb	c #295886",
"fb	c #C7D2DD",
"gb	c #DFE5EC",
"hb	c #A5B7CA",
"ib	c #466D95",
"jb	c #245483",
"kb	c #416A93",
"lb	c #99AEC4",
"mb	c #E5EAEF",
"nb	c #F6EFF0",
"ob	c #F2E7E9",
"pb	c #AF5A6A",
"qb	c #A95061",
"rb	c #9A3246",
"sb	c #AC5666",
"tb	c #AB5666",
"ub	c #B05E6D",
"vb	c #DDBDC3",
"wb	c #B96D89",
"xb	c #76103F",
"yb	c #582055",
"zb	c #402E69",
"Ab	c #552561",
"Bb	c #741A51",
"Cb	c #D7B8C7",
"Db	c #E2E6ED",
"Eb	c #91A8C0",
"Fb	c #426B93",
"Gb	c #1A4C7D",
"Hb	c #53789D",
"Ib	c #A3B5CA",
"Jb	c #E6EAEF",
"Kb	c #BCC9D8",
"Lb	c #6C8CAB",
"Mb	c #255483",
"Nb	c #164A7C",
"Ob	c #184B7D",
"Pb	c #426A93",
"Qb	c #94AAC1",
"Rb	c #E3E7ED",
"Sb	c #CBD5E0",
"Tb	c #7994B1",
"Ub	c #2B5987",
"Vb	c #275685",
"Wb	c #6787A8",
"Xb	c #BDCBD9",
"Yb	c #C68E99",
"Zb	c #B0606E",
"`b	c #EEDFE2",
" c	c #FDFEFE",
".c	c #D68DA3",
"+c	c #A30334",
"@c	c #9E0031",
"#c	c #9B002F",
"$c	c #930331",
"%c	c #6E164A",
"&c	c #403673",
"*c	c #343A7D",
"=c	c #62679A",
"-c	c #B3B6CF",
";c	c #F0F1F5",
">c	c #F2F5F7",
",c	c #B4C4D3",
"'c	c #5B7EA1",
")c	c #1B4C7D",
"!c	c #37628E",
"~c	c #839DB8",
"{c	c #D9E0E8",
"]c	c #8DA6BE",
"^c	c #39648F",
"/c	c #1E4F7F",
"(c	c #5D80A3",
"_c	c #B9C8D7",
":c	c #EAEDF2",
"<c	c #B0C0D2",
"[c	c #54799D",
"}c	c #1E4F80",
"|c	c #39648E",
"1c	c #8FA6BF",
"2c	c #DEE5EC",
"3c	c #FBF9FA",
"4c	c #912238",
"5c	c #891026",
"6c	c #EBD8DC",
"7c	c #FDFAFB",
"8c	c #F8EFF1",
"9c	c #F0D2DC",
"0c	c #B0083B",
"ac	c #A90033",
"bc	c #A50032",
"cc	c #A20032",
"dc	c #9F0031",
"ec	c #D09CAF",
"fc	c #9295B8",
"gc	c #3C4383",
"hc	c #31387C",
"ic	c #494E8B",
"jc	c #9DA0C0",
"kc	c #FBFCFC",
"lc	c #819BB6",
"mc	c #35608C",
"nc	c #255584",
"oc	c #5B7DA1",
"pc	c #B6C4D4",
"qc	c #E2E7ED",
"rc	c #5E7FA2",
"sc	c #215282",
"tc	c #194C7D",
"uc	c #38638E",
"vc	c #88A0BA",
"wc	c #D8E0E9",
"xc	c #D5DDE6",
"yc	c #869FBA",
"zc	c #35618D",
"Ac	c #5F81A3",
"Bc	c #B8C7D6",
"Cc	c #F2F4F7",
"Dc	c #D4A9B1",
"Ec	c #820019",
"Fc	c #B97381",
"Gc	c #E7D0D5",
"Hc	c #E5CAD0",
"Ic	c #E8D1D6",
"Jc	c #FCF6F9",
"Kc	c #C9466E",
"Lc	c #B40037",
"Mc	c #B20036",
"Nc	c #B00036",
"Oc	c #AE0035",
"Pc	c #A80033",
"Qc	c #F4E0E6",
"Rc	c #494F8B",
"Sc	c #4A508B",
"Tc	c #ADB0CB",
"Uc	c #AABBCE",
"Vc	c #567B9F",
"Wc	c #1F5181",
"Xc	c #305D8A",
"Yc	c #8CA3BC",
"Zc	c #D8DFE8",
"`c	c #DEE3EA",
" d	c #819CB7",
".d	c #36628C",
"+d	c #205281",
"@d	c #5E7FA1",
"#d	c #B3C2D2",
"$d	c #ECEEF3",
"%d	c #B2C0D2",
"&d	c #3A648F",
"*d	c #89A1BB",
"=d	c #FAF6F6",
"-d	c #9C374B",
";d	c #82001A",
">d	c #870921",
",d	c #F2E8EA",
"'d	c #A7AEBF",
")d	c #901F34",
"!d	c #830019",
"~d	c #932239",
"{d	c #EEC4D1",
"]d	c #BA033B",
"^d	c #B80039",
"/d	c #B70038",
"(d	c #B60038",
"_d	c #B20037",
":d	c #F3D9E1",
"<d	c #575D93",
"[d	c #31387B",
"}d	c #616699",
"|d	c #DBDCE7",
"1d	c #FCFDFD",
"2d	c #D0D9E3",
"3d	c #7794B1",
"4d	c #295786",
"5d	c #205180",
"6d	c #6585A7",
"7d	c #BFCCDA",
"8d	c #ACBDCF",
"9d	c #52769B",
"0d	c #2C5A87",
"ad	c #8AA2BB",
"bd	c #D6DDE6",
"cd	c #E4E8EE",
"dd	c #87A0BA",
"ed	c #3A658F",
"fd	c #174A7C",
"gd	c #5B7DA0",
"hd	c #AFBFD0",
"id	c #DAB4BB",
"jd	c #82011A",
"kd	c #BE7B88",
"ld	c #FBFBFC",
"md	c #F1F2F5",
"nd	c #9FA6B9",
"od	c #F2F4F5",
"pd	c #F3F4F6",
"qd	c #F2F3F6",
"rd	c #925E71",
"sd	c #D3A6AD",
"td	c #D9B2B8",
"ud	c #D9B1B8",
"vd	c #DEBBC1",
"wd	c #DA7393",
"xd	c #BD003A",
"yd	c #BC003A",
"zd	c #BB0039",
"Ad	c #BA0039",
"Bd	c #B90039",
"Cd	c #B60037",
"Dd	c #DF93AB",
"Ed	c #DEE0E9",
"Fd	c #474D89",
"Gd	c #424987",
"Hd	c #BABDD3",
"Id	c #EAEEF2",
"Jd	c #A0B3C7",
"Kd	c #497097",
"Ld	c #215080",
"Md	c #436B93",
"Nd	c #96ACC2",
"Od	c #DEE3EB",
"Pd	c #D0D8E2",
"Qd	c #7894B1",
"Rd	c #305D89",
"Sd	c #205181",
"Td	c #50759B",
"Ud	c #B0C0D1",
"Vd	c #BDCAD8",
"Wd	c #6181A3",
"Xd	c #265584",
"Yd	c #325F8B",
"Zd	c #829CB7",
"`d	c #9F3D51",
" e	c #8E1930",
".e	c #F3EAEB",
"+e	c #C6CBD6",
"@e	c #33466B",
"#e	c #36486D",
"$e	c #36486E",
"%e	c #36476E",
"&e	c #B5BCC9",
"*e	c #D14972",
"=e	c #BE003B",
"-e	c #BE013B",
";e	c #C52F5D",
">e	c #FAF0F4",
",e	c #B0B3CB",
"'e	c #30377A",
")e	c #394081",
"!e	c #B2B4CC",
"~e	c #F1F4F7",
"{e	c #3E6790",
"]e	c #215181",
"^e	c #6987A8",
"/e	c #C2CDDA",
"(e	c #A3B5C9",
"_e	c #1A4D7E",
":e	c #345F8B",
"<e	c #7A95B2",
"[e	c #DBE1E9",
"}e	c #93A9C0",
"|e	c #335E8B",
"1e	c #205080",
"2e	c #C5D0DD",
"3e	c #F1E4E6",
"4e	c #B9727F",
"5e	c #B76E7B",
"6e	c #B76E7A",
"7e	c #E6CDD1",
"8e	c #D4D8E0",
"9e	c #65738F",
"0e	c #465779",
"ae	c #64738F",
"be	c #8B96AB",
"ce	c #F9F2F4",
"de	c #CC98A2",
"ee	c #E6CFD4",
"fe	c #CA2B5C",
"ge	c #C0003B",
"he	c #BF003B",
"ie	c #BC013A",
"je	c #DA7795",
"ke	c #FDFCFD",
"le	c #4E5489",
"me	c #2F3779",
"ne	c #353C7E",
"oe	c #CBCDDE",
"pe	c #C3CEDC",
"qe	c #F0F3F6",
"re	c #DDE2EA",
"se	c #8DA4BC",
"te	c #819DB7",
"ue	c #B9C7D6",
"ve	c #F9FAFB",
"we	c #C6D1DE",
"xe	c #F3F6F8",
"ye	c #AAB0C1",
"ze	c #F9F5F6",
"Ae	c #A64D5D",
"Be	c #8A1129",
"Ce	c #AA5363",
"De	c #CB2F5F",
"Ee	c #BF0941",
"Fe	c #E395AE",
"Ge	c #FEFDFE",
"He	c #8E92B2",
"Ie	c #2D3573",
"Je	c #2F3778",
"Ke	c #4D538D",
"Le	c #D2DCE6",
"Me	c #B0C2D3",
"Ne	c #BAC9D8",
"Oe	c #EFF0F2",
"Pe	c #E4C7CD",
"Qe	c #BF7E89",
"Re	c #EEDEE1",
"Se	c #BD7985",
"Te	c #D24E77",
"Ue	c #C00740",
"Ve	c #DF87A2",
"We	c #FCF8F9",
"Xe	c #A9ABC2",
"Ye	c #2B316D",
"Ze	c #2D3473",
"`e	c #2F3678",
" f	c #9498BA",
".f	c #809BB6",
"+f	c #1C4F7F",
"@f	c #37648F",
"#f	c #FDFEFD",
"$f	c #F2F3F4",
"%f	c #B8BFCB",
"&f	c #C7CCD5",
"*f	c #C9CDD6",
"=f	c #D6ACB4",
"-f	c #F4EAEC",
";f	c #CB949F",
">f	c #F8F2F3",
",f	c #D2A6AE",
"'f	c #DF809D",
")f	c #D14B73",
"!f	c #F4D6DF",
"~f	c #A1A3BA",
"{f	c #292E66",
"]f	c #2B316C",
"^f	c #2D3472",
"/f	c #2F3677",
"(f	c #30387B",
"_f	c #484E8B",
":f	c #B7BECB",
"<f	c #142854",
"[f	c #AAB3C2",
"}f	c #7A859E",
"|f	c #172C57",
"1f	c #1D315A",
"2f	c #CFD4DC",
"3f	c #DDBCC2",
"4f	c #D7AFB7",
"5f	c #FCFBFB",
"6f	c #C88F99",
"7f	c #F0E3E5",
"8f	c #AB5565",
"9f	c #B16171",
"0f	c #F4D5DF",
"af	c #C20840",
"bf	c #C41349",
"cf	c #923563",
"df	c #36275C",
"ef	c #292D65",
"ff	c #2B306B",
"gf	c #2D3371",
"hf	c #2E3676",
"if	c #333A7D",
"jf	c #C8CADC",
"kf	c #E3E9EF",
"lf	c #34608C",
"mf	c #ACBECF",
"nf	c #EEEFF2",
"of	c #9AA3B5",
"pf	c #EDEEF1",
"qf	c #8E98AD",
"rf	c #9EA7B8",
"sf	c #AFB5C4",
"tf	c #AFB6C5",
"uf	c #B1B8C6",
"vf	c #F4EBED",
"wf	c #962A3E",
"xf	c #A6495B",
"yf	c #972B3F",
"zf	c #B16373",
"Af	c #AF5E6D",
"Bf	c #8E1A30",
"Cf	c #850720",
"Df	c #EAD6D9",
"Ef	c #FEFBFC",
"Ff	c #D65B81",
"Gf	c #B1053E",
"Hf	c #7D144C",
"If	c #42275E",
"Jf	c #2B306A",
"Kf	c #2C3370",
"Lf	c #2E3575",
"Mf	c #2F377A",
"Nf	c #969ABD",
"Of	c #CFD9E3",
"Pf	c #C8D4E0",
"Qf	c #CAD5E0",
"Rf	c #C9D5E0",
"Sf	c #CAD6E1",
"Tf	c #C9D4E0",
"Uf	c #EBEFF3",
"Vf	c #DFE1E6",
"Wf	c #E6CDD2",
"Xf	c #870B23",
"Yf	c #870A21",
"Zf	c #9F3D4F",
"`f	c #E1C4C8",
" g	c #F8E9EE",
".g	c #C6184D",
"+g	c #9E0D45",
"@g	c #771953",
"#g	c #4B2A65",
"$g	c #363372",
"%g	c #8084AD",
"&g	c #3F6992",
"*g	c #3E6992",
"=g	c #9EB3C8",
"-g	c #809BB7",
";g	c #3F6892",
">g	c #C3D0DC",
",g	c #C1CEDB",
"'g	c #577A9E",
")g	c #6285A6",
"!g	c #9EB3C7",
"~g	c #E4E9EF",
"{g	c #EEEFF3",
"]g	c #86A1BB",
"^g	c #D1D5DD",
"/g	c #A6AEBF",
"(g	c #FCF9F9",
"_g	c #F2E6E7",
":g	c #FBF8F9",
"<g	c #EDB9C9",
"[g	c #C41248",
"}g	c #BC023C",
"|g	c #B60440",
"1g	c #BA2154",
"2g	c #DB6F90",
"3g	c #E28EA7",
"4g	c #E8A6BB",
"5g	c #F4D5DE",
"6g	c #F6E0E7",
"7g	c #F8E6EC",
"8g	c #FCF6F8",
"9g	c #E1E7ED",
"0g	c #809AB5",
"ag	c #51749A",
"bg	c #FEFEFD",
"cg	c #B5C6D5",
"dg	c #AFC0D1",
"eg	c #214F80",
"fg	c #426B94",
"gg	c #8AA3BC",
"hg	c #CDD5E1",
"ig	c #D7DEE7",
"jg	c #6D8DAC",
"kg	c #D0D4DC",
"lg	c #253961",
"mg	c #182D56",
"ng	c #B6BCC9",
"og	c #F6EEEF",
"pg	c #FDFCFC",
"qg	c #DEBDC3",
"rg	c #BE7C88",
"sg	c #D0A0A9",
"tg	c #E9AEC0",
"ug	c #C51349",
"vg	c #C1043E",
"wg	c #C30E46",
"xg	c #C4164B",
"yg	c #E9AABE",
"zg	c #D9DFE8",
"Ag	c #6887A7",
"Bg	c #436B94",
"Cg	c #A8B9CD",
"Dg	c #9BADC4",
"Eg	c #164A7B",
"Fg	c #D2DCE5",
"Gg	c #6E8DAC",
"Hg	c #818CA3",
"Ig	c #CACFD8",
"Jg	c #C1C7D2",
"Kg	c #AEB5C3",
"Lg	c #E2C7CC",
"Mg	c #BB7482",
"Ng	c #F9F4F5",
"Og	c #DBB6BD",
"Pg	c #85081F",
"Qg	c #922339",
"Rg	c #C48994",
"Sg	c #F0C7D4",
"Tg	c #C9285A",
"Ug	c #E8A1B7",
"Vg	c #C0CBDA",
"Wg	c #5F82A5",
"Xg	c #91A7BF",
"Yg	c #8AA4BC",
"Zg	c #17497C",
"`g	c #37618D",
" h	c #708CAC",
".h	c #B6C6D5",
"+h	c #D3DCE6",
"@h	c #6989AA",
"#h	c #A7ADBD",
"$h	c #E1E4E9",
"%h	c #F0F1F3",
"&h	c #CF9FA9",
"*h	c #EEDDE1",
"=h	c #F4E9EC",
"-h	c #94253B",
";h	c #962B40",
">h	c #FBF9F9",
",h	c #B46977",
"'h	c #F8E8EC",
")h	c #D06084",
"!h	c #B9033D",
"~h	c #B5C5D5",
"{h	c #5B7EA2",
"]h	c #416B94",
"^h	c #D8DFE7",
"/h	c #8BA4BD",
"(h	c #8AA3BD",
"_h	c #174A7B",
":h	c #204F80",
"<h	c #6082A4",
"[h	c #53769B",
"}h	c #909AAE",
"|h	c #AAB2C0",
"1h	c #CFD3DB",
"2h	c #394A6E",
"3h	c #D2D6DE",
"4h	c #D1A3AC",
"5h	c #E0C2C8",
"6h	c #B76E7C",
"7h	c #810119",
"8h	c #D5AAB2",
"9h	c #C1828D",
"0h	c #F1F1F3",
"ah	c #AAABBA",
"bh	c #4D4F6B",
"ch	c #3C193E",
"dh	c #93093A",
"eh	c #BD013B",
"fh	c #E7A2B7",
"gh	c #456B94",
"hh	c #3C6690",
"ih	c #D2DBE5",
"jh	c #8AA4BD",
"kh	c #89A3BC",
"lh	c #5F81A4",
"mh	c #B6C5D5",
"nh	c #C4CEDB",
"oh	c #426C95",
"ph	c #A9B1C0",
"qh	c #304369",
"rh	c #5C6A88",
"sh	c #415275",
"th	c #79859D",
"uh	c #576685",
"vh	c #172C55",
"wh	c #5E6D8A",
"xh	c #F2E6E8",
"yh	c #982E41",
"zh	c #9F3E50",
"Ah	c #820119",
"Bh	c #AE5C6B",
"Ch	c #FAF5F6",
"Dh	c #B8717E",
"Eh	c #D7D9E3",
"Fh	c #9D9FB7",
"Gh	c #696D8E",
"Hh	c #2A2E5B",
"Ih	c #1F244F",
"Jh	c #1C2149",
"Kh	c #1A1E43",
"Lh	c #181B3C",
"Mh	c #3C1538",
"Nh	c #7F0B38",
"Oh	c #B7023A",
"Ph	c #E8A5BA",
"Qh	c #33608C",
"Rh	c #265383",
"Sh	c #86A0BA",
"Th	c #5E82A4",
"Uh	c #A4B4C9",
"Vh	c #ADBDCF",
"Wh	c #969FB3",
"Xh	c #37486D",
"Yh	c #23375F",
"Zh	c #21365D",
"`h	c #2E4166",
" i	c #74819A",
".i	c #E7D2D6",
"+i	c #B76D7C",
"@i	c #C68B96",
"#i	c #E7D1D5",
"$i	c #BCBED4",
"%i	c #B7BAD1",
"&i	c #B6B9D0",
"*i	c #ACAFCA",
"=i	c #9497B9",
"-i	c #8085AE",
";i	c #52598F",
">i	c #3C427D",
",i	c #323872",
"'i	c #292F67",
")i	c #262C61",
"!i	c #24295B",
"~i	c #222756",
"{i	c #202450",
"]i	c #1D224A",
"^i	c #1A1F43",
"/i	c #181C3D",
"(i	c #171937",
"_i	c #211531",
":i	c #570E32",
"<i	c #890735",
"[i	c #B4023A",
"}i	c #BF013B",
"|i	c #E9A7BB",
"1i	c #AEBED0",
"2i	c #33608B",
"3i	c #B5C2D3",
"4i	c #7D97B4",
"5i	c #718DAC",
"6i	c #D4DDE6",
"7i	c #5C7FA2",
"8i	c #8DA5BE",
"9i	c #A7BACD",
"0i	c #F4F6F7",
"ai	c #F1F3F5",
"bi	c #E1E4EA",
"ci	c #DFE2E8",
"di	c #F5ECED",
"ei	c #E0C2C7",
"fi	c #EDDCDF",
"gi	c #646A9C",
"hi	c #2C326E",
"ii	c #292F68",
"ji	c #272C62",
"ki	c #242A5C",
"li	c #222757",
"mi	c #202551",
"ni	c #1B1F44",
"oi	c #181C3E",
"pi	c #161938",
"qi	c #131631",
"ri	c #11132A",
"si	c #220F27",
"ti	c #3B0A26",
"ui	c #6F042C",
"vi	c #920534",
"wi	c #B90B41",
"xi	c #C1053E",
"yi	c #96ABC2",
"zi	c #6586A7",
"Ai	c #5F82A4",
"Bi	c #D3DCE5",
"Ci	c #17497B",
"Di	c #F7F7F9",
"Ei	c #466C95",
"Fi	c #A1B4C9",
"Gi	c #3E6892",
"Hi	c #838DA4",
"Ii	c #F5F5F6",
"Ji	c #C07F8B",
"Ki	c #FAF8F8",
"Li	c #EEDDE0",
"Mi	c #902035",
"Ni	c #83021B",
"Oi	c #8B1127",
"Pi	c #DDBBC1",
"Qi	c #656A9D",
"Ri	c #303779",
"Si	c #2D3574",
"Ti	c #2C326F",
"Ui	c #2A3069",
"Vi	c #272D63",
"Wi	c #242A5D",
"Xi	c #232858",
"Yi	c #212552",
"Zi	c #1E234C",
"`i	c #1B2046",
" j	c #191C3F",
".j	c #171A39",
"+j	c #141732",
"@j	c #11142B",
"#j	c #0E1025",
"$j	c #0D0F21",
"%j	c #64656F",
"&j	c #EBE4E7",
"*j	c #F3D1DC",
"=j	c #E9ACBF",
"-j	c #E391AB",
";j	c #D65D83",
">j	c #D14872",
",j	c #CD3664",
"'j	c #C92759",
")j	c #C92457",
"!j	c #C71B4F",
"~j	c #C41047",
"{j	c #C10941",
"]j	c #E9A9BC",
"^j	c #A8BACD",
"/j	c #D1DBE5",
"(j	c #DFE3EB",
"_j	c #819BB7",
":j	c #889FBA",
"<j	c #295585",
"[j	c #838DA5",
"}j	c #EBEDF1",
"|j	c #D2A6AF",
"1j	c #EAD4D8",
"2j	c #A64B5B",
"3j	c #8A1229",
"4j	c #D7B1B9",
"5j	c #EAD7DB",
"6j	c #B16270",
"7j	c #646A9D",
"8j	c #2A306A",
"9j	c #282D64",
"0j	c #252B5F",
"aj	c #232859",
"bj	c #212553",
"cj	c #1E234D",
"dj	c #1C2046",
"ej	c #191D41",
"fj	c #171A3A",
"gj	c #141734",
"hj	c #333549",
"ij	c #AEAFB5",
"jj	c #FCFCFB",
"kj	c #FEF9FA",
"lj	c #FDF5F7",
"mj	c #FCF4F7",
"nj	c #FCF1F5",
"oj	c #FBEEF2",
"pj	c #FAECF0",
"qj	c #FDF8F9",
"rj	c #2B5886",
"sj	c #EEEFF4",
"tj	c #4E7299",
"uj	c #CAD4DF",
"vj	c #34608B",
"wj	c #6988A9",
"xj	c #7D98B4",
"yj	c #CBCFD9",
"zj	c #455576",
"Aj	c #2B3D64",
"Bj	c #455577",
"Cj	c #35476C",
"Dj	c #BFC4D0",
"Ej	c #CE9DA7",
"Fj	c #ECD9DD",
"Gj	c #D1A5AD",
"Hj	c #BE7C89",
"Ij	c #C0818D",
"Jj	c #FDFBFB",
"Kj	c #2D3370",
"Lj	c #282D65",
"Mj	c #23295A",
"Nj	c #222654",
"Oj	c #1F234D",
"Pj	c #1C2148",
"Qj	c #292D4E",
"Rj	c #8A8C9B",
"Sj	c #E8E8EA",
"Tj	c #8BA3BC",
"Uj	c #E4E6ED",
"Vj	c #A1B5C9",
"Wj	c #5E81A4",
"Xj	c #39638E",
"Yj	c #B3C1D2",
"Zj	c #D0DAE4",
"`j	c #F5F5F8",
" k	c #2E5C89",
".k	c #7D99B5",
"+k	c #D1D4DD",
"@k	c #5A6886",
"#k	c #33456B",
"$k	c #505F80",
"%k	c #505F7F",
"&k	c #505E7F",
"*k	c #516080",
"=k	c #7C88A1",
"-k	c #E7CED4",
";k	c #A44658",
">k	c #BC7986",
",k	c #880F26",
"'k	c #962A3F",
")k	c #F7F0F2",
"!k	c #B76F7C",
"~k	c #2C3371",
"{k	c #262B61",
"]k	c #242A5B",
"^k	c #4C5076",
"/k	c #9D9FB1",
"(k	c #EFEFF1",
"_k	c #E2E8EE",
":k	c #8CA2BC",
"<k	c #53779D",
"[k	c #A6B9CC",
"}k	c #BCC7D7",
"|k	c #265685",
"1k	c #EFF1F5",
"2k	c #808AA2",
"3k	c #CD9BA5",
"4k	c #952A3F",
"5k	c #A34556",
"6k	c #EAD6DA",
"7k	c #E4C9CE",
"8k	c #DCB9BF",
"9k	c #373D79",
"0k	c #585D8B",
"ak	c #8D90AD",
"bk	c #D5D6DF",
"ck	c #F7F8F8",
"dk	c #6E8AAA",
"ek	c #3A638E",
"fk	c #A4B8CB",
"gk	c #A9BBCD",
"hk	c #7592B0",
"ik	c #FCFAFA",
"jk	c #32397D",
"kk	c #353D7E",
"lk	c #3F4685",
"mk	c #60669A",
"nk	c #878BB1",
"ok	c #B9BCD2",
"pk	c #F8F8F9",
"qk	c #235483",
"rk	c #E0E6ED",
"sk	c #C1CCDA",
"tk	c #7C98B4",
"uk	c #8EA4BD",
"vk	c #E1E8ED",
"wk	c #245584",
"xk	c #587CA0",
"yk	c #5D7EA2",
"zk	c #D3DDE6",
"Ak	c #BCC3CE",
"Bk	c #D2D6DF",
"Ck	c #D3D7DF",
"Dk	c #F7EFF1",
"Ek	c #D8AFB6",
"Fk	c #CE9CA5",
"Gk	c #CE9BA4",
"Hk	c #D5A8B0",
"Ik	c #777DA9",
"Jk	c #4E548F",
"Kk	c #545992",
"Lk	c #5A6096",
"Mk	c #6D73A2",
"Nk	c #7579A7",
"Ok	c #9599BC",
"Pk	c #B5B8D1",
"Qk	c #C2C4D7",
"Rk	c #5C80A3",
"Sk	c #1D4E7F",
"Tk	c #D3DAE4",
"Uk	c #ACBCCF",
"Vk	c #7B98B4",
"Wk	c #7E99B5",
"Xk	c #A6BACC",
"Yk	c #E1E7EE",
"Zk	c #3F6690",
"`k	c #50769C",
" l	c #B6BDCA",
".l	c #152A55",
"+l	c #A9B1C1",
"@l	c #7B879F",
"#l	c #1A2F59",
"$l	c #1A2F5A",
"%l	c #20345D",
"&l	c #D0D4DD",
"*l	c #982E42",
"=l	c #84041C",
"-l	c #83031A",
";l	c #F6F6F9",
">l	c #4A6F97",
",l	c #C6D2DE",
"'l	c #A8BBCD",
")l	c #7895B2",
"!l	c #EBEEF3",
"~l	c #E5E9EF",
"{l	c #7C98B5",
"]l	c #A5B8CB",
"^l	c #D8DEE8",
"/l	c #929CB0",
"(l	c #E7E9ED",
"_l	c #8791A7",
":l	c #99A2B4",
"<l	c #A4ACBC",
"[l	c #A5ACBD",
"}l	c #A7AEBE",
"|l	c #ECEEF1",
"1l	c #D6AEB5",
"2l	c #C78F99",
"3l	c #E5CCD1",
"4l	c #E8D0D5",
"5l	c #BF7F8C",
"6l	c #EBD7DB",
"7l	c #1C4E7F",
"8l	c #C7D3DF",
"9l	c #A9BCCE",
"0l	c #6685A6",
"al	c #2A5987",
"bl	c #97ABC2",
"cl	c #38648F",
"dl	c #547A9F",
"el	c #C7D1DE",
"fl	c #DBDFE3",
"gl	c #C9919D",
"hl	c #F5E8EA",
"il	c #DDE4EB",
"jl	c #D9E1E9",
"kl	c #F5F7F9",
"ll	c #FAFBFC",
"ml	c #DBE3EA",
"nl	c #E9EEF2",
"ol	c #F4F7F9",
"pl	c #DEE4EC",
"ql	c #D8E1E9",
"rl	c #EDEFF1",
"sl	c #959EB1",
"tl	c #7D89A0",
"ul	c #CBD0D9",
"vl	c #DDBBC2",
"wl	c #A14052",
"xl	c #BF7F8B",
"yl	c #E5CDD0",
"zl	c #B46877",
"Al	c #EFE2E5",
"Bl	c #F3E7E9",
"Cl	c #F6EDEE",
"Dl	c #275786",
"El	c #ADBED0",
"Fl	c #8893A9",
"Gl	c #DBDFE4",
"Hl	c #5F6D8A",
"Il	c #192E58",
"Jl	c #465778",
"Kl	c #3E4F73",
"Ll	c #DFE2E7",
"Ml	c #F7F1F3",
"Nl	c #9E3B4C",
"Ol	c #922035",
"Pl	c #9E3A4D",
"Ql	c #8C152D",
"Rl	c #B97481",
"Sl	c #F3F5F8",
"Tl	c #ABBDD0",
"Ul	c #A5B9CD",
"Vl	c #DCE4EB",
"Wl	c #B4BBC8",
"Xl	c #C1C6D1",
"Yl	c #B36170",
"Zl	c #B16271",
"`l	c #F4ECED",
" m	c #6184A6",
".m	c #7493B0",
"+m	c #FAFAFB",
"@m	c #7F8AA2",
"#m	c #F8F9FA",
"$m	c #E0E2E8",
"%m	c #314368",
"&m	c #3E5072",
"*m	c #EDEFF2",
"=m	c #D7DBE1",
"-m	c #ADB4C3",
";m	c #EBD8DD",
">m	c #6B8BAB",
",m	c #7E9AB5",
"'m	c #9FA8B9",
")m	c #3F5074",
"!m	c #304268",
"~m	c #A8AFBE",
"{m	c #CCD0D9",
"]m	c #E9D4D8",
"^m	c #CB95A0",
"/m	c #C8909B",
"(m	c #C9909B",
"_m	c #C8909A",
":m	c #BE7E8B",
"<m	c #B86C7B",
"[m	c #ABB2C0",
"}m	c #8792A6",
"|m	c #BAC0CB",
"1m	c #FAFBFB",
"2m	c #E5CACF",
"3m	c #850A20",
"4m	c #85061F",
"5m	c #890F27",
"6m	c #8E1B30",
"7m	c #D0A1A9",
"8m	c #AFB7C5",
"9m	c #C88E9B",
"0m	c #9B374A",
"am	c #EFDDE0",
"bm	c #F8F1F3",
"cm	c #485778",
"dm	c #6C7892",
"em	c #E2C4C9",
"fm	c #BE7D88",
"gm	c #C4D1DE",
"hm	c #D6DFE8",
"im	c #BBC8D7",
"jm	c #DDE5EC",
"km	c #EFF2F5",
"lm	c #DBE2EA",
"mm	c #EDF0F4",
"nm	c #D8E0E8",
"om	c #C5D2DE",
"pm	c #F1F3F6",
"qm	c #DAE2EA",
"rm	c #C5D1DE",
"sm	c #EEF1F5",
"tm	c #B5C4D4",
"um	c #99AFC5",
"vm	c #DDE4EC",
"wm	c #D6DFE7",
"xm	c #ECF1F4",
"ym	c #838FA4",
"zm	c #CF9EA7",
"Am	c #2B5887",
"Bm	c #ECF0F4",
"Cm	c #7E98B4",
"Dm	c #7B99B5",
"Em	c #C2CCDA",
"Fm	c #A8B9CC",
"Gm	c #849EB8",
"Hm	c #2E5B88",
"Im	c #2E5A88",
"Jm	c #16497B",
"Km	c #2C5A88",
"Lm	c #7893B1",
"Mm	c #EDF1F5",
"Nm	c #A9BACD",
"Om	c #D4DBE5",
"Pm	c #7C99B5",
"Qm	c #B6C6D6",
"Rm	c #6D8EAD",
"Sm	c #D2DAE4",
"Tm	c #6D8DAD",
"Um	c #6E8EAD",
"Vm	c #CBD0D8",
"Wm	c #67748F",
"Xm	c #949FB2",
"Ym	c #A6AEBD",
"Zm	c #A8B0BF",
"`m	c #ECEEF0",
" n	c #CE9DA6",
".n	c #BA7380",
"+n	c #CD9BA4",
"@n	c #D5AAB3",
"#n	c #98ADC3",
"$n	c #335F8B",
"%n	c #ECEFF4",
"&n	c #B1C0D1",
"*n	c #7D99B4",
"=n	c #96A8C1",
"-n	c #AEBCCF",
";n	c #B8C4D5",
">n	c #587DA0",
",n	c #B7C5D5",
"'n	c #577B9F",
")n	c #E9EDF2",
"!n	c #2F5C89",
"~n	c #A0B2C7",
"{n	c #436C94",
"]n	c #355F8B",
"^n	c #D1D9E3",
"/n	c #7591AF",
"(n	c #718BAB",
"_n	c #AFBCCF",
":n	c #E6EAF0",
"<n	c #CCD5E1",
"[n	c #6C89AA",
"}n	c #7E89A1",
"|n	c #1F335C",
"1n	c #1E335C",
"2n	c #24385F",
"3n	c #922136",
"4n	c #880E25",
"5n	c #992F44",
"6n	c #9FB2C7",
"7n	c #184B7C",
"8n	c #ADBECF",
"9n	c #D6DEE7",
"0n	c #D9E0E9",
"an	c #728FAE",
"bn	c #CED8E2",
"cn	c #8CA5BD",
"dn	c #E7ECF1",
"en	c #A6BACD",
"fn	c #A0B0C7",
"gn	c #E9EBEF",
"hn	c #CC97A1",
"in	c #FBF7F9",
"jn	c #275684",
"kn	c #487097",
"ln	c #9CB0C6",
"mn	c #4C7299",
"nn	c #B0BED0",
"on	c #9FB0C7",
"pn	c #F5ECEE",
"qn	c #4F769C",
"rn	c #EEF2F5",
"sn	c #1D4E7E",
"tn	c #98AEC4",
"un	c #6486A7",
"vn	c #174B7D",
"wn	c #7F9AB6",
"xn	c #BFCBD9",
"yn	c #1F5080",
"zn	c #CCD4E0",
"An	c #EFF0F5",
"Bn	c #D9DFE7",
"Cn	c #A0B3C8",
"Dn	c #3A648E",
"En	c #9FB0C6",
"Fn	c #5A7DA1",
"Gn	c #EEF0F4",
"Hn	c #586785",
"In	c #2E4167",
"Jn	c #CDD2DB",
"Kn	c #E7EBF0",
"Ln	c #4D749A",
"Mn	c #9DB1C6",
"Nn	c #C2CFDC",
"On	c #194B7D",
"Pn	c #718EAD",
"Qn	c #315E8A",
"Rn	c #3C658F",
"Sn	c #174B7C",
"Tn	c #315D8A",
"Un	c #839AB6",
"Vn	c #6A8BAB",
"Wn	c #F7F9FA",
"Xn	c #F1F3F7",
"Yn	c #4B7097",
"Zn	c #1A4C7E",
"`n	c #285785",
" o	c #6788A8",
".o	c #CAD3DF",
"+o	c #A0B1C7",
"@o	c #1E5080",
"#o	c #315D89",
"$o	c #D1D7E2",
"%o	c #8C97AC",
"&o	c #6C7993",
"*o	c #6E7B96",
"=o	c #EBEFF2",
"-o	c #4C7398",
";o	c #9AAFC4",
">o	c #295785",
",o	c #A5B8CC",
"'o	c #9BB0C6",
")o	c #6E8BAC",
"!o	c #7F99B5",
"~o	c #B2C0D1",
"{o	c #39658F",
"]o	c #215081",
"^o	c #D7DFE7",
"/o	c #6082A5",
"(o	c #37628D",
"_o	c #9BA4B6",
":o	c #E0E3E8",
"<o	c #EEF0F3",
"[o	c #1B4E7F",
"}o	c #9DB2C7",
"|o	c #7E98B5",
"1o	c #95ABC2",
"2o	c #E6EBF0",
"3o	c #54779C",
"4o	c #8CA2BB",
"5o	c #C1CDDB",
"6o	c #A1A9BA",
"7o	c #D5D9E0",
"8o	c #E6E8ED",
"9o	c #949DB1",
"0o	c #96A0B3",
"ao	c #AFB6C4",
"bo	c #B3BAC8",
"co	c #A9B0C1",
"do	c #D4D8DF",
"eo	c #C3C9D3",
"fo	c #EFF0F3",
"go	c #97A1B3",
"ho	c #BEC4CF",
"io	c #DADEE3",
"jo	c #939CB1",
"ko	c #959FB2",
"lo	c #A3ABBC",
"mo	c #CCD1DA",
"no	c #BEC3CF",
"oo	c #828DA4",
"po	c #828CA4",
"qo	c #98A1B4",
"ro	c #A1AABB",
"so	c #7F8BA2",
"to	c #A2AABB",
"uo	c #E5E7EB",
"vo	c #B1B9C6",
"wo	c #BEC4CE",
"xo	c #CFD3DA",
"yo	c #939CB0",
"zo	c #969FB2",
"Ao	c #ADB6C4",
"Bo	c #DADDE3",
"Co	c #949EB0",
"Do	c #99A2B5",
"Eo	c #CCD0DA",
"Fo	c #BEC3CE",
"Go	c #C7CCD6",
"Ho	c #B2B9C7",
"Io	c #CFD3DC",
"Jo	c #5D81A3",
"Ko	c #EFF2F6",
"Lo	c #476D95",
"Mo	c #7D97B3",
"No	c #C3CDDB",
"Oo	c #718FAD",
"Po	c #EBEEF2",
"Qo	c #C8D2DE",
"Ro	c #7F9BB6",
"So	c #8590A6",
"To	c #7E89A2",
"Uo	c #ACB5C3",
"Vo	c #77839B",
"Wo	c #D8DBE2",
"Xo	c #AAB2C2",
"Yo	c #475779",
"Zo	c #CBD0DA",
"`o	c #818DA4",
" p	c #D6DAE1",
".p	c #717D98",
"+p	c #A3ABBA",
"@p	c #667290",
"#p	c #CCD1DB",
"$p	c #7B859E",
"%p	c #BBC1CE",
"&p	c #A5AFBE",
"*p	c #A7AFBF",
"=p	c #E8E9EE",
"-p	c #687592",
";p	c #596885",
">p	c #DEE1E7",
",p	c #76839C",
"'p	c #DBDEE4",
")p	c #D3D6DD",
"!p	c #687590",
"~p	c #E8E9ED",
"{p	c #AEB4C4",
"]p	c #E7E9EE",
"^p	c #6F7A97",
"/p	c #D6DAE2",
"(p	c #DADEE4",
"_p	c #5E6D89",
":p	c #DEE2E7",
"<p	c #99A1B4",
"[p	c #A6ADBC",
"}p	c #C9CED6",
"|p	c #E1E3E9",
"1p	c #475778",
"2p	c #808CA3",
"3p	c #78869D",
"4p	c #6A7791",
"5p	c #BEC4D0",
"6p	c #B5BBC8",
"7p	c #9BA5B6",
"8p	c #CDD1DA",
"9p	c #4C5C7C",
"0p	c #76819B",
"ap	c #F3F4F7",
"bp	c #687692",
"cp	c #8D96AC",
"dp	c #435376",
"ep	c #F3F4F5",
"fp	c #3C4E72",
"gp	c #9BA4B7",
"hp	c #2B5986",
"ip	c #3E6791",
"jp	c #869EB9",
"kp	c #3B658F",
"lp	c #D3DBE5",
"mp	c #C0CDDA",
"np	c #5C7EA1",
"op	c #F7F8FA",
"pp	c #97ACC2",
"qp	c #859FB9",
"rp	c #425375",
"sp	c #162A55",
"tp	c #162B55",
"up	c #2A3E64",
"vp	c #C1C7D1",
"wp	c #CAD0DA",
"xp	c #8A95A9",
"yp	c #E6E9EE",
"zp	c #7D8AA2",
"Ap	c #7D89A1",
"Bp	c #6C7894",
"Cp	c #A2A9BB",
"Dp	c #A5AFBD",
"Ep	c #B3BBC9",
"Fp	c #79859E",
"Gp	c #78849C",
"Hp	c #E3E6EB",
"Ip	c #8B96AA",
"Jp	c #D3D6DF",
"Kp	c #D4D6DE",
"Lp	c #959FB1",
"Mp	c #6D7B96",
"Np	c #E2E5EA",
"Op	c #E8EAED",
"Pp	c #F3F5F6",
"Qp	c #75819A",
"Rp	c #75809A",
"Sp	c #D9DDE2",
"Tp	c #727F97",
"Up	c #8993A8",
"Vp	c #C0C6D1",
"Wp	c #7C879E",
"Xp	c #E2E4EA",
"Yp	c #B8BECB",
"Zp	c #596886",
"`p	c #8E97AD",
" q	c #8893A8",
".q	c #ABB3C1",
"+q	c #8590A7",
"@q	c #9CA4B7",
"#q	c #DAE1E9",
"$q	c #225282",
"%q	c #4E759B",
"&q	c #DEE5EB",
"*q	c #97ACC3",
"=q	c #9FB1C7",
"-q	c #B2B8C6",
";q	c #8892A9",
">q	c #A5ADBD",
",q	c #E6E8EC",
"'q	c #5B6987",
")q	c #919BAF",
"!q	c #BDC3CE",
"~q	c #62708C",
"{q	c #A4ACBD",
"]q	c #586686",
"^q	c #78839C",
"/q	c #7C86A0",
"(q	c #5E6C8A",
"_q	c #DADDE4",
":q	c #A5AEBD",
"<q	c #73809A",
"[q	c #C1C6D0",
"}q	c #435375",
"|q	c #7F89A1",
"1q	c #79849D",
"2q	c #5A6A87",
"3q	c #B6BDC9",
"4q	c #8E98AC",
"5q	c #8A95AA",
"6q	c #6A7893",
"7q	c #D5D8E0",
"8q	c #536280",
"9q	c #919BAE",
"0q	c #75809B",
"aq	c #C9CFD6",
"bq	c #5C6B88",
"cq	c #B3BAC7",
"dq	c #728098",
"eq	c #EAEBEE",
"fq	c #667490",
"gq	c #FAFBFA",
"hq	c #78859D",
"iq	c #5E6C89",
"jq	c #7E89A0",
"kq	c #748098",
"lq	c #6D7A95",
"mq	c #8E97AE",
"nq	c #C3C8D3",
"oq	c #738098",
"pq	c #737F99",
"qq	c #C0C5D0",
"rq	c #DCE2EA",
"sq	c #93A9C1",
"tq	c #C1CEDC",
"uq	c #C1CFDC",
"vq	c #ECEFF3",
"wq	c #6686A7",
"xq	c #95ADC4",
"yq	c #A2B7CA",
"zq	c #F6F8FA",
"Aq	c #456C94",
"Bq	c #BFCCD9",
"Cq	c #3B6690",
"Dq	c #ABBBCE",
"Eq	c #92A8BF",
"Fq	c #225382",
"Gq	c #2F5C88",
"Hq	c #95ACC3",
"Iq	c #D2DAE5",
"Jq	c #9CA5B7",
"Kq	c #808BA1",
"Lq	c #DCDFE6",
"Mq	c #697592",
"Nq	c #E0E3E9",
"Oq	c #C5CCD5",
"Pq	c #727F99",
"Qq	c #65728F",
"Rq	c #AFB6C3",
"Sq	c #D1D5DE",
"Tq	c #7F89A2",
"Uq	c #747F9A",
"Vq	c #D7DAE2",
"Wq	c #ABB2C1",
"Xq	c #BBC2CE",
"Yq	c #ACB3C2",
"Zq	c #E4E7EB",
"`q	c #536182",
" r	c #74819B",
".r	c #8793A8",
"+r	c #CFD8E3",
"@r	c #54789D",
"#r	c #38628E",
"$r	c #C3CEDB",
"%r	c #305C89",
"&r	c #E9ECF1",
"*r	c #A5B6CA",
"=r	c #D0D9E4",
"-r	c #D5DBE5",
";r	c #16497C",
">r	c #6D8EAC",
",r	c #C4D0DE",
"'r	c #9AAFC5",
")r	c #66748F",
"!r	c #64718D",
"~r	c #A3AABB",
"{r	c #B9BFCA",
"]r	c #BDC3CF",
"^r	c #EEF0F2",
"/r	c #727F98",
"(r	c #6B7894",
"_r	c #A5AEBE",
":r	c #808BA3",
"<r	c #CACED8",
"[r	c #7B859D",
"}r	c #D3D6DE",
"|r	c #AAB2BF",
"1r	c #BDC2CF",
"2r	c #596786",
"3r	c #A4AABB",
"4r	c #AEB4C2",
"5r	c #64728D",
"6r	c #A1A9B9",
"7r	c #727E98",
"8r	c #BBC1CC",
"9r	c #66738E",
"0r	c #BBC0CC",
"ar	c #6F7D96",
"br	c #647490",
"cr	c #E2E4E9",
"dr	c #5B6B89",
"er	c #3C4E71",
"fr	c #A9B9CC",
"gr	c #D5DDE7",
"hr	c #EAECF2",
"ir	c #E7EAF0",
"jr	c #EAECF1",
"kr	c #E8EBF1",
"lr	c #F9F9FB",
"mr	c #E8EAF0",
"nr	c #D9DCE2",
"or	c #949CB1",
"pr	c #63708C",
"qr	c #8690A6",
"rr	c #D5DAE0",
"sr	c #DEE2E6",
"tr	c #E4E7EC",
"ur	c #E6E9ED",
"vr	c #EFF1F3",
"wr	c #EAECF0",
"xr	c #EBEEF1",
"yr	c #C5CAD4",
"zr	c #D3D7DE",
"Ar	c #D7DCE2",
"Br	c #D9DEE3",
"Cr	c #EDEEF2",
"Dr	c #C9CFD8",
"Er	c #C2C8D2",
"Fr	c #D5DAE1",
"Gr	c #DFE3E8",
"Hr	c #E5E8ED",
"Ir	c #E1E4EB",
"Jr	c #F9FAFA",
"Kr	c #E1E5E9",
"Lr	c #C2C7D2",
"Mr	c #DCE0E4",
"Nr	c #ECEEF2",
"Or	c #C8CDD6",
"Pr	c #4A5A7B",
"Qr	c #F5F7F8",
"Rr	c #9099AE",
"Sr	c #182D57",
"Tr	c #3C4D71",
"Ur	c #CED2DB",
"Vr	c #A3B6C9",
"Wr	c #416992",
"Xr	c #3A628E",
"Yr	c #839EB8",
"Zr	c #90A7BF",
"`r	c #7795B2",
" s	c #B2C2D3",
".s	c #88A2BB",
"+s	c #C3D0DD",
"@s	c #C3CFDC",
"#s	c #90A8BF",
"$s	c #B4BAC8",
"%s	c #21345D",
"&s	c #22365F",
"*s	c #BAC0CC",
"=s	c #E8EBEE",
"-s	c #F6F7F7",
";s	c #EBECF0",
">s	c #EEEFF1",
",s	c #5E80A3",
"'s	c #285886",
")s	c #295987",
"!s	c #87A1BB",
"~s	c #295885",
"{s	c #A1B6CA",
"]s	c #1D5080",
"^s	c #51789D",
"/s	c #415274",
"(s	c #929CAF",
"_s	c #BBC1CD",
":s	c #9EA6B7",
"<s	c #8D98AD",
"[s	c #8792A9",
"}s	c #63708D",
"|s	c #A7AFC0",
"1s	c #8994A9",
"2s	c #626F8A",
"3s	c #6A7892",
"4s	c #B2B8C5",
"5s	c #5F6D8B",
"6s	c #8E97AC",
"7s	c #6D7B95",
"8s	c #768099",
"9s	c #7A859C",
"0s	c #808BA2",
"as	c #848FA6",
"bs	c #6A7691",
"cs	c #D7DAE1",
"ds	c #586684",
"es	c #7A859D",
"fs	c #8D96AA",
"gs	c #99A2B3",
"hs	c #3F4F72",
"is	c #7B869E",
"js	c #D1D4DC",
"ks	c #4F5E7D",
"ls	c #A0A9BA",
"ms	c #38496E",
"ns	c #B7BEC9",
"os	c #37476C",
"ps	c #EBEDEF",
"qs	c #6F7C97",
"rs	c #4B5A7B",
"ss	c #8F98AC",
"ts	c #66738F",
"us	c #CDD2DA",
"vs	c #8591A7",
"ws	c #536281",
"xs	c #255583",
"ys	c #2C5987",
"zs	c #F6F7FA",
"As	c #4E7499",
"Bs	c #94AAC0",
"Cs	c #75829B",
"Ds	c #707D96",
"Es	c #D9DDE4",
"Fs	c #7E88A0",
"Gs	c #848EA5",
"Hs	c #76809B",
"Is	c #697792",
"Js	c #99A1B2",
"Ks	c #697691",
"Ls	c #97A1B4",
"Ms	c #D9DCE3",
"Ns	c #6E7B95",
"Os	c #A0A8BA",
"Ps	c #7B869F",
"Qs	c #64728F",
"Rs	c #79869E",
"Ss	c #6B7792",
"Ts	c #9AA3B6",
"Us	c #C6CCD5",
"Vs	c #DFE3E6",
"Ws	c #7D88A0",
"Xs	c #D8DBE1",
"Ys	c #7D899F",
"Zs	c #8692A8",
"`s	c #859EB8",
" t	c #E9EDF1",
".t	c #F0F4F7",
"+t	c #235282",
"@t	c #245382",
"#t	c #CBD4E0",
"$t	c #6E8EAC",
"%t	c #D8DCE1",
"&t	c #C6CCD6",
"*t	c #7A859F",
"=t	c #77849C",
"-t	c #7A869E",
";t	c #DEE3E8",
">t	c #75819B",
",t	c #F3F5F7",
"'t	c #818CA2",
")t	c #717E97",
"!t	c #8F99AD",
"~t	c #A0A8B9",
"{t	c #E2E4E8",
"]t	c #BEC3D0",
"^t	c #DADCE3",
"/t	c #C8CDD7",
"(t	c #6A7792",
"_t	c #465678",
":t	c #7B87A0",
"<t	c #EFF1F4",
"[t	c #E3E6EA",
"}t	c #8691A7",
"|t	c #717D97",
"1t	c #61708D",
"2t	c #7A86A0",
"3t	c #DEE3E6",
"4t	c #E4E6EB",
"5t	c #97A0B3",
"6t	c #6F7C96",
"7t	c #92A9C0",
"8t	c #A0B4C8",
"9t	c #AEBDCF",
"0t	c #BFC5CF",
"at	c #D6DBE2",
"bt	c #D7DCE3",
"ct	c #AEB5C4",
"dt	c #77849B",
"et	c #DFE2E9",
"ft	c #A9B2C1",
"gt	c #AAB1C1",
"ht	c #E1E4E8",
"it	c #657390",
"jt	c #E9EBEE",
"kt	c #B8BFCC",
"lt	c #7A869D",
"mt	c #8894A9",
"nt	c #A3ABBB",
"ot	c #556484",
"pt	c #DDE1E6",
"qt	c #75819C",
"rt	c #D1D6DE",
"st	c #9CA4B6",
"tt	c #5C6B89",
"ut	c #51769C",
"vt	c #EAEEF3",
"wt	c #B0C1D2",
"xt	c #2F5B88",
"yt	c #152A56",
"zt	c #1E325B",
"At	c #65738E",
"Bt	c #E3E5E9",
"Ct	c #7C879F",
"Dt	c #C6CBD5",
"Et	c #5E6C88",
"Ft	c #EBECEF",
"Gt	c #99A3B5",
"Ht	c #677590",
"It	c #DCE0E5",
"Jt	c #667390",
"Kt	c #616F8B",
"Lt	c #B0B7C4",
"Mt	c #ECEDF1",
"Nt	c #B3BBC6",
"Ot	c #F0F2F4",
"Pt	c #DFE3E7",
"Qt	c #717E98",
"Rt	c #A6ADBD",
"St	c #98A0B2",
"Tt	c #CDD1D9",
"Ut	c #B2B9C5",
"Vt	c #8B95AA",
"Wt	c #34618D",
"Xt	c #496F97",
"Yt	c #E8EDF2",
"Zt	c #E6EBF1",
"`t	c #A8BBCE",
" u	c #E1E8EE",
".u	c #2B5785",
"+u	c #2C5886",
"@u	c #CBD4DF",
"#u	c #E5E8EC",
"$u	c #939DB0",
"%u	c #ABB3C2",
"&u	c #ADB5C3",
"*u	c #8692A6",
"=u	c #8C96AC",
"-u	c #8692A7",
";u	c #B5BCC8",
">u	c #FEFEFC",
",u	c #B5BDCA",
"'u	c #B8BECA",
")u	c #909BAF",
"!u	c #919DAF",
"~u	c #929DB0",
"{u	c #B4BAC7",
"]u	c #C3C8D2",
"^u	c #8A95AB",
"/u	c #ADB4C5",
"(u	c #B0B7C5",
"_u	c #8793A7",
":u	c #929DAF",
"<u	c #8893A7",
"[u	c #BCC1CD",
"}u	c #B1B7C6",
"|u	c #C7CDD7",
"1u	c #8D98AB",
"2u	c #C0C7D1",
"3u	c #BDC4CF",
"4u	c #B2B8C7",
"5u	c #406992",
"6u	c #9CAEC5",
"7u	c #CED8E3",
"8u	c #BFCAD8",
"9u	c #2E5987",
"0u	c #DEE0E6",
"au	c #275785",
"bu	c #91AAC1",
"cu	c #C0CCDA",
"du	c #1E5081",
"eu	c #D2D5DD",
"fu	c #8FA6BE",
"gu	c #9AAEC4",
"hu	c #6383A5",
"iu	c #BAC8D7",
"ju	c #2D5987",
"ku	c #DDE1E7",
"lu	c #616F8C",
"mu	c #455677",
"nu	c #C0C5CF",
"ou	c #596987",
"pu	c #1C315A",
"qu	c #3E4E73",
"ru	c #4B5B7C",
"su	c #B3C3D3",
"tu	c #285885",
"uu	c #BCC2CE",
"vu	c #B6C3D3",
"wu	c #325E8B",
"xu	c #708FAE",
"yu	c #315C89",
"zu	c #456E96",
"Au	c #487198",
"Bu	c #BAC7D6",
"Cu	c #A0A9B9",
"Du	c #B9BFCB",
"Eu	c #456D95",
"Fu	c #2D5B88",
"Gu	c #2D5C89",
"Hu	c #8098B4",
"Iu	c #6483A5",
"Ju	c #A7B9CC",
"Ku	c #A6B8CB",
"Lu	c #6B88A9",
"Mu	c #9EB1C6",
"Nu	c #A8B0C0",
"Ou	c #B7BDCA",
"Pu	c #F9FAFC",
"Qu	c #939DAF",
"Ru	c #445576",
"Su	c #283C62",
"Tu	c #2D4067",
"Uu	c #445676",
"Vu	c #495A79",
"Wu	c #405173",
"Xu	c #5A6988",
"Yu	c #DDE0E5",
"Zu	c #3D4E72",
"`u	c #8E99AD",
" v	c #455578",
".v	c #455478",
"+v	c #445477",
"@v	c #2B3E64",
"#v	c #1B305B",
"$v	c #CBCFD8",
"%v	c #3A4B70",
"&v	c #6C7A95",
"*v	c #828DA3",
"=v	c #C2C8D3",
"          . + @ # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # @ + .           ",
"      $ % & * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * & % $       ",
"    # & * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * & #     ",
"  $ & * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * & $   ",
"  % * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * %   ",
". & * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * & . ",
"+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * + ",
"@ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * = - = * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * ; > , ' ' ) ! * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * ; ~ ' { ] ^ / ( _ : < [ [ [ [ [ [ [ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * } | 1 ] 2 3 4 5 6 7 8 9 0 a b c c c d d d [ [ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * & ; e f g h } g - = & * * * * * * * * * * ! - i } j j g f = ; * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * [ [ k l m n o p q r s t u v w x y z A A A a a c c d [ [ * * * * * * * * * * * * * * * * * * & ! - g B B g f ! & * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * & C - g j > D D > E } - & * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * ; f > F G ' H 1 I J K L K I M _ D C * * * * * * e N O P Q J L R L Q H S ) > f ; * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * [ [ d c T U V W X Y Z `  ...+.@.#.$.%.&.*.=.=.=.-.-.z A A a c d d [ * * * * * * * * * * * & C j ;., >.,.P Q K L K Q H , '.B = * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * & C B ).!.~.M {.{ Q K R ].].].].R H ~ C * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * * * * * * * C > _ ^.,.Q /.(.@ / _.:.<.[.}.$ }.|.1.2.3.4.* * * * 5.6.Q 7.8.:.|.9.$ 0.$ [.a.+ 2.6.b.j ; * * * * * * * * * * * * * * * * * * * * * * * * * * * * [ d c.b d.A e.f.g.h.i.j.k.l.m.n.o.p.q.r.s.t.u.v.w.x.y.y.z.=.-.z A.A b c d [ * * * * * * * * - ~ , B.{ L 2.@ / C.D.|.9.$ }.[.D./ I !.g * * * * * * * * * * * * * * * * * * * * * * * * * * * * = B ;.E.B.P L ( F.G.+ 1.a.|.}.H.I.J.I.I.K.L b.e * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * * * * * = D 3.6.P R L.G._.<.0.M.N.O.P.Q.R.S.T.U.V.W.X.[.E.e * * F H ].Y.<.Z.`. +.+S.V.++U.T. +@+M.1.{ F i * * * * * * * * * * * * * * * * * * * * * * * * [ #+d b d.A.-.=.$+%+&+*+=+-+;+>+,+'+)+!+~+{+]+^+/+(+_+_+:+<+[+x.y.z.=.-.z A a c.d [ * * * * ; E }+B.I ].|+/ :.}.1+N.O.P. +.+T.U.V.S.Q.2+|.3+4.* * * * * * * * * * * * * * * * * * * * * * * * & } b.4+{.K ( # 8.:.9.5+6+7+`.X.8+W.V.++9+0+a+b+}.L ) e * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * * * & g _ M { ].F.8.a.H.c+2+d+S.9+e+f+g+h+i+j+k+l+l+m+n+o+p+G.~ q+{.2.r+H.s+W.e+t+u+v+w+x+y+l+z+A+h+B+C+Z.K ) e * * * * * * * * * * * * * * * * * * * * & d b A z -.z.y.D+E+F+G+H+I+J+K+L+M+N+O+P+Q+R+S+T+U+V+W+X+Y+Z+`+_+:+<+w.y.z.=.z A a c #+* * C ;.>.P ].|+ @.@+@@@#@8+a+C+$@%@&@*@=@-@x+m+v+;@>@,@|+j * * * * * * * * * * * * * * * * * * * * * f ;.' 1 L L.'@)@}.1+7+b+8+U.!@~@{@]@^@/@=@x+(@_@:@w+<@&@[@1+~.= * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * * ; % ~.{.L 7./ a.I.. #@.+9+}@|@1@k+2@3@4@4@4@4@4@4@4@4@4@3@5@*@6@$ # C.7@b+0+8@-@4@4@4@4@4@4@4@4@4@9@0@:@u+a@`.{ > ; * * * * * * * * * * * * * * * [ d b@c@z -.z.y.w.d@e@f@g@h@i@j@k@l@m@n@o@p@q@r@s@t@u@v@w@x@y@z@A@B@C@Y+D@_+:+[+E@z.=.z A b c.F@G@B.J (.'@H@I@J@K@L@M@N@O@P@Q@3@4@4@4@4@4@4@4@4@4@9@Q@R@ +| - * * * * * * * * * * * * * * * * & S@, H J (.Y.:.0.6+O.Q.U.C+8@T@U@(@V@4@4@4@4@4@4@4@9@W@2@_@k+<@X@Z.C * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * ! Y@>.{ ] Z@C.}.6+@+R.0+~@`@ #.#4@4@4@4@4@4@4@4@4@4@4@4@4@9@0@+#_@-@@###1+X.$#%@3@4@4@4@4@4@4@4@4@4@4@4@4@4@4@V@%#%@1+) ! * * * * * * * * * * * * [ < c@&#*#=#y.[+:+_+Z+-#;#>#,#'#)#!#~#{#]#^#/#(#_#:#<#[#}#|#1#2#3#4#5#y@A@B@X+6#`+:+[+E@z.7#z 8#9#O K 7.+ 0#a#b#c#d#e#f#k+3@4@4@4@4@4@4@4@4@4@4@4@4@4@4@W@g#n+8@{ C * * * * * * * * * * * * * ; h#4+1 /.# r+[.1+7+#@ +U.i#j#5@9@4@4@4@4@4@4@4@4@4@4@9@W@2@_@m+j+k#l#'@* * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * C m#M Q (.'@a.J.. @+n#S.o#j+V@3@3@9@4@4@4@4@4@4@4@4@4@4@4@4@3@V@+#x+p#z+q#C+2+r#s#4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@9@k+t#(.f * * * * * * * * [ & c u#v#=.w#x#d@y#Z+X+z#A#B#C#D#E#F#G#H#I#J#K#L#M#N#O#P#Q#R#S#T#U#V#W#X#2#3#5#Y#z#Z#Z+:+d@[+y.`# $.$+$@$8._.#$$$%$&$*$=$-$;$.#W@4@4@4@4@4@4@4@4@4@4@4@4@4@3@.#>$k+A+a+) * * * * * * * * * * * ; ,$>.{ ] Z@1.[.0.5+M.'$Q.)$>$2@2@2@!$0@W@9@4@4@4@4@4@9@3@0@g#(@w+P@j#>@!@f * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * ! F M Q L./ <.0.5+1+c+O.~$y+g#+#Q@Q@Q@g#.#3@4@4@4@4@4@4@4@4@9@3@.#+#y+p#{$^@T@]$<.t#0@3@9@9@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@!$h+}.^$* * * * * [ d c@&#/$=#`#($_$:$X+<$y@4#[$}$|$1$2$3$4$5$6$7$8$9$0$a$b$c$d$e$f$g$h$i$j$k$U#l$X#2#m$z@X+Z+Z+y#d@n$o$p$q$r$s$t$u$v$w$x$y$z$A$B$z+p#l++#W@4@4@4@4@4@4@4@4@4@4@3@.#Q@l+n+j#C$D$* * * * * * * * * & ).' { 2.G._.)@:.a.|.H.r#j+(@y+l+m+k+%#%#w+x+>$2@0@V@W@V@.#2@5@x+%#j+j#>@C$^$* * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * ; E$M Q (./ :.a.K.[.$ '$X@:@:@l+w+%#z+ #n+ #=@x+g#W@4@4@4@4@4@3@V@2@5@l+=@{$^@)$K.E { F$y+>$+#2@!$0@V@W@3@9@9@4@4@4@4@4@4@4@4@4@4@4@3@<@7+'.* * [ c a z /$w#x#G$H$I$W+J$5#3#K$L$M$N$O$P$Q$R$S$T$U$V$W$X$Y$Z$`$ %.%+%@%#%$%%%&%*%j$k$V#X#5#W+=%<$X+Z+-%;%>%,%'%)%!%~%{%]%^%/%(%_%i+F$R@&@1@A+=@g#9@4@4@4@4@4@4@9@W@.#Q@x+z+/@h+p+S@* * * * * * * * j 4+P ] Z@/ 8.+ r+C.K.:%p#w+z+q#<@u+A+j#<%F$F$k#/@q#k+y+_@_@(@l+k+n+u+F$s#8@S@* * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * D ' { ( G.r+_.C.)@D.J.h+l+k+z+P@{$*@j#F$[%&@o+&@^@u+w+g#V@3@W@0@2@Q@(@w+ #u+1@l##@* ; >.f+i+{$q#z+w+l+:@_@Q@g#!$0@W@3@4@4@4@4@4@4@4@4@4@V@;@P.}%|%a z =.y.1%2%:$3%4%5%4#6%l$7%8%9%0%a%b%c%d%e%f%g%h%i%j%k%l%m%n%o%p%q%r%s%t%u%v%%%w%i$U#4#z@5#x%y%z%A%B%C%D%E%F%G%!%H%I%J%K%L%M%@#N%O%I.@ 2./ s+P%%#0@9@4@4@9@3@0@2@>$l+v+u+R@Q%K * * * * * * * f D${./.F.@ Z@G.'@8.C.R%=@ #U@/@j#[%h+s#T@{@!@##9.[.7@a+t+<%S%j+j+<@/@k#h+T@P.! * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * 4.S 1 ] @ '@/ 8.]$r+0.T%%# #<@*@<%R@>@N%U%V%c+@ ' ~.3+Z@ +`@{$x+>$_@y+m+v+<@j#h+N%$ * * * h {.9.n#N@W%T@R@i+u+U@q#z+k+l+(@+#0@9@4@4@4@4@4@4@V@(@X%Y% $Z%y.<+`% &W+z@5#2#W#U#j$.&+&@&#&$&%&&&*&=&-&;&>&,&'&)&!&~&{&]&^&/&(&_&:&<&[&t%u%%%}&|&X#W#6%4#1&;#2&3&4&5&6&7&8&9&0&a&b&c&)$[@Q } ; * * * ; 4.;.a.W%q#+#!$2@g#5@y+w+q#*@&@N%r+* * * * * * ; ;.B.K (.7.F.|+# @ + U% #U@*@<%o+s#a@r#]$;.B - = * * & C g ~ {.. N@d&P%g+d&V%E$* * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * ; q+O L F.Z@Z@G.'@/ |.N%=@j+/@<%o+X@`@ +] S@& * * * * * * * C G $ $@i+j+j+S%j#&@]@[@m#* * * D >.1 ~.).S@E$,.'@5+P.!@U%O@>@^@A+<@=@_@V@4@4@4@4@e&f&g&h&i&j&k&`+l&<$y@3#6%V#}&*%%%m&n&o&p&q&r&s&t&u&v&w&x&y&z&A&B&C&D&E&F&G&H&I&J&J&K&<&L&u%M&l$j$j$U#W#N&O&P&Q&R&4&S&T&U&V&W&i+&@l#6@N * * * * * * * * * * = }+##X&v+w+w+=@n+S%k#T%Q%7.* * * * * * j ^.{ ] ( 2.L.7.F.# e+P@S%j#R@s#%@n#' ! * * * * * * * * * * * * * & g ~ }+Y@C * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * S@>.I (.|+# # @ Z@'@d& #<@;@[%@#Q% +4+C * * * * * * * * * * * * * e E.]$a+%@]@T@o#,.& * * * ,$H R R I 4+;.f * * * & h ~ 3.O (.)@P.O%X@k+V@4@Y&Z&`& *.*+*@*#*$*4%%*&*W#k$j$&%$%**=*-*;*>*,*'*)*!*~*{*]*^*/*(*_*:*<*[*}*|*1*2*3*4*I&J&J&5*u%k$6*$%%%*%k$7*8*9*0*a*b*c*d*e*f*g*h*i*B+H * * * * * * * * * * * * * * E I P.Q%<%k#1@j*)$~@~ * * * * * = _ H L ].] ( ( 2.(.s+/@u+F$j*l#f+K e * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * C G@{.].7.F.F.|+# @ S.q#{$j#&@]@k*|+f * * * * * * * * * * * * * * * * * * e j ;.N S@& * * * & ;.,.( 7.2./.I 6.D$G@h#& * * * * * * ! f h _ :.R%l*m*n*o*p*q*r*s*t*u*2#l$}&*%v*w*s%<&x*y*z*A*B*C*D*E*F*G*H*I*J*K*I*L*M*N*O*P*Q*R*S*J&J&4*J&T*w%w%s%[&t%$%w%j$U*V*W*X*a*b*c*Y*Z*`* =.=S.- * * * * * * * * * * * * * * * * = j E.a.P.n#a.).* * * * * * E ' I R R /.].] ] 8.R@/@F$T%X&a+;.& * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * D >.J 2.(.L.7.7.F.0.<%{$j#o+l#i#>.* * * * * * * * * * * * * * * * * * * * * * * * * * * * * & m#{.(.@ # 7.2.L.[@&@8@_ * * * * * * * * * * ! +=@=#=$=%=p.&=*===-=;=>=}&w%,=t%'=_&)=!=~={=]=^=/=(=_=J*:=<=[=}=|=1=2=3=4=5=6=7=8=9=0=5*K&K&a=i$b=K&K&<&c=d=e=f=g=h=i=X*j=V+k=l=m=n=o=p=[ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * ; b.H J K L R /./.( ,@u+<%T%X&P.5.* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * = N ,.].2.2.(.L.L.Z@|@U@i+&@l#o#| * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * & _ 1 L.'@Y.Z@# |.S%<%]@}.* * * * * * * * * * [ q=V r=s=t=u=v=w=x=y=z=A=&%d=c=<&_&)=B=C=D=E=F=G=(=H=I=J=K=L=M=N=O=P=Q=R=S=T=U=V=W=X=K&Y=Z=`= -.-+-I&@-#-$-%-&-*-=---;-i=X*>-,-'-)-!-~-{-[ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 4.~.P Q J K K L R a.<%k#h+T@T.D * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * B ^.I ] ( ( 2.2.(.c+u+*@[%X@t+1 & * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * ; N P 7.+ 8.'@G.Z.n+i+@#a+; * * * * * * * * * d ]-^-/-(-_-:-<-[-}-|-1-2-3-s%<&K&)=4-5-6-7-8-9-^=0-a-b-N=-&j%c-d-e-f-g-h-i-j-f-k-l-m-J&J&5*n-U#o-K&J&p-q-r-s-t-u-v-w-x-y-z-A-B-C-D-E-F-G-c.[ * * * * * * * * * * * * * * * * * * * * * * * * * * * * h#M I Q Q Q J K L t#A+R@]@C$;.* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * Y@O L ] ] ( ( ( (.P%u+F$>@g+K.& * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * = 3.P F.r+_.r+8.@+v+*@j*R%h * * * * * * * * & c y H-I-J-K-L-M-N-O-P-Q-R-S-_&J&J&4-4-T-U-V-W-X-'*Y-Z-`-j% ;.;k%+;@;#;$;%;&;*;f-=;-;;;K&J&>;6*,;';);p-!;~;{;];^;/;(;_;:;<;[;};|;1;2;3;4;5;a d * * * * * * * * * * * * * * * * * * * * * * * * * * * ; !.,.I I Q Q Q J 8.&@F$@#`@].* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * = , 1 /.].].] ] ( }.<@i+o+N%U.g * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * ! D${ |+C.)@1._.R.z+u+&@Q%!.* * * * * & * [ < c@6;7;8;3&9;0;a;b;c;d;e;f;g;J&J&4*J&_&h;i;j;k;q&l;m;m;n;o;p;q;r;s;t;u;v;w;x;y;z;A;B;C;<&<&a=D;T*J&5*E;~;{;F;G;H;I;t-J;K;L;M;N;O;P;Q;R;S;T;A c [ * * * * * * * * * * * * * * * * * * * * * * * * * * - | P I I I I Q Q 9+i+o+T@P.e * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * g 4+Q /.].].].].( C$/@1@s#U;D$* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * ! G I |+)@D.:.)@9+=@S%[%N%Q * * * * * * * < b@&#V;W;X;Y;Z;`; >.>+>@>#>$>0-J&I&J&5*);%>D=&>*>=>l;;;->l-;>>>,>'>y;)>!>~>{>]>^>/>(>C&_>_&0=:>a=<>J&@-[>}>|>1>2>3>4>5>*-6>7>8>9>0>a>b>c>d>e>f>a d * * * * * * * * * * * * * * * * * * * * * * * * * * E >.{ I I I I I L h+F$@#W%, * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * & % B.K /./././.].+ &@i+h+N%H.; * * * * * * & & & & * * * * * * * * * * * * * * * * * * * * * * * ! G I # :.a.a.D.p+p#<@^@)$C.* * * * * * [ c.c@g>h>i>j>k>l>m>n>o>p>q>r>s>t>4*J&>;);)=u>v>w>x>y>->z>A>B>C>D>E>f;F>G>H>I>J>K>G>L>M>N>O>P>`=n-0=5*K&K&#-r-Q>G;R>S>T>U>V>W>X>Y>Z>`> ,.,+,@,#,$,A.c [ * * * * * * * * * * * * * * * * * * * * * * * * * '.O I I I I I I a.;@&@)$#@! * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * ; b.,.R R /./././.d+u+^@s#W%^$* * * * e 5.b.}+S | E.3.) E C * * * * * * * * * * * * * * * * * * * ! , I # :.<.<.a.$@%#<@F$]@N.; * * * * * d a /$%,&,*,=,-,;,>,,,',),!,~,2={,J&5*Z=],^,/,(,_,:,<,[,},|,1,2,3,p%4,5,6,7,7,8,9,0,a,b,c,d,e,n-f,+-5*5*K&p-!;g,Q>h,|>i,j,k,l,m,n,o,p,q,r,s,u=t,u,v,a d * * * * * * * * * * * * * * * * * * * * * * * * & !.{.Q Q Q I I I C+k#T%O@{ * * * * * * * * * & - ^$b._ h & * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * C , P R R /././.].8@A+o+T@s+* * * & D | H Q ].L.# Y.'@Y.@ ] G B * * * * * * * * * * * * * * * * * = }+{ # :.<.<.<.C$%#U@<%X@8+! * * * * [ c A w,x,y,z,A,B,C,D,E,F,G,H,I,J,A*5*Z=K&J&K,L,M,N,O,P,$&Q,I>R,S,T,U,V,W,X,Y,Z,`, '.'+'@'#'$'%'3-);>;+-5*5*&'$-q-~;*'='-';'K&K&>',''')'!'~'{']'^'/'('A.c [ * * * * * * * * * * * * * * * * * * * * * * * = G P J J Q Q Q L a@^@s#U;4.* * * * * * * = j q+4+,.Q ].L S E & * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * f ~.I R R R /./.G.>@j#T%P%B.* * * } | 1 ].# ]$<.I.Z.N.##2+s+N.$ { h & * * * * * * * * * * * * * * ; G@{ |+:.<.<.<.k*%#U@<%s#++! * * * * d c@_':'<'['}'|'1'2'3'4'5'6'Q=^*7'E=Z=5*I&J&8'F=(,9'0'a'b'c'd'e'f'g'h'i'j'k'l'm'n'o'p'q'r's't'u'a=Z=0=>;+-5*<&v'w'x'y'j,%-@-I&J&)=z'A'O$B'C'D'E'F'G'H'I'a d * * * * * * * * * * * * * * * * * * * * * * * - 3+I L K J J Q G.T%R@l#.+* * * * * * ! > 3.>.P L (.G._.)@'@/.~.D ; * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * } ' J R R R R /.9.*@F$]@N@D * * * Y@O R Z@)@I.N.P.S.V%,@U%`@O@g+a@}@r+;.! * * * * * * * * * * * * & N P F.)@<.<.<.U%%#U@<%s#0+C * * * * J'K'L'M'N'O'P'Q'R'S'T'U'V'W'X'Y'Z'`'>;4*J&_& ).)+)9'@)#)$)%)&)g'*)=)-);)>),)')))!)~){)>)])^)/)()a=`=f,);T*+-+-c=e=i$`=>;Z=K&I&I&J&_):)<)[)})|)1)2)C-3)4)5)c [ * * * * * * * * * * * * * * * * * * * * * * } >.J R R L K K c+i+R@l#D.* & ; e j E$~.H I ].|+8.D.0.6+6)5+<./ 7.L.H b.! * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * S@M K R R R R R 2+/@[%T@c+; * * & q+1 2.]$$ N.n#0+N@s#k+V@9@4@4@4@9@.#/@,@Y.4.* * * * * * * * * * & _ P F.)@<.<.<.o#%#U@<%s#V%e * * * F@7)8)9)0)a)b)c)d)e)f)g)h)i)j)k)l)N,m)J&J&_&_&n).)o)p)q)r)s)t)u)v)w)x)y)z)A)r)B)C)D)E)F)F)G)H)I)J)K)L)`=f,Z=0=M)e=w%c=K&J&>;>;J&I&J&_&N)O)P)Q)R)D'S)T)U)V)W)0 #+* * * * * * * * * * * * * * * * * * * * * * S@M R # / '@G.'@p+z+<@k#r+b.G@E.4+H { R (.Z@r+K.J.. `.8+S.d+R.f+X@S%A+N%1+; * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * ^$B.L /./.R R R C+A+o+O@|+* * * & F 1 L.1.7@`.U.X)^@W@4@4@4@4@4@4@4@4@3@2@%#{@(.- * * * * * * * * & _ P 7.1.<.<.<.t#k+U@<%s#$#i * ! 5.Y)Z)`) !.!+!@!#!$!%!&!8,*!/>=!-!;!>![&)=K&_&_&,!'!)!!!~!{!]!^!/!~)(!_!:!<![!}!|!1!2!3!4!5!6!7!o,8!9!n-L)`=f,a=6*n-);<&_&J&J&Z=K&J&I&J&0!a!b!c!d!e!f!g!h!i!j!k!c * * * * * * * * * * * * * * * * * * * * * ; ,$O ]./ }.. O.s+s#>$-@n+[.].2.7.# Y.8._.<.0.Z.##P.W.V%~@|@;@x+Q@:@p#{$1@N%O * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * ).O R /././.R R %@i+j*~$~.* * * * E O (.)@M.X.r#{@V@4@4@4@4@4@4@4@4@4@4@W@g#w+A+++% * * * * * * * & b.1 7.1.K.<.<.e+k+j+j#j*$@D > D$O l!k!m!n!o!p!@!q!r!s!t!u!v!{*w!x!y!K)b=m)l,<&z!A!B!C!D!E!{!F!G!H!I!J!K!L!M!N!O!P!Q!R!S!T!U!V!W!X!Y!Z!`! ~K) ~.~o-0=5*5*_&K&J&5*0=J&4*J&K&+~@~#~$~%~&~*~=~-~;~>~,~[ * * * * * * * * * * * * * * * * * * * f m#6.{ 2.+ 0.2+V.t#=@W@2@x+2+}.I.7@6+. ##@+b+Q.W.0+p+:%@#w+3@V@!$5@x+=@{$^@l#c+* * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * ,$H R /././././.o+k#>@8@% * * * * & ).H 8.J.P.!@N%4@4@4@4@4@4@4@4@4@4@4@9@0@>$p#A+X)G@* * * * * * & b.1 7.)@|.|.K.!@w+ #<@A+a@M M { ].'~)~!~~~{~]~^~/~(~_~:~m%<~[~}~|~1~5*+-f,t%m)2~3~G=4~5~@&6~7~8~9~<!U!0~N!a~b~c~d~e~f~g~h~i~j~k~l~m~n~o~.-`!`!o-';0=>;5*<&_&J&J&);K&4*I&J&p~q~r~s~t~u~v~w~x~y~z~A~B~* * * * * * * * * * * * * * * * * & g }+O J L./ )@[.M.`.C~:@3@W@5@.+s+b+Q.T.V%}@o#R%N%T%k# #g#9@3@V@!$+#(@m+ #u+1@]@@+* * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * '.H /.]./././.].;@<%@#C~f * * * * * * e Y@J )@. U;W@3@9@4@4@4@4@4@4@4@4@4@3@2@y+ #^@6@~ * * * * * & b.1 L.)@9.9.}.}@(@l+%# #j*# ].|+D~E~F~G~H~I~J~K~L~M~d;N~r>O~P~Q~R~T*J&J&<&[&';S~y!T~U~V~W~X~Y~D)Z~`~h= {.{+{@{#{${%{&{*{={-{;{>{,{'{){!{~{ - ~L)f,Z=T*+-5*K&],I&+-0=J&4*J&_&{{]{^{/{({_{:{<{[{}{|{1{^$* * * * * * * * * * * * * * * * } D$,.L F.]$K.D.)@:.|.P.x++#Q@>$j#X@Q%R@S%z+-@_@+#.#V@W@W@V@0@.#2@Q@(@-@=@j+;@o+T@J.* * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * '.H /.].].]./.L.S%F$X@V.! * * * * * * * * ! ,$P . :@>$5@+#.#3@4@4@4@4@4@4@9@.#5@w+S%o+.+= * * * * & _ 1 L.1.I.'$O.:%!$Q@_@l+/@|.+ <.2{3{4{5{6{3&j@7{8{9{0{a{b{c{d{S*0=<>I&K&5*5*>;e{f{g{h{i{j{Y~k{l{m{n{o{p{+{q{r{s{t{u{v{w{x{y{z{A{B{C{D{E{F{.~,;K)b=f,0=>;5*5*K&J&J&Z=K&I&J&K&[&G{H{1$I{J{K{L{M{N{O{P{N.& * * * * * * * * * * * * * * e G@O K F.r+}.M.I.|.D.$ a@m+w+p#=@z+z+=@p#k+w+-@l+x+y+(@_@_@>$_@(@y+-@%# #U@A+[%s#%@, * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * ,$H /.] ].].].8.S%F$]@d+& * * * * * * * * * * = ,$9+S%U@j+q#=@(@W@4@4@4@4@4@W@+#x+ #i+l#F.* * * * ; N P 7.)@M.d+V%X&3@V@2@5@z+2+5+6)Q{R{S{T{U{V{W{X{Y{Z{`{E> ].]+]K&);J&J&_&5*5*>;=*y!g{@]#]$]B)%]&]i~*]=]q{-];]>],]'])]!]~]{]C,]]^]/](]_]:]F{<]`!n-L)M)Z=T*+->;l,5*J&0=5*J&J&J&'=[]}]|]E#1]2]3]4]5]6]h*.=^.* * * * * * * * * * * * * & '.M I K (.:.c+`.s+'$R.k#%#q#S%;@<%^@R@&@&@R@1@F$k#j#A+*@u+S%<@U@j+U@{$u+;@F$&@X@B+|.& * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * ).H /.] ] ] ].:.S%^@]@`.* * * * * * * * * * * * * 4.8.}@~$Q%T@X@*@x+V@4@4@4@3@!$_@p#{$&@6@> * * * = 3.{ F.:.Z.Q.C+X@4@3@.#5@=@`.7@7]8]9]0]a]b]c]d]e]f]g]h]i]j]4-+]_&T*I&K&_&5*+-T*k]l]m]n]o]p]q]r]s]R'p{q{t]u]v]w]x]y]z]A]B]C]D]E]q{F]G]H]I]E{!{D;:>K)b=f,f,b=K)d=`=],5*>;J&I&J&<&**J]K]L]M]N]O]P]Q]R]S]T%8+e * * * * * * * * * * * * f S 1 J Q ].]$1+Q..+O%k+(@%#<@k#T%)$f+@+9.# J K @ :.7@6)Q.++e+t#U;R%%@N%N%Q%B+$@O.>.! * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * ^$O /.( ( ] ] K.{$F$]@`.* * * * * * * * * * * * * * * & B 5.h#h#D$(.P.|@*@0@3@.#5@m+q#k#)$|+* * * ! D${ |+D.6+Q.!@T@3@V@.#5@m+8+_.X.T]U]V]W]X]Y]Z]`] ^.^+^<&J&I&)=<&<&+]_&<&<&>;1~@^l]#^$^%^B)&^*^ {=^]]-^;^>^,^'^)^!^~^{^]^^^/^(^_^:^O&<^[^}^|^<]`!,;.-<]1^~{2^`=>;J&K&Z=J&I&J&:&t%3^4^e)5^6^7^8^9^0^a^b^B+4+* * * * * * * * * * * * D M { I Q R '@0.`.t#_@g#(@%#<@F$]@N@h#* * * * * * * * * * * * * e g S@h#).% D - * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * S@M /.2.2.( ( D.{$F$]@`.* * * * * * * * * * * * * * * * * * * * * C S ( a.W.>@Q@+#l+ #A+>@0+- * * ! G I # a.6+X..+P%V@!$Q@(@-@R%f+P@c^d^e^f^g^h^i^j^I#k^l^L&5*],K&Z=K&J&_&<&<&'=m^n^o^p^q^p]r^s^R!n{t^u^v^>^w^x^y^z^A^B^C^D^E^F^G^v^-^H^I^J^K^L^E{M^V#N^ -3-f,>;5*K&J&J&Z=K&I&J&K&O^P^Q^R^S^T^U^V^W^X^Y^Z^]@$ & * * * * * * * * * * & '.B.{.1 { J # |.d+z++#_@x+q#S%<%X@9+C * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * } 6.R L.(.2.( ]$<@<%X@P.* * * * * * * * * * * * * * * * * * * * * & F { @ [.6+X)m+y+z+u+o+W%;.* * e S Q # a.6+6)2+t+2@5@y+w+v+<@{$`^ /./+/@/#/$/%/&/*/=/9%$%u%-/t%3-);>;'='=>;T*;/>/,/'/)/p]!/~/{/]/^///C](/_/:/</[/}/|/1/2/3/4/F^C]5/6/7/8/9/0/a/|^.~n-b=';T*+-5*b/],I&0=K&4*J&K&s%,=c/d/e/f/g/h/i/X^j/k/>@C+h * * * * * * * * * * & ,$^.6.O ,.P ( 1.:%g#>$x+<@H.R%j#s#e+f * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * f ^.L 7.7.L.(.# <@k#s#S.= * * * * * * * * * * * * * * * * * * * * * 5.,.(.C.K.0.N@:@p#{$[%X&L * * - ~.Q @ <.c+N.. t+5@x+k+n+S%i+1@l/S]m/n/o/p/q/r/s/t/u/v/w/*%i$j$U#i$*%h$v*x/**y/z/A/B/C/B)}!D/E/F/C,v^>^G/H/I/J/K/L/M/N/_'O/P/Q/R/S/T/U/V/W/}^X/<]2^K)b=';0=>;5*5*K&I&>;5*J&I&J&[&$%Y/Z/`/ (.(+(@(#(j/$(h+W%m#* * * * * * * * * * * = j _ 3+6.O Q _.S%Q@(@w+.+] e+;@>@o#B * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * ! G J F.|+F.7.7.u+i+>@r#e * * * * * * * * * * * * * * * * * * * * * E B.].8.C.:.[.i+%#U@^@l#H.* * i 3+J Z@K.'$7+6)g+(@k+q#u+<%h+l#%(3{&(*(=(-(;(>(,('()(!(G=0=0=f,n-`=u%v%$%,;,=~({(](^(/(q]((_(G]:(;#A%<([(3/}(g>|(1(2(3(4(5(6(7(8(9(T/0(a(X#a/X/~{.-3-b=f,0=>;5*5*_&4*>;>;4*J&J&L&d=b(c(M!d(e(f(g(h(i($(&@g+4+* * * * * * * * * * * * * = h b.~.B.D.v+:@x+O@Z@( d+*@h+R%,$* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * ; _ { F.@ # |+F.F$A+j*t#j * * * * * * * * * * * * * * * * * * * * * B 6.R Y.]$r+C.C~%#U@<%X@Q.* * 4.^.K G.|.. 2+s+l#(@k+j+j#j*T@$#B~j(^-k(l(m(n(o(Y{p(q(r(s(^,J&5*);J&<><&>;>;1~t(u(v(w(x(y(s^z(A(B(E]C(D(E^E(F(G(H(I(I(J(K(_'L(M(N(C]5/O(P(Q(a/E{!{.-n-b=f,0=>;5*<&K&J&+->;J&I&J&'=d=R(2!S(T(U(V(W(X(Y($(&@X&1 * * * * * * * * * * * * * * * ; B ) C.P@%#S%7@F.(.0.k#[%O@6.* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * & ).{.L.Y.G.@ # l#u+&@d&!.* * * * * * * * * * * * * * * * * * * * * B 6.L Z@'@8.]$7+v+U@<%s#r#* * g 4+K G.[.6)@+@+h+_@k+j+k#s#i#) d L/Z(`( _m(._o(+_@_#_$_=&%_4*K&0=I&K&:&5*>;&_n^*_=_n]-_;_>_,_]/'_)_!_~_{_]_^_u#/_(___2(:_<_[_M(E+C]5/0(}_|_a/1_!{.-n-b=f,0=>;5*<&K&I&+->;J&I&J&'=d=2_3_ {4_5_6_0)7_8_$(&@N%I * * * * * * * * * * * * * * * * * ; 6.F${$P.'@G.# / @#k#]@H.* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * g M ] / / '@G.i#<@1@O@K * * * * * * * * * * * * * * * * * * * * * S@M R @ G.Y.'@$ /@U@k#s#,@* * B ' L Y.[.6)#@#@k#_@w+P@j#s#N@> d 9_5;0_a_-(b_I{c_d_e_f_g_h_4*K&0=I&i__&5*+-j_k_l_m_n_Y~;_>_o_`/a~p_q_~_r_s_^_t_T H(u_v_N/w_E(x_(+C(y_z_A_B_C_M^|^ -`!:>n-o-b=`=c=c=T*f,';5*<>5*s%D_E_F_G_H_I_J_K_L_9]M_o+X&P * * * * * * * * * * * * * * * * * * = J a.L '@_.8.Y.{@/@h+t#C * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * ; E.L '@r+]$8.S.q#k#l#K.* * * * * * * * * * * * * * * * * * * * * % O /.# @ Z@G.:.R@U@<%s#X)* * h >.L Y.9.7+P.X.S%>$w+q#i+>@[@).d a N_O_P_Q_|;R_S_T_U_V_A;1*W_K&Z=I&J&K&5*5*X_Y_Z_`_ :.:k{&^+:@:'_p_9(D([(#:v,t_$:%:&:M/*:=:-:;:>:A%)_,:G]':):X/~{%%!:~:{:]:^:/:(:*%*%i$~{`!,;v%$%w/_:::C#<:[:}:|:1:2:l/j*g+M * * * * * * * * * * * * * * * * * * * * 5.{.|+D.<.1. +q#<%X&6.* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * E$P @ )@)@_.s+n+*@>@V.4.* * * * * * * * * * * * * * * * * * * & F ,.] |+|+# @ _.T%<@F$s#p+* * E 6.R '@}.##d+n#q#>$m+q#;@T%{@E$[ a 1/%+C%3:4:5:6:9{7:8:9:[=0:K&Z=J&],_&5*:&a:b:c:d:i{Y~]!e:f:={:(g:h:i:G/j:7#k:l:5)m:n:1/o:p:q:/^r:s:t:u:v:w:x:y:z:A:B:C:D:(=E:C:F:G:,=:>,;%%.~h$H:I:J:K:L:M:N:>%O:P:Q:>@t+G@* * * * * * * * * * * * * * * * * * * * ! | ]._.5+J.J.n+{$h+d+C * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * g 6.2.)@|.<.5+*@U@R@~$!.* * * * * * * * * * * * * * * * * * * e , P 2.F.|+|+|+C.R@{$^@]@9+* * > M R '@}.s+Q.8+p#>$m+n+A+T%t+_ [ a R:S:T:U:V:W:X:Y:Z:`: <1=.<^,Z=J&J&_&5*+<@<C:#<$<%<&<*<s^=<-<]/;<><,<'<)<E@z.Z%</!<~<s_{<]<>^^<E]/<A((<_<:<<<[<}<m]|<1<2<:,3<4<I=;*5<6<7<5*0=8<9<0<a<n{b<c<d<e<f<g<h<X@6@^$* * * * * * * * * * * * * * * * * * * * * ^$1 @ $ s+s+@#p#;@N%,.* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * ; G@K + $ H.}.X&v+j#l#8.* * * * * * * * * * * * * * * * * * * S@>.J L.7.F.F.F.<.;@u+[%l#P.* * D M /./ $ 2+8+.+m+5@-@n+A+j*a@D$[ c z i<j<k<l<m<n<o<p<q<r<s<t<u<0=K&J&_&<&;/v<w<x<y<z<$]Y~^!A<B< {C<D<E<F<G<<+w.H<I<J<K<L<M<N<O<P<Q<a~R<>,S<y(T<U<p^V<W<X<|,Y<Z<`<b-t> [0-.[;*+[>/@[#[$[-{%[&[8;*[r =[o+)$s+! * * * * * * * * * * * * * * * * * * * * * ! , ].)@N.W.U%:@v+^@p+E * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * E O |+|.6+Z.$@w+{$&@8@e * * * * * * * * * * * * * * * * * ! N ,.].7.7.7.7.F.1+<@*@&@N%[.* * ^$B.].8.0.O.R.V.l+5@-@ #*@h+%@~.[ c A -[;[>[,['[R))[![~[{[][^[0-_&>;I&K&s%/[([_[:[<[[[W~}[|[c!T!1[2[3[4[5[6[`+_+`%7[8[x]9[0[a[b[c[y{d[;=e[K!f[g[h[#^:)i[j[k[<,`<l[m[n[o[p[q[r[(>s[t[:;u[-{v[w[x[y[z[A[B[%@] * * * * * * * * & & * * * * * * * * * * * * * j O Z@0.X.~@%#Q@ #R@7+= * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * ; _ R r+M.`.W.v+z+;@]@( * * * * * * * * * * * * * * * * & % >.Q (.7.7.7.7.7.R.j+i+j*%@P * * D B.].8.0.O.W.9+:@Q@l+v+/@o+Q%6.* d A C[D[E[F[G[H[I[J[K[L[M[}=N[O[);J&J&P[Q[R[S[p)T[~!U[V[W[X[.>Y[Z[`[4[ }.}X+Y+ &+}@}#}$}%}&}*}=}-{;=-}<!;}>},}'},/)}!}~}{}]}^})&/}(}_}:}<}[}}}|}1}M~2}K~3}4}5}4)6}B[7}}@> * * * * * * & g m#D$5.! * * * * * * * * * * * & E$L _.c+a+l#3@!$%#R@)@! * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * f 6.F.[.`.T.<%y+q#1@,@D * * * * * * * * * * * * * * & j 3+1 ] 7.7.7.7.7.F.N%{$<%s#k*,$* * E M /.8.0.@+S.!@(@Q@l+v+/@&@X&P * d a 8}9}0}a}b}c}d}e}f}g}h}s<J,i}0=K&J&K,W-j}/=k}l}m}n}o}/!p}q}r}s}t}u}v}w}A@x}W+y}z}A}B}C}D}E}d[F}G}<!H}I}J}K}L}M}N}D:O}P}v!f-Q}R}S}T}U}V}-&W}X}Y}Z}`} |.|+|@|#|$|%|&|Y.* * * * * * e Y@3+,.K K ^.).! * * * * * * * * * * ; , (.K.#@~@m+4@3@5@i+K.- * * * * * * * & & = e 4.S@% ).g & * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * 5.{ 8.1+W.k*!$x+U@>@c+! * * * * * * * * * * * * & E | {./.F.F.F.7.7.7.H.U@*@R@)$V.e * * B >.R / 0.@+T.C~>$Q@x+z+u+R@N%L.* #+a =#*|=|-|;|m<>|,|'|)|q;!|~|{|]|>;I&^|/|(|_|:|<|[|~!}|||1|_!2|3|4|5|6|7|x%5#5%8|9|0|a|b|c|d| { ><!e|f|g|h|i|o^j|Z_|<k|l|m|Q=n|o|p|q|r||=s|X$9$t|u|v|w|x|y|z|A|B|C|p+- * * * * C ).S H J 2.G./ |+/.6.Y@- * * * * * * * * * - ~.# J.R.a@3@4@4@9@_@$@E.> B } E h#;._ G 3+M ,.{ J R L ~.E & * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * & ;./.)@##!@n+W@_@{$l#2.* * * * * * * * * * * ! ~ ^.1 ].F.# |+|+F.F.Y.g+{$k#T%O@] * * * f 3+L '@$ O.V.C~_@+#x+=@S%R@T@/ * [ c z $,;%D|E|F|G|H|I|J|K|P=|=L|M|);)=X=j}N|O|P|Q,Q|m}R|v)h|S|T|U|V|r]W#W|X|2#3#Y|Z|`| 1.1+1@1#1$14!f|%1j)&1*1Z_=1E:-1p%;1>1,1p&'1)16-!1M|R*~1{1]1^#o@^1/1(1e^_1:1T%1 C ! f E E$~.H Q ( @ _.[.$ D.+ # /.L.C.1 i * * * * * * * i 3+'@Z.a+A+4@4@4@4@9@v+W.@ R J K R ] (.|+G./ r+)@<.}.<.Z@' h#= * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * ; !.(.9.d+R%!$4@2@v+Q%| & * * * * * * & ! > 3.B.I ] # Z@@ # # |+# a+<@A+[%]@6@D * * * ! E.J Y.9.s+T.C+_@+#y+=@S%[%)$:.* [ c.A <1[1}1F[G[|11121a$314151n|61710!81(,91:,01|,b'a1b1c1d1^)e1f1g1h1U#K^i1W#X#W|j1k1l1m1*^2!n1o1p1q1j)i'r1s1t1C!u1v1w1q%x1y1z1y/A1B1C1H=D1Z,E1F1G1H1I1J1K1L1M1N12@~$( M M ,.{ L 2.@ ]$K.5+N.N.7@}.9.a+1@/@>@@+C * * * * * * * e 4+/ 6)N@x+4@4@4@4@4@W@u+C+. 0.9.[.$ J.M.'$7+O.b+Q.P.c+<.'@P Y@i ; * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * & m#(.H.V.&@3@4@4@.#<%7.D B } B E h#m#~.O I ].F.'@/ Y.G.Z@@ # 8+S%S%F$>@O@G.* * * * & _ I @ |.7+.+9+x+g#y+p#{$1@l#I.* * d d.O1P1X;K-Q1R1S1T1U1V1W1X1m[Y1j};/Z1`1O| 2z>$&.2+2@2#2$2%2&2*2=2-2|^E{k$;2>2a/,2'2)2!2%<~2{21|]2^2/2(2_2:2<2[2A>}2|29:122232z:42.)+)526272f)829202a2b2c2d2e2f2Y&4@:@[@Z.C._.1.<.0.M.##P. +P.#@~@*@-@z+u+R@X&| * * * * * * * * = q+Z@s+:%+#4@4@4@4@4@4@9@l+j*{@X)V%U.a+r#,@o#d&O@)$l#j*k#/@j#~$H.).* * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * & ^$J 7@r#j+4@4@4@4@:@t## L Q Q J R ] 7.Z@]$C.r++ 8.'@Y.8.9+U@{$j#h+T@++- * * * * * ~ ,.F.D.'$X.R.v++#y+p#<@^@]@`.* * [ a z g2h2i2j21]k2l2m2n2o241k-p2q2,!a:{=r2s2t2u2v2w2x2y2z2A2B2/)''C2<]!{i$1^1_1_D2E2F2G2H2I2J2K2L2M2i'N2{>O2P2Q2R2p;S2!&T2U2V2W2A/p^4~X2Y2Z2`2 3.3+3@3#3$3%3&3*34@4@4@9@:@>@6@R.d+Q..+a+r#C+~$u+Q@_@m+ #/@R@T@|+* * * * * * * * * & S@I . R%!$4@4@4@4@4@4@4@4@9@0@(@%#=@p#:@.#3@4@9@3@.#Q@x+z+/@o+!@E * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * * e G K.!@m+4@4@4@4@3@ #t#7+I.}.[.}.$ $ [.a.)@C.r+C.'$g+j+{$i+o+)$8@b.* * * * * * 4.' ] _.I.'$2+&@+#y+p#<@F$X@T.* * [ c A =3-3;3g/|;|)>3,3'3)3!3P=/}^*~3{3]3_,^3/3(3_3:3<3[3}3|3132333P^`!.~&%h$!{~{~{43536373839303a39,U,N2b3c3d3e3$;@;j%f3w!g3j;(|h3i3j3k30<l3$[m3n3o3p3q3r3s3t3e&4@4@4@4@4@4@0@(@ #*@F$;@ #:@!$2@5@x+%#P@;@o+N%7.* * * * * * * * * * * ! ,$+ U;Q@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@3@V@2@5@l+v+u+R@X&1 * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * * * * f 4+@+u+9@4@4@4@4@4@5@[%W%~@W.@+. 1+I.5+2+0+N%v+q#S%k#o+l#O%E.* * * * * * * * h }+K Z@:.0.U%>$l+z+S%^@X@$#* * * d a R:u3T:v3w3x3y3z3A3B3C3D3E3F3G3.)H3I3a1J3K37=L3M3N3^&O3P3b1Q3K)n-$%,=v*.~`!`!R3S3T3^(U3V3W3X34,Y34,Z3`3 4.4<=+4>&q[@4#4$4%4*>O|&4*4=4F]-4;4s*>4,4'4)4!4~4{44@4@4@4@4@4@4@4@4@4@9@3@V@.#g#>$x+%#q#u+F$@#%@3.* * * * * * * * * * * * * & ,$H.<%3@4@4@4@4@4@4@4@4@4@4@4@4@4@9@3@V@!$Q@:@w+q#*@R@N%@ * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * * * * * * f 3+,@Q@W@3@3@3@3@3@W@g#%#<@;@<%k#u+p#%#v+<@*@F$j*T@,@N * * * * * * * * * * * } _ Q @ P.-@%#P@*@R@l#R.* * * [ c A ]4^4/4(4_4:4<4[4}4|41424M[34^344h[N,54s(64q;74849404a4b4c4b=L)w*x/x/,;n-n-x//[d4e4f4g4h4i4j4D>d3k4l44,m4n4o4p4q4r4s4q[t4u4$;v4w4x4x3v@y4z4A4B4C4D4|%E46.r#w+W@3@3@3@3@3@W@V@0@!$+#5@:@-@p#P@u+<%j*N% +! * * * * * * * * * * * * * * * & Y@`. #.#V@W@3@3@3@3@3@3@3@W@V@0@!$g#5@:@m+v+{$j#j*Q%I * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * * * * * * * * f /.g+k+_@5@Q@Q@Q@5@>$_@:@l+w+=@n+<@*@<%o+s#B+6)).* * * * * * * * * * * * * & 4.m#( o+U@*@^@>@O@# * * * * d a F4%+G4H4I4J4K4_#L#0$)3L4j-M4N4O4T~(=r2P4A;o;Q4H,$>R4s[S4s%f,T4T4t%**K)b=b=b=U4V4W4X4.2H>Y4Z4`474 5.5+5@5#5$5%5&5:*O~*5=5-5;5>5,5'5)5!5~5{5]5!~6;&#^5& & e !.T.U@_@+#+#+#Q@5@_@:@l+w+=@q#{$;@1@T%X&0+,$* * * * * * * * * * * * * * * * * * = N R.;@m+(@>$5@Q@Q@Q@Q@5@>$_@(@x+m+p#q#S%i+&@]@O%).* * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * - ( C$A+j+n+ #v+ #n+P@<@S%A+k#1@j*]@g+++^.; * * * * * * * * * * * * * * * * * e 1+o+h+s#O@b+h * * * * [ c /5(5|:_5:5<5[5}5|5152535455565#475859505a5b5Q4^}c5d5e5f5T*0=s%s%s%`=o-M)M)f,s%k]Z_g5%)K*h5>>q;D3p;i5j5k5o)>;[&Z1l5q[a5+4m5n5o5p5q5r5s5t5u5v5/$&#c@< & & & & & ;.2+<%n+z+z+z+ #n+j+{$*@j#[%T%l#t+$ E * * * * * * * * * * * * * * * * * * * * * * '.0.W%i+<@P@n+ #v+v+ #n+q#j+{$/@i+^@j*l#|@M * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * - D$1.0+d&T@@#j*h+j*@#l#%@U%9+C.G@e * * * * * * * * * * * * * * * * * * * * ! | F.(.G f * * * * * * < c@w5x5y5z5A5B5C5D5E5'(H|F5G5 5O~.[75E:Q*c{H5I5|2l|U,J5<&+->;'='=T*f,`=0=0=0=0=K5g3L5()M5N5m|O5c-k%s;94P5Q5R5<>J&S5%4T5U5V5W5X5Y5Z5`5 6.6+6w#v#c@^5& & & & & & & & ~ G.r#P%>@&@R@&@j*s#X&{@0+]$E$& * * * * * * * * * * * * * * * * * * * * * * * * * i D$8.R.C$%@]@>@h+o+o+h+>@]@X&~$X)0.;.* * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * ! h ,$S ,.Q K { 4+) S@e * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * c @6#6$6%6&6*6=6-6;6>6,6'6)6!3!6~6{6]6^6/6 ](6|=_6:6+)<&5*5*<&l,'=f,f,>;>;>;>;+-<6=_[6}66=|6j%i%N=16_*268~36>;J&J&K&46t(566676869606a6_$x#=#v#|%& & & & & & & & & * * ! > }+I G.+ G.Q E.^$- * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * = g ^$b.^.{.J L J P >.3.% g & * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * & /_b6y[c6d6e6f6g6h6i6j6k6l6m6-&Q}n6[~p[o6p6q6h5r6s68'K&_&<&<&<&<&`=Z=5*5*5*5*5*0!t6u6.2v664w6x6y6z6L*A6B6N$C6>;K&5*`=:>~{L^W#4#y%X+y#[+w#/$c@< & & & & & & & & & * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * b@D6E6F6G6H6I6J6K6L6M6m29$|}N6S2K=x&p4O6n[p6n,P6Q64-J&J&i__&_&<&a=s%_&_&_&K&_&_&R6S6T6U6V6W6X6s6r464Y6Z6`6 7.7s%`=:>*%k$W#3#+7Z#D@d@y.-.&#b@& & & & & & & & & & * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * & & ; ! C f } E ~ @7#7$7%7!~&7*7=7-7;7>7,7Y}0$l6'7o;!&][)7_*!70%~7{7+-],J&4-4-J&<&o-Z=K&K&_&K&],)=_&]7^7S[/7(7^3_7^[q[x&P=:7<7[7}7|7172737475767I$77x.=.z b [ & & & & & & & & & & * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * & f g g g g g g g g g g g g g g g g g g g g g g g g g g g g B j j j j j j E E E E S@S@S@S@S@S@S@S@S@S@S@D D D D D D 5.).~ ,$,$Y@;.;.F q+N }+G 3+>.O {.{ J R 879707a7b7c7d7e7f7g7h7J#i7j7k7l7r;v!m7n7o7p7q7_&0=Z=[&l,_&J&5*n-T*J&J&J&J&J&J&_&w*r7s7t7N|05u7v7w7,&x7y7z7A7x4B7C7>{]/'_D7E7F7G7H7I7J7K7L7,$,$~ % ^$^$^$^$^$^$D S@S@S@S@S@S@S@S@S@S@S@E E E j j j j j j j } g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g g 4.! * * * * * * * * * * * * * * * @ ",
"@ * * * * * * e F ' ,.{ I I I I I I I I I I I I I I I I I I I I I I I I I I I Q J J K K K K K K K K K L L L L L L L L L L L R /./././.].].( ( 2.2.(.L.7.F.# @ G.Y.8.]$C.)@D.:.t$M7N7O7P7Q7R7S7T7U7D5V7O#W7X7Y7Z7`7 8H).8)=4*J&J&_&'=[&m)a=+8`=T*>;>;0=0=Z=m)t%@88<]3#805$8f3%8&8}}*8=8T1-8;8>8,8x3'8)8!8~8{8]8^8/8|+7.L.(.2.2.( ] /./././././.R L L L L L L L L L L L K K K K K K K K J Q I I I I I I I I I I I I I I I I I I I I I I I I I I I I I I I I I I {.N f * * * * * * * * * * * * * @ ",
"@ * * * * * & E$M Q (.Y.C.a.<.<.<.<.<.<.<.<.<.<.<.<.<.<.<.<.<.<.<.<.<.<.<.<.<.<.<.K.|.|.[.[.[.[.[.[.[.[.9.9.9.9.9.9.9.9.9.9.9.}.$ 0.0.0.0.0.H.J.5+7@7@1+Z.6+c+. 6)7+s+O.2+7+M.K.(8_8:8<8[8}8|818283848586878889808a80%K5)=I&4*4*+])=J&)=M)h$f,>;+-5*5*K&K&)=<&v%v%b8c8d8e8Q}c-W}f8g8'3h8i8j8k8l8m8n8o8p8q8r8r s8s+7+N.c+6+Z.1+7@5+5+I.H.0.0.0.0.$ }.9.9.9.9.9.9.9.9.9.[.[.[.[.[.[.[.[.[.[.|.K.K.<.<.<.<.<.<.<.<.<.<.<.<.<.<.<.<.<.<.<.<.<.<.<.<.<.<.<.<.<.<.<.<._.L _ } & * * * * * * * * * * @ ",
"@ * * * * * ! G 1 2./ K.M.s+d+R..+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+W.S.T.T.T.T.T.T.T.T.V.V.V.V.V.U.U.U.U.U.U.U.++a+a+9+9+9+9+9+V%r#!@!@$#p+~@N@8@[@C$8@$@,@U%l#t8j/u8v8w8x8y8z8A8B8C8O-D8E8F8G8H8I8'=_&K&J&)=)=4-4*)=`=&%T*J&J&4*I&4*I&I&i_c=$%'=J8K8L8M8N8O88$P8[4_#Q8R8S8T8U8V8W8X8Y8Z8`8 9F$h+N%R%C$o#i#~@,@p+r#r#0+9+9+9+9+a+++++U.U.U.U.U.U.U.V.V.V.V.T.T.T.T.T.T.T.T.T.S..+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+Q.6+)@]., } * * * * * * * * * @ ",
"@ * * * * * ! S Q |+:.7@@+S.C~U;F$w+w+w+w+w+w+w+w+w+w+w+w+w+w+w+w+w+w+w+w+w+w+w+w+w+w+w+w+m+y+y+y+y+:@:@:@:@:@:@(@(@(@(@(@(@(@(@(@(@(@+#2@2@!$!$!$!$0@W@W@W@3@3@3@3@3@0@w+u+q#-@Q@.9N1+9@9#9$9%9&9*9=9-9;9>9,9'9)9!9%%**m)'=:&_&)=)=J&_&K)h$0=J&I&I&I&J&J&J&)='=u%m)l,[&~9{9]9^9M#Z}/9(9_9:9<9[9r.}9|9192939494@4@4@9@9@9@3@3@3@3@3@W@W@W@V@!$!$!$!$!$2@g#>$(@(@(@(@(@(@(@(@(@(@:@:@:@:@:@:@:@y+y+y+m+w+w+w+w+w+w+w+w+w+w+w+w+w+w+w+w+w+w+w+w+w+w+w+w+w+w+w+w+w+k+ #u+F$s#d&e+'@S@* * * * * * @ ",
"@ * * * * * & N I @ <.'$Q.$#C$x+4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@9@>$:@>$g#.#W@596979899909a9b9c9d9e9f9g9h9i9l$i$6*$%u%t%s%'=<&<&L&6**%[&K&J&J&J&K&K&_&<&L&-/**w*v%%%h$j9k9l9C8m9n9o9p9q9r9s9t9u92939494@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@3@.#+#y+p#S%o+S.} * * * * * @ ",
"@ * * * * * * g 3+(.:.c+8+e+1@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@9@9@9@3@3@3@W@V@.#g#+#+#+#Q@g#v9w9x9%3y9z9A9B9g!c]C9D9E9F9G9U#}&i$&%6*,=d=**t%u%1^i$t%'='='=L&[&s%c=t%u%$%v*&%*%j$k$l$X#H9:(I9J9K9L9M9N9O9P9Q9R9S9Y&4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@4@9@V@2@5@x+=@{$1@X&# * * * * * @ ",
"@ * * * * * * * & S@3+L.<.7+[%V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@0@0@0@0@0@0@0@0@0@0@0@0@0@0@.#.#.#.#!$!$2@2@g#g#+#Q@Q@>$_@(@:@x+-@w+p#z+p#x+T9U9V9y9W9X9Y9Z9`9 0.0+0@02#X#V#k$M&i$*%&%&%*%W#;2%%3-3-d=$%,=P^%%e=h$i$j$k$V#W#6%3#5#z@<$#0$0%0&0*0N{=0-0;0_@+#g#g#2@2@!$!$!$.#.#0@0@0@0@0@0@0@0@0@0@0@0@0@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@V@.#2@5@:@w+ #/@[%l#M.* * * * * @ ",
"@ * * * * * * * * * ; S@^.# :%(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@:@:@y+y+y+y+y+y+y+y+y+x+x+x+x+l+-@-@m+m+w+k+%#p#=@z+v+n+P@j+{$u+A+j#F$[%<%>0 /,0'0)0N9!0~0{0]0^0._%*4#2#6%X#l$V#k$k$V#4#W#j$~{~{*%*%i$i$j$}&U#V#l$X#2#|&5#z@<$X+Z+_+d@/0(0_0:0<0[0u+P@n+v+=@%#k+w+m+m+-@l+l+x+x+x+x+y+y+y+y+y+y+y+y+y+:@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@(@:@x+w+v+<@i+h+N%9.* * * * * @ ",
"@ * * * * * * * * * * * ; j L F$<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@{${${${$S%S%S%S%u+u+u+u+u+u+/@*@*@*@*@A+;@;@i+j#j#k#F$^@1@R@&@j*T%s#X&B+f+9+'$}0|010203040506070809000Z#A@y@%*4#3#6%X#X#2#4%3#C_U#U#V#V#V#l$W#X#6%2#|&5#5%4%<$X+Z+y#:+[+y.=.-.A a0b0K 5+U.[@%@s#o+[%^@F$k#j#i+;@;@A+*@*@*@/@/@u+u+u+u+u+u+S%S%{${${${${${$<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@<@{${$/@j#R@X@k*}+* * * * * @ ",
"@ * * * * * * * * * * * * * * B.C+~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$W%W%d&k*U%C$C$C$[@[@[@[@f+$@e+C~C~C~!@.+ +d+O.2+c+5+|._.|+Q S ) j = & & * * d c0!4d0e0f0g0h0i0<(`+6#X+W+x}4%5%%*5#J$I$z@3#2#2#2#2#j0|&k05#%*z@A@<$X+Y+D@_+d@[+y.z.-.z a c d * * * & ; i ,$, {.7.+ a.5+6+2+@+X. +R.V%C~C~e+p+O%f+[@[@[@[@[@C$U;:%k*d&W%W%~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$~$d&d&e+{ * * * * * * @ ",
"@ * * * * * * * * * * * * * * * f % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % h#h#^$> h B B B B B B B } g f - - - e ; & & * * * * * * * * * * * * * * * * & & < l0m0q n0o0p01%[+:+_+H$ &q0X+Z#W+l&`%r0J$J$J$y%y%A@z#<$B@C@l&6#`+_+:+<+x.y.=.-.z A b d [ * * * * * * * * * * * * * * * * * * & ; e - - - - 4.} B B B B B B B h S@^$h#h#% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % ^$% } * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * & & & & E4s0t0u0/$=.z.y.x#v0G$G$_+H$H$771%`+Y+Y+Y+Y+Y+6#Z+Z+`+y#77d@<+x.y.z.=.-.z A b c.[ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * & & & & & & < b@a A z -./$=#w#`#x.x#1%x.w0<+:+:+:+:+:+d@d@[+w.x.y.z.z.=.-.z A a c d [ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * & & & & & & & & & d c b a u#t_v#/$=.=#=.=.=#y.y.y.y.y.y.y.z.z.=.=.-.-.z A a a c d [ [ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * & & & & & & & & * * * [ < < b@b@d.A &#z A z -.-.-.-.-.-.-.z z z A d.a c c d d [ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * & & & & & & & * * * * * [ [ & d < < b a a a a a a a a a a b c c d d [ [ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * & & & & * * * * * * * * * * * * [ d d d d d d d d d d [ [ [ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * x0y0* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * & z0A0B0C0D0E0F0G0H0I0* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * & J0K0* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * L0M0N0O0P0Q0R0S0T0U0V0W0X0Y0Z0`0* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * *  a.a+a@a* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * L0#a$a%a&a*a=aN0-a* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * & ;a>a>a,a* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 'a)a!a~a{a]a^a* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * /a(a>a>a_a:a* * * * * * * * * * * * * * * -a<a* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * [a}a|a1a2a3a4a* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 5a6a7a8a9a/_* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * L00aaa>a>a>aba* * * * * * * * * * * * * * * cadaea* * * * * fa* * * * * * * * * * * * * * * * * * * * * * * * * * * gahaiajakalama* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * E4naoapaqarasatauavawa& * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * N/xa>a>a>a>ayas0* * * * * * * * * * * * * * zaAaL0BaBaBa* & Ca* * * * * * * * * * * * * DaEa_5FaGaHaIaJaKaLaMaeaNaOaPaQaRaSaTaUa* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * eaVaWaXaYaZa`a b.bVa+b@bpa#b$b%b/_* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * &b*b=b-b;b;b;b>b* * * * * * * * * * * * & ,b'b)b!b!b!b!b!b~b{bNa* * * * * * * * * * * * & L0[ ]b2(:_^b/b(b_b:b<b[b}b|b1bRa2b3b* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 4b5b6b7b8b9b0babbbcbdbeb$bfbgbhbibjbkblbmb< * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * nbob* * * * * * * * * * * * * * * & pbqbrbsbsbsbsbtbubvb* * * * * * * * * * * * * * * * * * * * * * ea-awbxbybzbAbBbCb; * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * & DbEbFbGbHbIbJbKbLbMbNbNbNbNbNbObPbQbRbSbTbUbVbWbXb/_* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * [ YbZb* * * * * * * * * * * * * * * Naea`bAaMa* * * * MaMa* * * * * * * * * * * * * * * * * * * * * *  c.c+c@c#c$c%c&c*c=c-c;c& * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * >c,c'c)c!c~c{c{c]c^cNbNbNbNbNbNbNbNbNbNbNb/c(c_c:c<c[c}c|c1c2c& * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * 3c4c5c6c* * * * * * * * * * * * * * * * 7c8c* * * * * * * * * * * * * * * * * * * * * * * * * * * * * 9c0ckaacbcccdcecfcgchcicjce.& * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * kc{clcmcncocpcqcpcrcscNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbtcucvcwcxcyczcjbAcBcCc* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * DcEcEcFc* * * * * s0Na* * * * * & GcHcHcHcHcHcHcHcHcIc& * * * * * * * * * * * * * * * * * * * * * * JcKcLcMcNcOckaPcQc& v^RchchcScTcH(* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * %:UcVcWcXcYcZc`c d.dNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNb+d@d#d$d%d'ctc&d*dgb& * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * =d-d;d;d>d,d* * * * 'dea* * * * * ; )dEc!d!d!d!d!d!d!d~d& * * * * * * * * * * * * * * * * * * * * * * {d]d^d/d(dLc_dNc:d* * E(<dhchc[d}d|d& * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 1d2d3d4d5d6d7dwa8d9dObNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNb0dadbdcdddedfdgdhdCc* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * idjd;d;d;dkd* * ldmdndodpdpdpdpdqd&brdsdtdtdtdtdtdtdudvd& * * * * * * * * * * * * * * * * * * * * * * wdxdydzdAdBd/dCdDdNa* * EdFdhchchcGdHd< * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * IdJdKdLdMdNdOdPdQdRdNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbSdTdUdRbVdWdXdYdZdxcE4* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * ; `dEc;d;d;d e.e* +e@e(a#e$e$e$e$e%e(a&e* * * * Na* * * * * * * * * * * * * * * * * * * * * * * * * * & *e=e-exdxdydzdAd;e>e* * * ,e'ehchchc)e!e& * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * ~e{e]e^e/e$d(eTd_eNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNbNb:e<eZc[e}e|e1e2e* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * 3e4e5e5e5e5e6e7e* 8e9e0eaeaeaeaeaeaebec0* * Nacedeee* * * * * * * * * * * * * * * * * * * * * * * * * & fegegehe-e-exdxdiejeke* * < lemehchchcneoe* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * peqe creseteteteteteteteteteteteteteteteteteteteteteteteteteteteteteteteteteteteteteteteteteteueve= wexe* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * yeMa* * * * * * * * * zeAeBeCe* * * * * * * * * * * * * * * * * * * * * * * * * L0Degegegegegehehe-eEeFeGe* * HeIeJehchchcKe_'* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * LeMeMeMeMeMeMeMeMeMeMeMeMeMeMeMeMeMeMeMeMeMeMeMeMeMeMeMeMeMeMeMeMeMeMeMeMeMeMeMeMeMeMeMeMeMeMeMeMeMeNe& * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * Oe* * * * * * * * * * PeQeReSe* * * * * * * * * * * * * * * * * * * * * * * * * NaTegegegegegegegegegeUeVeWe* XeYeZe`e[dhchc f* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * .f+f+f+f+f+f+f+f+f+f+f+f+f+f+f+f+f+f+f+f+f+f+f+f+f+f+f+f+f+f+f+f+f+f+f+f+f+f+f+f+f+f+f+f+f+f+f+f+f+f@f#f* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * $f%fmd& x0&f&f&f&f*fpd* * * * =f-f* ;f* * * >f,fL0* * * * * * * * * * * * * * * * * * * * 'fgegegegegegegegegegehe)f!f~f{f]f^f/f(fhc_f<1* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * NaE4*:e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.e.H(* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * :f<f[fea}f|f|f|f|f1f2f* * * * 3f4f5f6f& & 7f8f9f& * * * * * * * * * * * * * * * * * * * * 0fafgegegegegegegegegegehebfcfdfefffgfhf'eifjf* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * kflfVbVbVbVbVbVbVbVbVbVbVbVbVbVbVbVbVbVbVbVbVbVbVbVbVbVbVbVbVbVbVbVbVbVbVbVbVbVbVbVbVbVbVbVbVbVbmf* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * nfofpf* qfrfsftftfufnf* * * * vfwfxfyfzfAfBfCfDf* * * * * * * * * * * * * * * * * * * * * EfFfgegegegegegegegegegegegegeGfHfIfJfKfLfMfNf* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * /_Of.b.b9aPfPfQf.b.b.b.bRfPfPf.b.b.b.b9aPfPfSf.b.b.b.bTfPfTf.b.b.b.bQfPfPf9a.b.b.b9aPfPfRf.b.b.bUf* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * & Vf& * * * * ea* * * * NaWf,bXf;dYfZf`f* * * * * * * * * * * * * * * * * * * * * * *  g.ggegegegegegegegegegegegegegege+g@g#g$g%g* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *  b&g*g=g* * * * -g*g;g* * * * >g*g*g,g* * * * 'g*g)gL0* * * !g*g*g~g* * * {g*g*g]g* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * & ^g/gpd* * * * * * * * * (g-f_g.e:g* * * * * * * * * * * * * * * * * * * * * * * * * <g[ggegegegegegegegegegegegegegegege}g|g1g2g3g4gT05g6g7g8g* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 9gNbNb0g* * * * agNbNbbg* * * cgNbNbdg* * * L0egNbfgL0* * * ggNbNbhg* * * igNbNbjg* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * kglgmgng* * * * * * * -aogpg* & qgrgsg= * * * * * * * * * * * * * * * * * * * * * * * Natguggegegegegegegegegegegegegegegegegegegegegegevgwgxgyg* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * zgNbNbAg* * * * BgNbNb-a* * * CgNbNbDg* * * eaEgNbfgL0* * * ddNbNbue* * * FgNbNbGg* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * & HgIgJgKg* * * * * * * LgMgNgNaOgPgQg'bRgNa* * * * * * * * * * * * * * * * * * * * * * * * SgTggegegegegegegegegegegegegegegegegegegegegegegegeUg* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * VgNbNbWg* * * * fgNbNb<_* * * XgNbNbYg* * * MaZgNb`gMa* * *  hNbNb.h* * * +hNbNb@h* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * C #h& $hKg* * * %h(_* * &h*h* =h-h;hza>h,h; * * * * * * * * * * * * * * * * * * * * * * * * Na'h)h!hgegegegegegegegegegegegegegegegegegegegegegeUg* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * ~hNbNb{h* * * [ ]hNbNb^h* * * /hNbNb(h* * * ea_hNb:h[ * * * <hNbNb.h* * * FgNbNb[h* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * *  c}h:a$h|hea; 1h2h3h* * 4h5hpg6h7h8h* Ma9hpg* * * * * * * * * * * * * * * * * * * * * * & bg0hahbhchdhehgegegegegegegegegegegegegegegegegegegegefh* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * ~hNbNbgh& * * & hhNbNbih* * * jhNbNbkh* * * 8#NbNbNb& * * * lhNbNbmh* * * nhNbNboh* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * phqhrhshthuhvhwh(_* * xhyhzhAhBh& * ChDhBa* * * * * * * * * * * * * * * * * * eaMaM/EhFhGhHhIhJhKhLhMhNhOhgegegegegegegegegegegegegegegegegegePh* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * ~hNbNbQh[ * * MaRhNbNbSb* * * ggNbNbSh* * * `c_hNbNbL0* * * ThNbNbUh* * * VhNbNb]h& * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * 1dWhXhYhZh`h is0* * * & .i+i@iga* * #iRe* * * * * * * * * * * * * C]$i%i&i*i=i-i;i>i,i'i)i!i~i{i]i^i/i(i_i:i<i[i}igegegegegegegegegegegegegege|i* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 1iNbNb2i& * * & fdNbNb3i* * * 4iNbNb5i* * * 6iEgNbfdBa* * * 7iNbNb8i* * * 9iNbNb]h& * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * 0i& aibiciy0Na* * * * * Ge[ * * dieifi& * * * * * * * * * * * * * gihchchchchchchcJeZehiiijikilimi]inioipiqirisitiuiviwixigegegegegegegegegege|i* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * yiNbNbQh& * * [ NbNbNb9i* * * ziNbNbAi* * * BiNbNbCiDi* * * EiNbNbkh* * * FiNbNbGi& * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * Hi* * * * * * * Ii* * *hJiKiNaLiMiNiOiPiBa* * * * * * * * * * * * QihchchchchchchchcRiSiTiUiViWiXiYiZi`i j.j+j@j#j$j%j&j*j=j-j;j>j,j'j)j!j~j{j]j* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * jhNbNbYdke* * & NbNbNb^j* * NaAiNbNbAi* * * /jNbNbNb(j* * * lfNbNb_j* * * :jNbNb<j& * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * [j* * * * * * }j^g* * |j1j* (g2j3j4j5j6j& * * * * * * * * * * * * 7jhchchchchchchchchcRiLfKf8j9j0jajbjcjdjejfjgjhjijjj* * * * * L0kjljmjnjojpjqj* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * ggNbNbrjsj* * veNbNbNb9i* * * AiNbNbtj* * * ujNbNbNbih* * * vjNbNbwj* * * xjNbNbfd& * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * yjzjAjBjBjBjBjBjBjCjDj* * EjFj* GjNiHj-a& IjJj* * * * * * * * * * * * gihchchchchchchchchchc'eLfKjJfLj0jMjNjOjPjQjRjSj* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * TjNbNbncVa* * UjNbNbNbVj* * L0WjNbNbXj* * * YjNbNbNbZj* * `j kNbNbAi* * * .kNbNbNb& * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * +k@k#k$k%k%k%k&k*k=kN/* * -k;k>k,k'k)k* & !k& * * * * * * * * * * * * gihchchchchchchchchchchc(fhf~k]f{f{k]k^k/k(k* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * ~cNbNbnc_k* * BiNbNbNb:k* * * <kNbNbQh* * * [kNbNbNb}k* * ~g|kNbNbWj[ * * .kNbNbNb1k* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * & 2kE41d1d1d1d; * * * * pg3k4k5k6k* * 7k8k* * * * * * * * * * * * * gihchchchchchchchchchchchc(f/f9k0kakbkck* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * dkNbNbnc_k* * BiNbNbNb.k* * BaekNbNb2i& * * fkNbNbNbgk* * 9gncNbNbWj* * * hkNbNbNb{c* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * @a* * * * * * * * * * * [ zeik* * * -aMa* * * * * * * * * * * * * gihchchchchchchchcjkkklkmknkokH/pk* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * ThNbNbqkrk* * skNbNbNbtk* * * lfNbNbQh< * * ukNbNbNb9i* * vkwkNbNbxk* * * ykNbNbfdzk* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * __AkI(ea>bBkBkBkBkCkF@* * * * & DkEkFkGkGkHk& * * * * * * * * * * * * * * IkJkKkLk7jMkNkOkPkQk_/&:& L0* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * [ RkNbNbSkTk* * UkNbNbNbVk* * E4YdNbNb k`j* * WkNbNbNbXk* * YkwkNbNbZk* * * `kNbNbNbBi* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * *  l.l+lea@l#l#l$l$l%l&l* * * * -f*lAh=l-l=l-h& * * * * * * * * * * * * * * H(;lH(veE4Maea* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * >lNbNbNb,l* * 'lNbNbNb)l* * !lebNbNb|k~l* * {lNbNbNb]l* * ^lSdNbNblf* * * `kNbNbNbzk* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * *  a/l(l* _l:l<l[l[l}l|l* * * * 1l2l3l4l5l4l6lNa* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * & ed+f+f7l8l* * 9l+f+f+f0l* * kfal+f+fal_k* * .f+f+f+fbl* * uj}c+f+fcl* * * dl+f+f7lel* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * ea* & fl& * * * * * * * * * 4hdi* * glhl* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * iljljljlkl* * qejljljlvk* * llmljljlmlJ'* * nljljljl!l* * oljljljlpl* * * _kjljlqlK/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * s0rl& * rlsltlul& * * vlwlxlnbylzlAlBlClBa* * * * * * * * * * * * ).b.b.F F F F ) E$~ * j E$'.'.'.'.'.).4.* * * * B ).% ).h * * * * * B % % ).j * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * kfzcDlDlDlDlDlDlDlDlDlDlDlDlDlDlDlDlDlDlDlDlDlDlDlDlDlDlDlDlDlDlDlDlDlDlDlDlDlDlDlDlDlDlDlDlDlDlEl* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * & FlGl& ; HlIlJlKlLl* * MlNlOlcaz0PlQlBfRlMa* * * * * * * * * * * * 8@5@>$(@(@(@(@:@x+l#* 6)x+m+m+m+m+m+%#*@b+E * * '$%#%#p#k*e * * * * f+p#p#p#U.* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * SlTlUlUlUlUlUlUlUlUlUlUlUlUlUlUlUlUlUlUlUlUlUlUlUlUlUlUlUlUlUlUlUlUlUlUlUlUlUlUlUlUlUlUlUlUlUlUlVl* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * H(slMa* Wl>atl= Xltf* * * ogLi* * 6lYlZl`l* * * * * * * * * * * * * d&4@W@j#[%F$<%<%<%U;* #@4@4@ #/@/@z+9@4@4@d&& * X.4@4@4@!$D$* * * '.9@4@4@4@C+* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * [k m m m m m m m m m m m m m m m m m m m m m m m m m m m m m m m m m m m m m m m m m m m m m m m m m.m& * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * +m@m#m$m%m&m*m* =m-m* * * * * * * * * [ ;m* * * * * * * * * * * * * W%4@(@N e - - - - e * #@4@4@Y.i i } | u+4@4@/ * X.4@V@*@4@U.* * * S.4@[%9@4@C+* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * El>m>m>m>m>m>m>m>m>m>m>m>m>m>m>m>m>m>m>m>m>m>m>m>m>m>m>m>m>m>m>m>m>m>m>m>m>m>m>m>m>m>m>m>m>m>m>m>m>m,m& * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * Ma'm)m!m.aJg* ea~m{m* * & ]m^m/m(m(m_m:m<mBa* * * * * * * * * * * * W%4@(@E.j j j j j - * #@4@4@7.* * * * @ 9@4@e+* X.4@V@'$4@q#h#* S@j+9@5+9@4@C+* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * & [m}mXl* * * |m1m* * 2m3m;d4m5m5m5m6m7m* * * * * * * * * * * * * W%4@4@4@4@4@4@4@4@M.* b+4@4@7.* * * * q+(@4@Q%; X.4@V@M *@9@a.* 8.4@i+>.9@4@C+* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * < }h8m& * * * * * * * * 9m0mamDkbmbmbmNg-a* * * * * * * * * * * * * W%4@V@>@X&X&X&N%]@/ * b+4@4@7.* * * * 3.5@4@Q%; d+4@0@M 7+4@^@= X@4@7+G 4@4@C+* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * Na* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * (_cmdmMa* * * * * * * * emfm* * * * * * * * * * * * * * * * * * * * a@4@:@F * * * * * * * b+4@4@7.* * * * L.9@4@e+*  +4@0@>.q+:@4@$ 2@W@).E.4@4@V%* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * gmhm* * * * * * LeTflleaim1d* * * * * * * * plgmSl* jmgmkmlmgmmm* * * * * * * nmompmqmgmgmgmgmgmgm9a* kl8lgmrm[eol< * * * * * smtmum]l~g& * * vmgm4bplgmgmgmgmgmgmgmwmL0gmgmgmgmgmgmgmxm* qm,lK/qmgmgmgmgmgmgmgmqm* * * * * @ ",
"@ * * * * * * * * * * * * * * * * &eym= * * * * * * * * 5fzm6l* * * * * * * * * * * * * * * * * * * `@4@:@F * * * * * & * b+4@4@(.* * * F <%4@4@/ *  +4@.#4+* R%4@!$4@R%* E.4@4@0+* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * NbTh* * * * * * `kAmBm* Xabb[ * * * * * * * CmNb+h* DmNbEmFmNbGm* * * * * * ldHmImIdjgNbNbNbNbNbNblf* zgSdNbNbJmKmLmMm* * * peYdNbNbNbncNm* * VkNbOmPmNbNbNbNbNbNbNbAi* NbfdNbNbNbNbNbQm* RmSkSmTmNbNbNbNbNbNbNbUm* * * * * @ ",
"@ * * * * * * * * * * * * * * * MaVm*bWmXmYmZm`m& Dczmzmzm n.nZl+nzm@n& * * * * * * * * * * * * * * `@4@3@m+%#z+ # # #g+* b+4@4@%#u+/@j++#4@4@%@! *  +4@.#4+* |+9@4@3@# * E.4@4@0+* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * NbTh* * * * * * `kAmBm* fg7l#n* * * * * * * CmNb+h* DmNbEmDieb$n%n* * * * * &nNb*n* jgSk=n-n-n-n-n;n* zgSd>n,nlb'ntc{hve* )n!n7b~nreXb{n]n4b* VkNbOm^n-n-n/nNb(n-n-nel* Nbcb-n-n-n-n_n:n* RmSkSm<n-n-n:jNb[n-n-nhg* * * * * @ ",
"@ * * * * * * * * * * * * * * * * }n|n1n|n1n2n^g-a3n4n5m5m5m5m5m5m5m5n& * * * * * * * * * * * * * * :%(@(@_@_@_@_@_@>$T%* ##>$>$>$>$>$5@>$z+S.> * * P.Q@:@3+* j j#+#i+} * G 2@2@U.* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * NbTh* * * * * * `kAmBm* fgNbta6n< * * * * * CmNbzk* DmNbEm* ~c7n8n* * * * ; (c7l9n* jgSd0n* * * * * * zgSdRm* * ldan7lbn* ueNbcn* * * ~ldn* * VkNbOm* * * enNbfn* * * * NbWg* * * * * * * RmSkSm* * * gmNbum* * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * eamd@a@a@a@agn+m-ahnnb<ainininininin:g* * * * * * * * * * * * * * * e - f g g g g B E h * f S@^$^$^$^$h#E * * * * * E E$E$e * * ,$b.).* * f 3.}+'.* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * NbTh* * * * * * `kAmBm* fgjnkntaln* * * * * CmNb+h* DmNbEm* plqkmnMa* * * wm7l7iE4* jgSd{c* * * * * * zgSdRm* * * ,gJmnn* KbNbdd* * * * * * * VkNbOm* * * enNbon* * * * NbWg* * * * * * * RmSkSm* * * gmNbum* * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * (_y0& * * * & pn* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * NbTh* * * * * * qnAmBm* ]h$nrnXasntn* * * * CmNb+h* DmNbEm* & unvnOf* * * wnEgxn* * jgynznAnAnAnAn&:* BnSdRm* * * CnObwe* smDn1e*d~g[ * * * * VkNbOm* * * enNbEn* * * * NbFnAnAnAnAnGnld* RmSkSm* * * gmNbum* * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * F@HnInJn* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * NbTh* * * * * * `kAmBm* fg2i* KnLntaMn c* * CmNbzk* DmNbEm* * NnOnPn& * rnQnRnE4* * jgSnpaTnTnTnTnUn* zgSdVnWnqemh!nfgXn* * ZcYnZn`n o.o< * * VkNbOm* * * enNb+o* * * * Nb@oTnTnTnTn#o$o* RmSkSm* * * gmNbum* * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * & %o&o*o-m* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * NbTh* * * * * * `kAmBm* fg2i* * =o-o_e;o* * CmNb+h* DmNbEm* * vekn>omb* ,oNb'o* * * jgta)o!o!o!o!o~o* zgSdjb{o]oNbFb^o* * * * llKb/o7nta*d& * VkNbOm* * * enNbon* * * * Nb(o!o!o!o!o!oDb* RmSkSm* * * gmNbum* * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * = _o; :oKg* * * L0Na* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * NbThNa* * * * * qnAmBm* fg2i* * * <oXa[o}o* |oNbzk* DmNbEm* * * CgNb1o& Bgeb2o* * * jgSd{c* * * * * * zgSdsa3o7n4o/_* * * * * * * < ^nkbOb5o* VkNbOm* * * 9iNbfn* * * * NbWg* * * * * * * RmSkSm* * * gmNbum* * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * = 6o& $hKg* * __tl7o* * 8o9o0o0oao=m^gea; boH(co0o0oufI(do0a0o0oeofo9o0ogohoioWhjokolo@amo& noooporfvepdqo0o0orobg2f_lsoto2(uosl0o0ovo& /l|l* bgwoxo0oyozoAoBoCo0oDoEo* Fo(_* & :feaGoHo* * * tfIo* * * * * * * * * * * * * * * * EgJo& * * * * ldknXcKo* fg2i* * * * JbLo7lfkMoNb+h* DmNbEm* * * 8#0dhhNofdOo* * * * jgSd{c* * * * * * BnSdRmKn(oRdPo* * * * Ba* * * * QoNbRo* VkNbOm* * * enNbEn* * * * NbWg* * * * * * * RmSkSm* * * gmNbum* * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * & SoToUoVoWoXoYo!mpf* * Zo`o p p:opd.p aKg+p* @p#p p$p%p&p*p p p=pLl-p p3h;p>p p,pHo'p)pzos0!p~pnfof{p]p^p/p p(p___p:p<o<p[p}poo/p p|pMa1p2p& bg3p|l p4p5pci6p7p p8p9p* 0pap* & bpBacpdpep* +mfpgp* * * * * * * * * * * * * * * * ]eXj%:* * * * Bmhpsave* fg2i* * * * * Vaip@o!cNb+h* DmNbEm* * * * jp_ekptalp* * * * jgSd{c* * * * * * zgSdRm* mpSknpop* opppqpea* * * _kEgVk* VkNbOm* * * enNbon* * * * NbWg* * * * * * * RmSkSm* * * gmNbum* * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * nfrp|fsp.atpupvpea* * wpxpyp]pN/* >pzpApld* Bpap* Cp-mDpEp]p]pK(LlFp* * GpHp* IpJp* KpLps0MpNpOpPpve]pQp]p]p}j(lRp* * *mSp}pIp]p]p{gMaTpUpVp#f3p* * WpXp* ngYp* & Zp* 0pap* L0bpBa`p quf* .q+q@q* * * * * * * * * * * * * * * * anZndg* * * & lbfd~c* * fg2i* * * * * * DbkpNbNbzk* DmNbEm* * * * #q$qNbxkE4* * * * jgSd{c* * * * * * zgSdRm* &  dfdse& & %qtc&q* * Ma*qNbyi* VkNbOm* * * 9iNb=q* * * * NbWg* * * * * * * RmSkSm* * * gmNbum* * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * eaqd-q;q[j>q,q* * * * wp'q)q)q!q* &:~q{q& * ]q^q/q(q_q:q<q)q)q[qLl}q|q1q2qll* IpCk* KpLp& 3q4q5q6q7q]p8q9q)qYm(l0q* *  c= aqbq)q)qcqMadqeqfqgqhq* * WpXp* &eiqjqkqlq* 0pap* eabpBamqnqoq(_pqqq@q* * * * * * * * * * * * * * * * rqHmqksqtquqjpscmcvq* * fg2i* * * * * * * [ekpNbzk* DmNbEm* * * * GewqNbtm* * * * * jg7l dxqxqxqxqyq* zgSdRm* * zqAqscBq* uesnCqDqNnEqFqGq1k* VkNbOm* * * 9iNb+o* * * * Nb*gxqxqxqxqHq2c* RmSkIq* * * gmNbum* * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * ; }pop* * ea* * * * * * wpgoea* ea* Jq!qKqLq* MqNq}j1m& &pOq* * * LlPq*my0Qqpf* IpCk* KpLps0Rq* * Sqto(lTq* * NagnUqL0* VqWq}pqo* * * MadqL0Xqofhq* * WpXp* ngYqrlZq`q*  rK(* & fqBamqmo=bFo.r+e@q* * * * * * * * * * * * * * * * * +rknEgNbNb7n@rZc* * * ]h2i* * * * * * * * #q#rzk* {lNbEm* * * * * $r:e1m* * * * * jgNbNbNbNbNbNbQh* zgSdTm* * * bdjn%r&r< *r7bfdNbCiib=r* * tkNb-r* * * 9iNbEn* * * * NbNbNbNbNbNb;rQm* >rSkTk* * * ,rNb'r* * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * ; -q)rVoXlpk* ea* * * * wp!r~r~r{r]r9o& ^r/rpd(rap* * * _r:r~r~r<rLlth* * [rNp* Ip}r* }rkopdfq|rsf1q1r(l2r~r3r4rkc5r6r-m7r8r}p9r~r~r0r cdqL0& arbr* * Wpcr* ngYp* * dr* 6ojq~rqoarMa`pmo3her3h+egp* * * * * * * * * * * * * * * * * * 1mOf6afrgrld* * * * $dhr* * * * * * * * * gbkf* pmir#m* * * * * opKb* * * * * * 1kiriririririrjr* ldkr;c* * * * vqirop* * PomhCnbnlr* * * pmirld* * * klir&:* * * * iririririririrop* ;cmrll* * * lrir`j* * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * ; nrorprqrdo+mea* * &:rrrrrrsrtrDi* * ur&:tr; * * * vrrrrrrrur(_ur* * ]pve* wrDi* 1(xr* ,qyrvpzr[ +mArrrrrBr& CrDrErWo; 0iFrrrrrGr& Hr& * *mIr* * ]pJr* s0qd* * Kr* ld8eLrmoK(* wr1(ldMr= &:Nr* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * ]bOr9pPrkg* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * Qr* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * ea; x0RrshSrTrUr* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 1kVr7iWrXrTdYrab& * * +mZr`r`r`r`r`r`r s* .s>g* * * * * * * * Vl`r+s@s`r`r`r`r`r`r`r#sea* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * c0$sHl%s&s9e*s&:Ma* * JrQr* * = :aE4pf=s a-s* E4|l@a aF@Mamdy0y0nf= * * * ]b|ly0y0K(&  cep* (_y0=sy0(_* $fJry0y0y0y0& (_*m* * * Pp* * * ld;sy0y0<o* * * & *mld* * = pf; 1(y0y0y0pd= y0y0y0N/Na& v_* * H(>s& * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * [ ,liptc8b,s[n;g}cjb#sll* __Wrtc's)s)s)s)s!s* Dm~s@s* * * * * * * gmNbum{s)s)s|kSn]s)s)s^s* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * L0so>a/s(s aMa* * * * * (pFl* * _s:s6r i<s[s}s< |sPq<s1s2sC 3s-b*bWm4s* * * $h5s4q6s7seoCr8s* 9s0sqfasso* bscs*bdsesfsI(gshs&:* & is* * * jsks;b*bls* * * pdmsnsea* 6pospsofqs*b*bAksrrsss6stsusfovsMa* )qws=s* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 5bxsysfrzs* *  c2dAsObBs* DiWrQhqe* * * * & * DmNb`n%b* * * * * * gmNbum& * * zgSdjg* * & * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * qrLr1mMa* * * * * * * I(5rE4Ba.pOpCs:a* eaDstrpq^r* & thEshq cMa&lFs* * * $h0o* NaLlGsCrHseaIsbg* bgJsE4KsnfMaLsMs* ldNsvpOs* & Ps* * * +k_leaMaMa* * * apQsRsL0ldpqSs@6TsUseaea* VsWsBaNaXsYs4(ZsMav_&oDjrf* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * CcGqpaih* * * * * * &:`s t* __WrQh.t* * * * * * DmNb+t@t#t* * * * * gmNbum* * * ZcSd$t* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * Ma%t& * * * * * * * * * * rf&t@a*tL0=tJr* * -t;t>t,t* * 't7o)tqqqq!t~t* * * bi0o* * {tWs*mHs* QsMaps]tyr; Ks<o* Ls^t* /tgs1m(tve& Ps* * * +k_t:t:t0a* * * ,t>t@l<t[t}t|t@6Ts1t:t2t6p3ttl* * 4t-t4(ZsMamo5tck6t1m* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 7tNb8t* * * * * * * * * * * __WrQh.t* * * * * * DmNb9tpays.o* * * * gmNbum* * * zgSd$t* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * #m0t1(L0(latatatatbt1(* * * * * od>tct3qBadtJr* * thet rpd* * 'tFr*oftgt0p$s* * * bi0o* * htWsCrHseaitMajtktrs1mKs<o* Ls^tealtmtntotpt& Ps* * * +k_l* * * * * * apqtrtjostaq|t@6TsUs* * * Vstl* * Hpis4(Zs#fWsbentttCk* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * < utebvt* * * * * * * * * * * DiWr)senwtwtwtwtrk* DmNbYk%b$qxt<n* * * gmNbum* * * zgSd$t* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * :fytph* -tSrSrSrSrzt&l* * * * * * FpAtepeathIggnBt;p,tCtDtgnZqEtFthqMa* ^gWs* * * $h5q8o8oHoGt*mHseaHtItgn:oJt& Ks<o* LsMspdKt{m8pLt(sbgqs,q,qMt&lis,q,qwr* * * ap>t c~q3skc|t@6TsNt,q,qOtPtQt8o,qRtStfoZsrlNsTt8pUtVt* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * qeWtXtld* * * * & YtZtZtZtZtSlDiWrNbNbNbNbNbNb`t* DmNb u* sk.u+u@u* * gmNbum* * * ZcSd$t* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * @aUp#u* qr$u%u%u%u&u*m* * * * * * VmZm* L0&bIp*uFl leaht=u-uFl;u>u,u& * ,q'u* * * fo)u!u~u_ofo&:{u* ]u1s-u^uusMa/u1(* Us aciLr[ * ! (u& _u:u:u.q4t<u(s:uDp* * * #mWl[ [u]r* }u:a|u1u:u:u2url.r/l~u:l2(1(3ucrOrea* +m4u* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * qeWtknld* * * * op5uebebebeb6u__Wr!n7uqmqmqmqm~e* DmNb u* * 8unc9u#t* gmNbum* * * ZcSd$t* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * 0uea* * * * * * Na* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * E4mnauId* * * * ld}obubuVcNb,o__WrQh.t* * * * * * DmNb u* * * cuduImPdgmNbum* * * ZcSdGg* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * & & BaBaBaBaL0y0eu* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * fuNbgu* * * * * * * eahuNbbd__WrQh.t* * * * * * DmNb u* * * * iuncjuguNbum* * * zgSd$t* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * eakulumuBjBjBj}q`hnu* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * UfVbrj9a* * * * * * ,gWcXt* DiWrQh.t* * * * * * DmNb_k* * * * * Qmjb@oNbum* * * ZcSdGg* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * ldoupuquru9p9p9pit}j* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * Nasu}c's#dkc[ NaldUdtu@tSb* __Wrlf.t* * * * * * DmNb u* * * * * * im}cNbum* * * ZcSd$t* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * JrPruuldE4; ; ; & ea* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * & vuwuObRnjgxuGiObyuVd* * __Wr+fzuAuAuAuAutn* DmNb_k* * * * * * BaBujbum* * * zgSd$t* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * MaCuDu& * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * :nZrEuFuGuBgfuJb* * * veHuIuIuIuIuIuIuFm* JuIuUf* * * * * * * * pcKu* * * ~lLuMu* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * & NuOu; * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * [ * * * * * * * * * * * * * * * * * * * * * * * * * * * * Pu* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * L0QuRuSuTuUuVuMs* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * GpWuouXuXuwhYu* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * Hopk* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * & ]b& & & & & [ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * L0!tZuZuZuZuZuLt* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * eaph(t(t(tIsZpGp& * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * Ba& Ll+l= * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * * * `u/t* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * * ep*kro* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * L0or v v.v.v+v@v#v$v* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * Gp%v)r(t(t&v*v=vE4* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * ct(_* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * Na* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"@ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * @ ",
"+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * + ",
". & * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * & . ",
"  % * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * %   ",
"  $ & * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * & $   ",
"    # & * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * & #     ",
"      $ % & * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * & % $       ",
"          . + @ # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # @ + .           "};

